@@ -24,12 +24,13 @@ $wgAutoloadLocalClasses = array(
 	'AuthPluginUser' => 'includes/AuthPlugin.php',
 	'Autopromote' => 'includes/Autopromote.php',
 	'BacklinkCache' => 'includes/BacklinkCache.php',
+	'BadTitleError' => 'includes/Exception.php',
 	'BaseTemplate' => 'includes/SkinTemplate.php',
 	'Block' => 'includes/Block.php',
 	'Category' => 'includes/Category.php',
 	'Categoryfinder' => 'includes/Categoryfinder.php',
 	'CategoryPage' => 'includes/CategoryPage.php',
-	'CategoryViewer' => 'includes/CategoryPage.php',
+	'CategoryViewer' => 'includes/CategoryViewer.php',
 	'CdbFunctions' => 'includes/Cdb_PHP.php',
 	'CdbReader' => 'includes/Cdb.php',
 	'CdbReader_DBA' => 'includes/Cdb.php',
@@ -46,11 +47,15 @@ $wgAutoloadLocalClasses = array(
 	'ConfEditor' => 'includes/ConfEditor.php',
 	'ConfEditorParseError' => 'includes/ConfEditor.php',
 	'ConfEditorToken' => 'includes/ConfEditor.php',
-	'ContextSource' => 'includes/RequestContext.php',
 	'Cookie' => 'includes/Cookie.php',
 	'CookieJar' => 'includes/Cookie.php',
+	'MWCryptRand' => 'includes/CryptRand.php',
+	'CurlHttpRequest' => 'includes/HttpFunctions.php',
+	'DeferrableUpdate' => 'includes/DeferredUpdates.php',
+	'DeferredUpdates' => 'includes/DeferredUpdates.php',
+	'DerivativeRequest' => 'includes/WebRequest.php',
 	'DiffHistoryBlob' => 'includes/HistoryBlob.php',
-	'DjVuImage' => 'includes/DjVuImage.php',
+
 	'DoubleReplacer' => 'includes/StringUtils.php',
 	'DummyLinker' => 'includes/Linker.php',
 	'Dump7ZipOutput' => 'includes/Export.php',
@@ -87,13 +92,10 @@ $wgAutoloadLocalClasses = array(
 	'FormAction' => 'includes/Action.php',
 	'FormOptions' => 'includes/FormOptions.php',
 	'FormSpecialPage' => 'includes/SpecialPage.php',
-	'GenderCache' => 'includes/GenderCache.php',
 	'HashtableReplacer' => 'includes/StringUtils.php',
 	'HistoryBlob' => 'includes/HistoryBlob.php',
 	'HistoryBlobCurStub' => 'includes/HistoryBlob.php',
 	'HistoryBlobStub' => 'includes/HistoryBlob.php',
-	'HistoryPage' => 'includes/HistoryPage.php',
-	'HistoryPager' => 'includes/HistoryPage.php',
 	'Hooks' => 'includes/Hooks.php',
 	'Html' => 'includes/Html.php',
 	'HTMLCheckField' => 'includes/HTMLForm.php',
@@ -113,8 +115,8 @@ $wgAutoloadLocalClasses = array(
 	'HTMLTextAreaField' => 'includes/HTMLForm.php',
 	'HTMLTextField' => 'includes/HTMLForm.php',
 	'Http' => 'includes/HttpFunctions.php',
+	'HttpError' => 'includes/Exception.php',
 	'HttpRequest' => 'includes/HttpFunctions.old.php',
-	'IContextSource' => 'includes/RequestContext.php',
 	'IcuCollation' => 'includes/Collation.php',
 	'IdentityCollation' => 'includes/Collation.php',
 	'ImageGallery' => 'includes/ImageGallery.php',
@@ -128,6 +130,7 @@ $wgAutoloadLocalClasses = array(
 	'IndexPager' => 'includes/Pager.php',
 	'Interwiki' => 'includes/interwiki/Interwiki.php',
 	'IP' => 'includes/IP.php',
+	'LCStore_Accel' => 'includes/LocalisationCache.php',
 	'LCStore_CDB' => 'includes/LocalisationCache.php',
 	'LCStore_DB' => 'includes/LocalisationCache.php',
 	'LCStore_Null' => 'includes/LocalisationCache.php',
@@ -139,9 +142,6 @@ $wgAutoloadLocalClasses = array(
 	'LinksUpdate' => 'includes/LinksUpdate.php',
 	'LocalisationCache' => 'includes/LocalisationCache.php',
 	'LocalisationCache_BulkLoad' => 'includes/LocalisationCache.php',
-	'LogEventsList' => 'includes/LogEventsList.php',
-	'LogPage' => 'includes/LogPage.php',
-	'LogPager' => 'includes/LogEventsList.php',
 	'MagicWord' => 'includes/MagicWord.php',
 	'MagicWordArray' => 'includes/MagicWord.php',
 	'MailAddress' => 'includes/UserMailer.php',
@@ -159,24 +159,23 @@ $wgAutoloadLocalClasses = array(
 	'OldChangesList' => 'includes/ChangesList.php',
 	'OutputPage' => 'includes/OutputPage.php',
 	'Page' =>  'includes/WikiPage.php',
-	'PageHistory' => 'includes/HistoryPage.php',
-	'PageHistoryPager' => 'includes/HistoryPage.php',
 	'PageQueryPage' => 'includes/PageQueryPage.php',
 	'Pager' => 'includes/Pager.php',
 	'PasswordError' => 'includes/User.php',
-	'PatrolLog' => 'includes/PatrolLog.php',
+	'PathRouter' => 'includes/PathRouter.php',
+	'PathRouterPatternReplacer' => 'includes/PathRouter.php',
 	'PermissionsError' => 'includes/Exception.php',
 	'PhpHttpRequest' => 'includes/HttpFunctions.php',
 	'PoolCounter' => 'includes/PoolCounter.php',
 	'PoolCounter_Stub' => 'includes/PoolCounter.php',
 	'PoolCounterWork' => 'includes/PoolCounter.php',
+	'PoolWorkArticleView' => 'includes/WikiPage.php',
 	'Preferences' => 'includes/Preferences.php',
 	'PreferencesForm' => 'includes/Preferences.php',
 	'PrefixSearch' => 'includes/PrefixSearch.php',
 	'ProtectionForm' => 'includes/ProtectionForm.php',
 	'QueryPage' => 'includes/QueryPage.php',
 	'QuickTemplate' => 'includes/SkinTemplate.php',
-	'RawPage' => 'includes/RawPage.php',
 	'RCCacheEntry' => 'includes/ChangesList.php',
 	'RdfMetaData' => 'includes/Metadata.php',
 	'ReadOnlyError' => 'includes/Exception.php',
@@ -185,10 +184,9 @@ $wgAutoloadLocalClasses = array(
 	'RegexlikeReplacer' => 'includes/StringUtils.php',
 	'ReplacementArray' => 'includes/StringUtils.php',
 	'Replacer' => 'includes/StringUtils.php',
-	'RequestContext' => 'includes/RequestContext.php',
 	'ReverseChronologicalPager' => 'includes/Pager.php',
-	'Rev_Item' => 'includes/RevisionList.php',
-	'Rev_List' => 'includes/RevisionList.php',
+	'RevisionItemBase' => 'includes/RevisionList.php',
+	'RevisionListBase' => 'includes/RevisionList.php',
 	'Revision' => 'includes/Revision.php',
 	'RevisionList' => 'includes/RevisionList.php',
 	'RSSFeed' => 'includes/Feed.php',
@@ -213,6 +211,7 @@ $wgAutoloadLocalClasses = array(
 	'SquidPurgeClient' => 'includes/SquidPurgeClient.php',
 	'SquidPurgeClientPool' => 'includes/SquidPurgeClient.php',
 	'Status' => 'includes/Status.php',
+	'StreamFile' => 'includes/StreamFile.php',
 	'StringUtils' => 'includes/StringUtils.php',
 	'StubContLang' => 'includes/StubObject.php',
 	'StubObject' => 'includes/StubObject.php',
@@ -257,15 +256,26 @@ $wgAutoloadLocalClasses = array(
 
 	# includes/actions
 	'CreditsAction' => 'includes/actions/CreditsAction.php',
-	'DeletetrackbackAction' => 'includes/actions/DeletetrackbackAction.php',
+	'DeleteAction' => 'includes/actions/DeleteAction.php',
+	'EditAction' => 'includes/actions/EditAction.php',
+	'HistoryAction' => 'includes/actions/HistoryAction.php',
+	'HistoryPage' => 'includes/actions/HistoryAction.php',
+	'HistoryPager' => 'includes/actions/HistoryAction.php',
 	'InfoAction' => 'includes/actions/InfoAction.php',
 	'MarkpatrolledAction' => 'includes/actions/MarkpatrolledAction.php',
+	'ProtectAction' => 'includes/actions/ProtectAction.php',
 	'PurgeAction' => 'includes/actions/PurgeAction.php',
+	'RawAction' => 'includes/actions/RawAction.php',
+	'RawPage' => 'includes/actions/RawAction.php',
+	'RenderAction' => 'includes/actions/RenderAction.php',
 	'RevertAction' => 'includes/actions/RevertAction.php',
 	'RevertFileAction' => 'includes/actions/RevertAction.php',
 	'RevisiondeleteAction' => 'includes/actions/RevisiondeleteAction.php',
 	'RollbackAction' => 'includes/actions/RollbackAction.php',
+	'SubmitAction' => 'includes/actions/EditAction.php',
+	'UnprotectAction' => 'includes/actions/ProtectAction.php',
 	'UnwatchAction' => 'includes/actions/WatchAction.php',
+	'ViewAction' => 'includes/actions/ViewAction.php',
 	'WatchAction' => 'includes/actions/WatchAction.php',
 
 	# includes/api
@@ -358,13 +368,14 @@ $wgAutoloadLocalClasses = array(
 	'ApiUpload' => 'includes/api/ApiUpload.php',
 	'ApiUserrights' => 'includes/api/ApiUserrights.php',
 	'ApiWatch' => 'includes/api/ApiWatch.php',
-	'UsageException' => 'includes/api/ApiMain.php',
 
 	# includes/cache
 	'CacheDependency' => 'includes/cache/CacheDependency.php',
 	'ConstantDependency' => 'includes/cache/CacheDependency.php',
 	'DependencyWrapper' => 'includes/cache/CacheDependency.php',
+	'FileCacheBase' => 'includes/cache/FileCacheBase.php',
 	'FileDependency' => 'includes/cache/CacheDependency.php',
+	'GenderCache' => 'includes/cache/GenderCache.php',
 	'GlobalDependency' => 'includes/cache/CacheDependency.php',
 	'HTMLCacheUpdate' => 'includes/cache/HTMLCacheUpdate.php',
 	'HTMLCacheUpdateJob' => 'includes/cache/HTMLCacheUpdate.php',
@@ -372,10 +383,20 @@ $wgAutoloadLocalClasses = array(
 	'LinkBatch' => 'includes/cache/LinkBatch.php',
 	'LinkCache' => 'includes/cache/LinkCache.php',
 	'MessageCache' => 'includes/cache/MessageCache.php',
+	'ObjectFileCache' => 'includes/cache/ObjectFileCache.php',
+	'ResourceFileCache' => 'includes/cache/ResourceFileCache.php',
 	'SquidUpdate' => 'includes/cache/SquidUpdate.php',
 	'TitleDependency' => 'includes/cache/CacheDependency.php',
 	'TitleListDependency' => 'includes/cache/CacheDependency.php',
 
+	'UsageException' => 'includes/api/ApiMain.php',
+
+	# includes/context
+	'ContextSource' => 'includes/context/ContextSource.php',
+	'DerivativeContext' => 'includes/context/DerivativeContext.php',
+	'IContextSource' => 'includes/context/IContextSource.php',
+	'RequestContext' => 'includes/context/RequestContext.php',
+
 	# includes/db
 	'Blob' => 'includes/db/DatabaseUtility.php',
 	'ChronologyProtector' => 'includes/db/LBFactory.php',
@@ -418,6 +439,9 @@ $wgAutoloadLocalClasses = array(
 	'ResultWrapper' => 'includes/db/DatabaseUtility.php',
 	'SQLiteField' => 'includes/db/DatabaseSqlite.php',
 
+	# includes/debug
+	'MWDebug' => 'includes/debug/Debug.php',
+
 	# includes/diff
 	'_DiffEngine' => 'includes/diff/DairikiDiff.php',
 	'_DiffOp' => 'includes/diff/DairikiDiff.php',
@@ -443,24 +467,57 @@ $wgAutoloadLocalClasses = array(
 	'ExternalUser_vB' => 'includes/extauth/vB.php',
 
 	# includes/filerepo
-	'ArchivedFile' => 'includes/filerepo/ArchivedFile.php',
-	'File' => 'includes/filerepo/File.php',
 	'FileRepo' => 'includes/filerepo/FileRepo.php',
 	'FileRepoStatus' => 'includes/filerepo/FileRepoStatus.php',
-	'ForeignAPIFile' => 'includes/filerepo/ForeignAPIFile.php',
 	'ForeignAPIRepo' => 'includes/filerepo/ForeignAPIRepo.php',
-	'ForeignDBFile' => 'includes/filerepo/ForeignDBFile.php',
 	'ForeignDBRepo' => 'includes/filerepo/ForeignDBRepo.php',
 	'ForeignDBViaLBRepo' => 'includes/filerepo/ForeignDBViaLBRepo.php',
 	'FSRepo' => 'includes/filerepo/FSRepo.php',
-	'LocalFile' => 'includes/filerepo/LocalFile.php',
-	'LocalFileDeleteBatch' => 'includes/filerepo/LocalFile.php',
-	'LocalFileMoveBatch' => 'includes/filerepo/LocalFile.php',
-	'LocalFileRestoreBatch' => 'includes/filerepo/LocalFile.php',
 	'LocalRepo' => 'includes/filerepo/LocalRepo.php',
-	'OldLocalFile' => 'includes/filerepo/OldLocalFile.php',
+	'NullRepo' => 'includes/filerepo/NullRepo.php',
 	'RepoGroup' => 'includes/filerepo/RepoGroup.php',
-	'UnregisteredLocalFile' => 'includes/filerepo/UnregisteredLocalFile.php',
+
+	# includes/filerepo/file
+	'ArchivedFile' => 'includes/filerepo/file/ArchivedFile.php',
+	'File' => 'includes/filerepo/file/File.php',
+	'ForeignAPIFile' => 'includes/filerepo/file/ForeignAPIFile.php',
+	'ForeignDBFile' => 'includes/filerepo/file/ForeignDBFile.php',
+	'LocalFile' => 'includes/filerepo/file/LocalFile.php',
+	'LocalFileDeleteBatch' => 'includes/filerepo/file/LocalFile.php',
+	'LocalFileMoveBatch' => 'includes/filerepo/file/LocalFile.php',
+	'LocalFileRestoreBatch' => 'includes/filerepo/file/LocalFile.php',
+	'OldLocalFile' => 'includes/filerepo/file/OldLocalFile.php',
+	'UnregisteredLocalFile' => 'includes/filerepo/file/UnregisteredLocalFile.php',
+	'FSFile' => 'includes/filerepo/backend/FSFile.php',
+	'TempFSFile' => 'includes/filerepo/backend/TempFSFile.php',
+
+	# includes/filerepo/backend
+	'FileBackendGroup' => 'includes/filerepo/backend/FileBackendGroup.php',
+	'FileBackend' => 'includes/filerepo/backend/FileBackend.php',
+	'FileBackendStore' => 'includes/filerepo/backend/FileBackend.php',
+	'FileBackendMultiWrite' => 'includes/filerepo/backend/FileBackendMultiWrite.php',
+	'FileBackendStoreShardListIterator' => 'includes/filerepo/backend/FileBackend.php',
+	'FSFileBackend' => 'includes/filerepo/backend/FSFileBackend.php',
+	'FSFileBackendFileList' => 'includes/filerepo/backend/FSFileBackend.php',
+	'SwiftFileBackend' => 'includes/filerepo/backend/SwiftFileBackend.php',
+	'SwiftFileBackendFileList' => 'includes/filerepo/backend/SwiftFileBackend.php',
+	'LockManagerGroup' => 'includes/filerepo/backend/lockmanager/LockManagerGroup.php',
+	'LockManager' => 'includes/filerepo/backend/lockmanager/LockManager.php',
+	'ScopedLock' => 'includes/filerepo/backend/lockmanager/LockManager.php',
+	'FSLockManager' => 'includes/filerepo/backend/lockmanager/FSLockManager.php',
+	'DBLockManager' => 'includes/filerepo/backend/lockmanager/DBLockManager.php',
+	'LSLockManager' => 'includes/filerepo/backend/lockmanager/LSLockManager.php',
+	'MySqlLockManager'=> 'includes/filerepo/backend/lockmanager/DBLockManager.php',
+	'NullLockManager' => 'includes/filerepo/backend/lockmanager/LockManager.php',
+	'FileOp' => 'includes/filerepo/backend/FileOp.php',
+	'FileOpScopedPHPTimeout' => 'includes/filerepo/backend/FileOp.php',
+	'StoreFileOp' => 'includes/filerepo/backend/FileOp.php',
+	'CopyFileOp' => 'includes/filerepo/backend/FileOp.php',
+	'MoveFileOp' => 'includes/filerepo/backend/FileOp.php',
+	'DeleteFileOp' => 'includes/filerepo/backend/FileOp.php',
+	'ConcatenateFileOp' => 'includes/filerepo/backend/FileOp.php',
+	'CreateFileOp' => 'includes/filerepo/backend/FileOp.php',
+	'NullFileOp' => 'includes/filerepo/backend/FileOp.php',
 
 	# includes/installer
 	'CliInstaller' => 'includes/installer/CliInstaller.php',
@@ -526,13 +583,32 @@ $wgAutoloadLocalClasses = array(
 	'JSMinPlus' => 'includes/libs/jsminplus.php',
 	'JSParser' => 'includes/libs/jsminplus.php',
 
+	# includes/logging
+	'DatabaseLogEntry' => 'includes/logging/LogEntry.php',
+	'DeleteLogFormatter' => 'includes/logging/LogFormatter.php',
+	'LegacyLogFormatter' => 'includes/logging/LogFormatter.php',
+	'LogEntry' => 'includes/logging/LogEntry.php',
+	'LogEventsList' => 'includes/logging/LogEventsList.php',
+	'LogEntryBase' => 'includes/logging/LogEntry.php',
+	'LogFormatter' => 'includes/logging/LogFormatter.php',
+	'LogPage' => 'includes/logging/LogPage.php',
+	'LogPager' => 'includes/logging/LogPager.php',
+	'ManualLogEntry' => 'includes/logging/LogEntry.php',
+	'MoveLogFormatter' => 'includes/logging/LogFormatter.php',
+	'NewUsersLogFormatter' => 'includes/logging/LogFormatter.php',
+	'PatrolLog' => 'includes/logging/PatrolLog.php',
+	'PatrolLogFormatter' => 'includes/logging/LogFormatter.php',
+	'RCDatabaseLogEntry' => 'includes/logging/LogEntry.php',
+
 	# includes/media
 	'BitmapHandler' => 'includes/media/Bitmap.php',
 	'BitmapHandler_ClientOnly' => 'includes/media/Bitmap_ClientOnly.php',
 	'BitmapMetadataHandler' => 'includes/media/BitmapMetadataHandler.php',
 	'BmpHandler' => 'includes/media/BMP.php',
 	'DjVuHandler' => 'includes/media/DjVu.php',
+	'DjVuImage' => 'includes/media/DjVuImage.php',
 	'Exif' => 'includes/media/Exif.php',
+	'ExifBitmapHandler' => 'includes/media/ExifBitmap.php',
 	'FormatExif' => 'includes/media/FormatMetadata.php',
 	'FormatMetadata' => 'includes/media/FormatMetadata.php',
 	'GIFHandler' => 'includes/media/GIF.php',
@@ -541,7 +617,6 @@ $wgAutoloadLocalClasses = array(
 	'IPTC' => 'includes/media/IPTC.php',
 	'JpegHandler' => 'includes/media/Jpeg.php',
 	'JpegMetadataExtractor' => 'includes/media/JpegMetadataExtractor.php',
-	'ExifBitmapHandler' => 'includes/media/ExifBitmap.php',
 	'MediaHandler' => 'includes/media/Generic.php',
 	'MediaTransformError' => 'includes/media/MediaTransformOutput.php',
 	'MediaTransformOutput' => 'includes/media/MediaTransformOutput.php',
@@ -552,6 +627,7 @@ $wgAutoloadLocalClasses = array(
 	'ThumbnailImage' => 'includes/media/MediaTransformOutput.php',
 	'TiffHandler' => 'includes/media/Tiff.php',
 	'TransformParameterError' => 'includes/media/MediaTransformOutput.php',
+	'XCFHandler' => 'includes/media/XCF.php',
 	'XMPInfo' => 'includes/media/XMPInfo.php',
 	'XMPReader' => 'includes/media/XMP.php',
 	'XMPValidate' => 'includes/media/XMPValidate.php',
@@ -563,7 +639,6 @@ $wgAutoloadLocalClasses = array(
 	'APCBagOStuff' => 'includes/objectcache/APCBagOStuff.php',
 	'BagOStuff' => 'includes/objectcache/BagOStuff.php',
 	'DBABagOStuff' => 'includes/objectcache/DBABagOStuff.php',
-	'eAccelBagOStuff' => 'includes/objectcache/eAccelBagOStuff.php',
 	'EhcacheBagOStuff' => 'includes/objectcache/EhcacheBagOStuff.php',
 	'EmptyBagOStuff' => 'includes/objectcache/EmptyBagOStuff.php',
 	'FakeMemCachedClient' => 'includes/objectcache/EmptyBagOStuff.php',
@@ -647,6 +722,7 @@ $wgAutoloadLocalClasses = array(
 	'ResourceLoaderNoscriptModule' => 'includes/resourceloader/ResourceLoaderNoscriptModule.php',
 	'ResourceLoaderSiteModule' => 'includes/resourceloader/ResourceLoaderSiteModule.php',
 	'ResourceLoaderStartUpModule' => 'includes/resourceloader/ResourceLoaderStartUpModule.php',
+	'ResourceLoaderUserCSSPrefsModule' => 'includes/resourceloader/ResourceLoaderUserCSSPrefsModule.php',
 	'ResourceLoaderUserGroupsModule' => 'includes/resourceloader/ResourceLoaderUserGroupsModule.php',
 	'ResourceLoaderUserModule' => 'includes/resourceloader/ResourceLoaderUserModule.php',
 	'ResourceLoaderUserOptionsModule' => 'includes/resourceloader/ResourceLoaderUserOptionsModule.php',
@@ -739,6 +815,7 @@ $wgAutoloadLocalClasses = array(
 	'SpecialBlockme' => 'includes/specials/SpecialBlockme.php',
 	'SpecialBookSources' => 'includes/specials/SpecialBooksources.php',
 	'SpecialCategories' => 'includes/specials/SpecialCategories.php',
+	'SpecialChangeEmail' => 'includes/specials/SpecialChangeEmail.php',
 	'SpecialChangePassword' => 'includes/specials/SpecialChangePassword.php',
 	'SpecialComparePages' => 'includes/specials/SpecialComparePages.php',
 	'SpecialContributions' => 'includes/specials/SpecialContributions.php',
@@ -747,6 +824,7 @@ $wgAutoloadLocalClasses = array(
 	'SpecialExport' => 'includes/specials/SpecialExport.php',
 	'SpecialFilepath' => 'includes/specials/SpecialFilepath.php',
 	'SpecialImport' => 'includes/specials/SpecialImport.php',
+	'SpecialJavaScriptTest' => 'includes/specials/SpecialJavaScriptTest.php',
 	'SpecialListFiles' => 'includes/specials/SpecialListfiles.php',
 	'SpecialListGroupRights' => 'includes/specials/SpecialListgrouprights.php',
 	'SpecialListUsers' => 'includes/specials/SpecialListusers.php',
@@ -799,12 +877,13 @@ $wgAutoloadLocalClasses = array(
 	'WithoutInterwikiPage' => 'includes/specials/SpecialWithoutinterwiki.php',
 
 	# includes/templates
-	'UsercreateTemplate' => 'includes/templates/Userlogin.php',
 	'UserloginTemplate' => 'includes/templates/Userlogin.php',
+	'UsercreateTemplate' => 'includes/templates/Usercreate.php',
 
 	# includes/upload
 	'UploadBase' => 'includes/upload/UploadBase.php',
 	'UploadFromFile' => 'includes/upload/UploadFromFile.php',
+	'UploadFromChunks' => 'includes/upload/UploadFromChunks.php',
 	'UploadFromStash' => 'includes/upload/UploadFromStash.php',
 	'UploadFromUrl' => 'includes/upload/UploadFromUrl.php',
 	'UploadStash' => 'includes/upload/UploadStash.php',
@@ -815,6 +894,9 @@ $wgAutoloadLocalClasses = array(
 	'UploadStashFileNotFoundException' => 'includes/upload/UploadStash.php',
 	'UploadStashNotAvailableException' => 'includes/upload/UploadStash.php',
 	'UploadStashZeroLengthFileException' => 'includes/upload/UploadStash.php',
+	'UploadStashNotLoggedInException' => 'includes/upload/UploadStash.php',
+	'UploadStashWrongOwnerException' => 'includes/upload/UploadStash.php',
+	'UploadStashNoSuchKeyException' => 'includes/upload/UploadStash.php',
 
 	# languages
 	'FakeConverter' => 'languages/Language.php',
@@ -831,10 +913,13 @@ $wgAutoloadLocalClasses = array(
 	'Maintenance' => 'maintenance/Maintenance.php',
 	'FixExtLinksProtocolRelative' => 'maintenance/fixExtLinksProtocolRelative.php',
 	'PopulateCategory' => 'maintenance/populateCategory.php',
+	'PopulateImageSha1' => 'maintenance/populateImageSha1.php',
 	'PopulateLogSearch' => 'maintenance/populateLogSearch.php',
 	'PopulateLogUsertext' => 'maintenance/populateLogUsertext.php',
 	'PopulateParentId' => 'maintenance/populateParentId.php',
 	'PopulateRevisionLength' => 'maintenance/populateRevisionLength.php',
+	'PopulateRevisionSha1' => 'maintenance/populateRevisionSha1.php',
+	'RefreshLinks' => 'maintenance/refreshLinks.php',
 	'SevenZipStream' => 'maintenance/7zip.inc',
 	'Sqlite' => 'maintenance/sqlite.inc',
 	'UpdateCollation' => 'maintenance/updateCollation.php',
@@ -843,15 +928,19 @@ $wgAutoloadLocalClasses = array(
 
 	# maintenance/language
 	'csvStatsOutput' => 'maintenance/language/StatOutputs.php',
+	'languages' => 'maintenance/language/languages.inc',
+	'MessageWriter' => 'maintenance/language/writeMessagesArray.inc',
 	'statsOutput' => 'maintenance/language/StatOutputs.php',
 	'textStatsOutput' => 'maintenance/language/StatOutputs.php',
 	'wikiStatsOutput' => 'maintenance/language/StatOutputs.php',
 
+	# maintenance/term
+	'AnsiTermColorer'  => 'maintenance/term/MWTerm.php',
+	'DummyTermColorer' => 'maintenance/term/MWTerm.php',
+
 	# tests
-	'AnsiTermColorer' => 'tests/testHelpers.inc',
 	'DbTestPreviewer' => 'tests/testHelpers.inc',
 	'DbTestRecorder' => 'tests/testHelpers.inc',
-	'DummyTermColorer' => 'tests/testHelpers.inc',
 	'TestFileIterator' => 'tests/testHelpers.inc',
 	'TestRecorder' => 'tests/testHelpers.inc',
 
