@@ -24,11 +24,6 @@
  * @file
  */
 
-if ( !defined( 'MEDIAWIKI' ) ) {
-	// Eclipse helper - will be ignored in production
-	require_once( 'ApiQueryBase.php' );
-}
-
 /**
  * Query module to enumerate all available pages.
  *
@@ -312,16 +307,19 @@ class ApiQueryAllpages extends ApiQueryGeneratorBase {
 		) );
 	}
 
-	protected function getExamples() {
+	public function getExamples() {
 		return array(
-			'Simple Use',
-			' Show a list of pages starting at the letter "B"',
-			'  api.php?action=query&list=allpages&apfrom=B',
-			'Using as Generator',
-			' Show info about 4 pages starting at the letter "T"',
-			'  api.php?action=query&generator=allpages&gaplimit=4&gapfrom=T&prop=info',
-			' Show content of first 2 non-redirect pages begining at "Re"',
-			'  api.php?action=query&generator=allpages&gaplimit=2&gapfilterredir=nonredirects&gapfrom=Re&prop=revisions&rvprop=content'
+			'api.php?action=query&list=allpages&apfrom=B' => array(
+				'Simple Use',
+				'Show a list of pages starting at the letter "B"',
+			),
+			'api.php?action=query&generator=allpages&gaplimit=4&gapfrom=T&prop=info' => array(
+				'Using as Generator',
+				'Show info about 4 pages starting at the letter "T"',
+			),
+			'api.php?action=query&generator=allpages&gaplimit=2&gapfilterredir=nonredirects&gapfrom=Re&prop=revisions&rvprop=content' => array(
+				'Show content of first 2 non-redirect pages begining at "Re"',
+			)
 		);
 	}
 
@@ -330,6 +328,6 @@ class ApiQueryAllpages extends ApiQueryGeneratorBase {
 	}
 
 	public function getVersion() {
-		return __CLASS__ . ': $Id: ApiQueryAllpages.php 104449 2011-11-28 15:52:04Z reedy $';
+		return __CLASS__ . ': $Id$';
 	}
 }
