@@ -411,8 +411,7 @@ Hindi (hi)फ़िलहाल इस पन्ने पर कोई सा
 'linksearch' => 'बाहरी कड़ी',
 
 # Special:Log/newusers
-'newuserlogpage'          => 'नया सदस्यॊ के सूची',
-'newuserlog-create-entry' => 'नवीन सदस्य',
+'newuserlogpage' => 'नया सदस्यॊ के सूची',
 
 # Special:ListGroupRights
 'listgrouprights-members' => '(सदस्य सूची)',
@@ -447,8 +446,6 @@ Hindi (hi)फ़िलहाल इस पन्ने पर कोई सा
 'actionfailed'           => 'क्रिया विफल',
 'deletedtext'            => '"$1" कॆ हटैलॊ गेलॊ छै.
 हाल में हटैलॊ गेलॊ लेखॊ के सूची लेली $2 देखॊ.',
-'deletedarticle'         => '"[[$1]]" कॆ हटैलॊ गेलॊ छै.',
-'suppressedarticle'      => 'दबैलॊ "[[$1]]"',
 'dellogpage'             => 'हटाबै के सूची',
 'dellogpagetext'         => 'नीचॆ हाल मॆं हटैलॊ गेलॊ पन्ना के सूची छै.',
 'deletionlog'            => 'हटाबै के सूची',
@@ -534,7 +531,6 @@ $2 द्वारा संपादित आखिरी अवतरण क
 'undeletepagetitle' => "'''नीचे [[:$1]] केरॊ हटैलॊ गेलॊ अवतरण भी दर्शैलॊ गेलॊ छै.'''",
 'viewdeletedpage'   => 'हटैलॊ पन्ना वापस लानॊ',
 'undeletelink'      => 'देखॊ/पुनर्स्थापित करॊ',
-'undeletedarticle'  => '"[[$1]]" पुनर्स्थापित करलॊ गेलै',
 
 # Namespace form on various pages
 'namespace'      => 'नामस्थान:',
@@ -619,8 +615,6 @@ $2 द्वारा संपादित आखिरी अवतरण क
 कृपया एकरा स्वयं बदली दहॊ'''",
 'movedto'          => ' स्थानांतरीत करलॊ गेलै',
 'movetalk'         => 'संबंधित वार्ता पृष्ठ भी बदलॊ',
-'1movedto2'        => '[[$1]] सॆ[[$2]] पर स्थानांतरित करलॊ गेलै',
-'1movedto2_redir'  => '[[$1]] इ लेख के नाम बदली कॆ [[$2]] करी देलॊ गेलॊ छै (अनुप्रेषित)',
 'movelogpage'      => 'स्थानांतरण सूची',
 'movereason'       => 'कारण:',
 'revertmove'       => 'पुरानॊ अवतरण पर लॆ चलॊ (रिवर्ट)',
@@ -692,7 +686,7 @@ $2 द्वारा संपादित आखिरी अवतरण क
 
 # Media information
 'file-info-size' => '$1 × $2 चित्रतत्व, संचिका के आकार: $3, MIME प्रकार: $4',
-'file-nohires'   => '<small>सॆं ज्यादा रिज़ोल्यूशन उपलब्ध नै छै.</small>',
+'file-nohires'   => 'सॆं ज्यादा रिज़ोल्यूशन उपलब्ध नै छै.',
 'svg-long-desc'  => 'SVG फ़ाईल, साधारणत: $1 × $2 पीक्सेल्स, फ़ाईल केरॊ आकार: $3',
 'show-big-image' => 'संपूर्ण रिजोल्यूशन',
 
