@@ -232,6 +232,7 @@ $messages = array(
 'nstab-category'  => 'Trokiñ',
 
 # General errors
+'error'              => 'Welulkan',
 'missing-article'    => 'Feychi ngülümdunguwe kintulay feychi wülngiñ ñi wirin, welu nienuafulu. Ñi üy ta "$1" $2.
 
 Chi kiñe rakizuamün ta pünefalkülenuchi kalelu kam nülkükawlelu liftungepelu wülngiñ ñi rupañmael.
@@ -254,6 +255,7 @@ Nieafuy falinochi wirin püñamtuam wülngiñ ñi üy.',
 'nav-login-createaccount' => 'konkülen/dewman konün',
 'loginprompt'             => 'Müley "Cookies" ñi püneleael wirintukuwam {{SITENAME}} mew.',
 'userlogin'               => 'Konkülen/dewman konün',
+'userloginnocreate'       => 'Konün',
 'logout'                  => 'Tripan',
 'userlogout'              => 'Tripan',
 'notloggedin'             => 'Petu konlaymi.',
@@ -263,9 +265,13 @@ Nieafuy falinochi wirin püñamtuam wülngiñ ñi üy.',
 'gotaccount'              => 'Dew nieymi konün? $1.',
 'gotaccountlink'          => 'Konün',
 'userlogin-resetlink'     => 'Ngoyüniengetuymi chumngechi konün?',
+'createaccountreason'     => 'Dungu:',
 'mailmypassword'          => 'Amulün we nülawe werküwe mew',
 'loginlanguagelabel'      => 'Cezugun: $1',
 
+# Change password dialog
+'resetpass-submit-cancel' => 'Katrüntukun',
+
 # Edit page toolbar
 'bold_sample'     => 'Kurükünualu wirin',
 'bold_tip'        => 'Kurükünualu wirin',
@@ -361,8 +367,6 @@ Rulpakünuy feychi kangelkülelu dungu.",
 'revdel-restore-visible'     => 'pengengekelu malün',
 'pagehist'                   => 'pünon pakina',
 'deletedhist'                => 'Ñamümüngelu pünon',
-'revdelete-uname'            => 'Üy kellufe',
-'revdelete-hid'              => 'Ellkan $1',
 'revdelete-edit-reasonlist'  => 'Wirin dungu ñamümgün mew',
 
 # History merging
@@ -581,7 +585,7 @@ Fey ñi chumngen mülelu ($2 fey ñi chumngen wülngiñ) pengeli tüfa mew.',
 'nviews'            => '$1 {{PLURAL:$1|pen|pen}}',
 'prefixindex'       => 'Kom wülngiñ engu wüne konkülelu nemül',
 'shortpages'        => 'Pichi pakina',
-'usercreated'       => 'Llintun $1 mew $2 mew',
+'usercreated'       => '{{GENDER:$3|Dewmangey}} $1, $2 mew',
 'newpages'          => 'Weke wülngiñ',
 'newpages-username' => 'Kellufe ñi üy',
 'move'              => 'Wiñamün',
@@ -657,7 +661,6 @@ Fey ñi chumngen mülelu ($2 fey ñi chumngen wülngiñ) pengeli tüfa mew.',
 'delete-legend'         => 'Ñamümün',
 'actioncomplete'        => 'Wechuley chi femün',
 'actionfailed'          => 'Wedalkay chi femün.',
-'deletedarticle'        => '«[[$1]]» Ñamümün',
 'dellogpage'            => 'Liftungepelu wülngiñ ñi wirintukun',
 'deletereasonotherlist' => 'Kake dungu',
 
@@ -756,7 +759,6 @@ Fey ñi chumngen mülelu ($2 fey ñi chumngen wülngiñ) pengeli tüfa mew.',
 'move-watch'              => 'Llaytun tüfachi pakina',
 'movepagebtn'             => 'Nengümün pakina',
 'movedto'                 => 'Nengümün',
-'1movedto2'               => '[[$1]] wiñamngey [[$2]] püle',
 'movelogpage'             => 'Nengümün wirintukun',
 'revertmove'              => 'wüñoeltun',
 'delete_and_move'         => 'Ñamümün ka nengümün',
@@ -835,15 +837,13 @@ Fey ñi chumngen mülelu ($2 fey ñi chumngen wülngiñ) pengeli tüfa mew.',
 'others'    => 'fill',
 'siteusers' => '{{PLURAL:$2|Kellufe|Kellufe}} $1 {{SITENAME}}',
 
-# Patrol log
-'patrol-log-diff' => 'ng$1',
-
 # Browsing diffs
 'previousdiff' => '← Füta wirin',
 'nextdiff'     => 'We wirin →',
 
 # Media information
 'file-info-size' => '$1 × $2 adentun piküsel, eltukawün ñi tunte ngen: $3, MIME ñi chumngen: $4',
+'file-nohires'   => 'Pepiduamngefalay chum pengeam.',
 'svg-long-desc'  => 'SVG eltukawe, pingey $1 × $2 adentun piküsel, eltukawün ñi tunte ngen: $3',
 'show-big-image' => 'Rüf chum pengeam',
 
@@ -851,7 +851,7 @@ Fey ñi chumngen mülelu ($2 fey ñi chumngen wülngiñ) pengeli tüfa mew.',
 'ilsubmit' => 'Kintu',
 
 # Video information, used by Language::formatTimePeriod() to format lengths in the above messages
-'hours-abbrev' => 'o',
+'hours-abbrev' => '$1o',
 
 # Bad image list
 'bad_image_list' => 'Feychi chumkünuwe ta femngechi:
@@ -908,9 +908,6 @@ Ka dungu ellkangeay wünedullin reke.
 'monthsall'     => '(kom)',
 'limitall'      => 'Kom',
 
-# Trackbacks
-'trackbackremove' => '([$1 Ñamümün])',
-
 # action=purge
 'confirm_purge_button' => 'Feley may',
 
