@@ -9,6 +9,7 @@
  *
  * @author Behdarvandyani
  * @author GerardM
+ * @author Huji
  * @author Meno25
  */
 
@@ -28,8 +29,7 @@ $messages = array(
 'tog-editsection'             => 'امکان اصلاح یه قسمت زه راه لینکها',
 'tog-editsectiononrightclick' => 'امکان اصلاح یه قسمت زه راه راست کلیک کردن رو عنوان  اوقسمت- جاوااسکریپت',
 'tog-showtoc'                 => 'نشودادن فهرست محتوا سی صفحاتی که بیشتر زه سه سرخط دارن',
-'tog-rememberpassword'        => 'به حافظه کامپیوتر دادن نحوه ورودی خوم',
-'tog-editwidth'               => 'اصلاح جعبه یا کادری که عرضا پر وابیده',
+'tog-rememberpassword'        => 'به حافظه کامپیوتر دادن نحوه ورودی خوم (for a maximum of $1 {{PLURAL:$1|day|days}})',
 'tog-watchcreations'          => 'اضاف کردن اوصفحاتی که خوم درست کردم به فهرست نمایشی',
 'tog-watchdefault'            => 'اضاف کردن اوصفحاتی که خوم اصلاح کردم به فهرست نمایشی',
 'tog-watchmoves'              => 'اضاف کردن صفحاتی که خوم جابجا کردم به فهرست نمایشی',
@@ -121,7 +121,7 @@ $messages = array(
 'category-media-header'          => 'مدیا دردسته "$1"',
 'category-empty'                 => 'ای دسته درحال حاضر دارای هیچ صفحه یا مدیایی نه',
 'hidden-categories'              => '{{PLURAL:$1|دسته قایم|دسته های قایم}}',
-'hidden-category-category'       => 'دسته های قایم', # Name of the category where hidden categories will be listed
+'hidden-category-category'       => 'دسته های قایم',
 'category-subcat-count'          => '{{PLURAL:$2|ای دسته فقط دسته های فرعی زیر راداره.|ای دسته چیزهای زیر راداره {{PLURAL:$1|دسته فرعی|$1 دسته های فرعی}}, بیشتراز$2 کل.}}',
 'category-subcat-count-limited'  => 'ای دسته چیزهای زیر راداره {{PLURAL:$1|دسته فرعی|$1 دسته های فرعی}}.',
 'category-article-count'         => '{{PLURAL:$2|ای دسته فقط دارای صفحات زیره.|ذیل الذکر{{PLURAL:$1|صفحه است|$1 صفحات هستند}} دراین دسته, بیشترزه$2 کل.}}',
@@ -133,10 +133,14 @@ $messages = array(
 'about'     => 'درباره',
 'newwindow' => '(پنجره تازه واز کن)',
 'cancel'    => 'لغو',
-'qbfind'    => 'پیدا کردن',
-'qbedit'    => 'اصلاح',
 'mytalk'    => 'صحبت مو',
 
+# Cologne Blue skin
+'qbfind'  => 'پیدا کردن',
+'qbedit'  => 'اصلاح',
+'faq'     => 'اف ای کیو',
+'faqpage' => 'Project:اف ای کیو',
+
 'errorpagetitle'   => 'خطا',
 'returnto'         => 'بازگشت به $1.',
 'tagline'          => 'از {{SITENAME}}',
@@ -174,7 +178,7 @@ $messages = array(
 'otherlanguages'   => 'درزبانهای دیگر',
 'redirectedfrom'   => '(تصحیح مجدداز$1)',
 'redirectpagesub'  => 'صفحه تصحیح وهدایت مجدد',
-'lastmodifiedat'   => 'این صفحه اخیرا تغییر واصلاح شددر $1, در $2.', # $1 date, $2 time
+'lastmodifiedat'   => 'این صفحه اخیرا تغییر واصلاح شددر $1, در $2.',
 'viewcount'        => 'این صفحه قابل دسترسی شده است {{PLURAL:$1|once|$1 times}}.',
 'protectedpage'    => 'صفحه حمایت شده',
 'jumpto'           => 'پریدن به:',
@@ -186,7 +190,6 @@ $messages = array(
 'aboutpage'            => 'Project:درباره',
 'copyright'            => 'محتوا باای شماره قابل دسترسیه
  $1.',
-'copyrightpagename'    => '{{SITENAME}} کپی رایت',
 'copyrightpage'        => '{{ns:project}}:کپی رایت',
 'currentevents'        => 'اتفاقات جاری',
 'currentevents-url'    => 'Project:اتفاقات جاری',
@@ -194,8 +197,6 @@ $messages = array(
 'disclaimerpage'       => 'Project:انکار کاربران',
 'edithelp'             => 'کمک برای اصلاح',
 'edithelppage'         => 'Help:اصلاح',
-'faq'                  => 'اف ای کیو',
-'faqpage'              => 'Project:اف ای کیو',
 'helppage'             => 'Help:محتوا',
 'mainpage'             => 'صفحه اصلی',
 'mainpage-description' => 'صفحه اصلی',
@@ -210,9 +211,9 @@ $messages = array(
 'badaccess-groups' => 'او کاری که ایسا درخواست کردین فقط سی کاربرانیه که من ای  گروهن
 {{PLURAL:$2|آن گروه|یکی زه گروهها}}: $1.',
 
-'versionrequired'     => 'یه نسخه زه نیازمندیهای ویکی مدیا 
+'versionrequired'     => 'یه نسخه زه نیازمندیهای ویکی مدیا
 $1',
-'versionrequiredtext' => 'یه نسخه زه ویکی مدیا($1) نیازمند ه به استفاده زه ای صفحه 
+'versionrequiredtext' => 'یه نسخه زه ویکی مدیا($1) نیازمند ه به استفاده زه ای صفحه
 بوین :[[Special:Version|version page]].',
 
 'ok'                      => 'خووه',
@@ -248,16 +249,15 @@ $1',
 
 # General errors
 'badtitle'       => 'عنوان بد',
-'badtitletext'   => 'عنوان درخواستی نامعتبر، خالی، یا عنوانی بین زبانی یا بین‌ویکی‌ای با پیوند نادرسته 
+'badtitletext'   => 'عنوان درخواستی نامعتبر، خالی، یا عنوانی بین زبانی یا بین‌ویکی‌ای با پیوند نادرسته
 و ممکنه دارای یک یا چند کاراکتر بوه که در عنوان مربوط نوا زش استفاده کنین',
 'viewsource'     => 'مشاهده منبع',
-'viewsourcefor'  => 'سی $1',
 'viewsourcetext' => 'ایسا ترین بوینین وکپی کنین منبع ای صفحه را:',
 
 # Login and logout pages
 'yourname'                => 'نام کاربر:',
 'yourpassword'            => 'رمز:',
-'remembermypassword'      => 'رمز اویدن به سیستم را دراین رایانه به خاطر بسپار',
+'remembermypassword'      => 'رمز اویدن به سیستم را دراین رایانه به خاطر بسپار (for a maximum of $1 {{PLURAL:$1|day|days}})',
 'login'                   => 'اویدن به سیستم',
 'nav-login-createaccount' => 'اویدن به سیستم',
 'loginprompt'             => 'ایسا وا کوکی ها رافعال کنین سی اویدن به  {{SITENAME}}.',
@@ -269,13 +269,11 @@ $1',
 'createaccount'           => 'درست کردن حساب کاربری',
 'gotaccount'              => "آیا تقریبا یه حساب کاربری دارین? '''$1'''.",
 'gotaccountlink'          => 'اویدن به',
-'yourrealname'            => 'نام واقعی:',
-'prefs-help-realname'     => 'ذکر نام واقعی اختیاریه ایر تصمیم به گدن بگیرین هنگام ارجاع به آثارتو و انتساب هونو به ایسا زه نام واقعیتو استفاده ابوه',
 'loginsuccesstitle'       => 'اویدن با بخت وتوفیق به سیستم',
 'loginsuccess'            => "''' ایسا اویدن به داخل سایت {{SITENAME}} بعنوان \"\$1\".'''",
 'nosuchuser'              => 'کاربری به ای نام وجود نداره "$1".
 حروف نام را چک کنین, یا [[Special:UserLogin/signup|درست کنین یه حساب کاربری تازه]].',
-'nosuchusershort'         => 'کاربری به ای نام وجود نداره"<nowiki>$1</nowiki>".
+'nosuchusershort'         => 'کاربری به ای نام وجود نداره"$1".
 حروف نام راچک کنین.',
 'nouserspecified'         => 'ایسا دارین یه نام کاربر ذکر اکنین.',
 'wrongpassword'           => 'رمز وارد وابیده درست نه.
@@ -296,7 +294,7 @@ $1',
 لطفا بعد از دریافت آن داخل سیستم بوین.',
 'eauthentsent'            => 'یه نامه الکترونیکی سی تایید نشانی پست الکترونیکی به نشانی مورنظر ارسال وابید. قبل زه یو که نامه دیگری قابل ارسال به این نشانی بوه، وا دستورهایی که در آن نامه اویده را جهت تأیید ای مساله که ای نشانی مال ایسانه اجرا کنین.',
 
-# Password reset dialog
+# Change password dialog
 'retypenew' => 'تایپ دوباره رمز:',
 
 # Edit page toolbar
@@ -311,8 +309,6 @@ $1',
 لینک خارجی',
 'headline_sample' => 'سرخط متن',
 'headline_tip'    => '2سرخط یکسان',
-'math_sample'     => 'فرمول نهادن ایچو',
-'math_tip'        => 'فرمول ریاضی (LaTeX)',
 'nowiki_sample'   => 'متن شکل نداده یافرمت نوابیده را ایچو بنین',
 'nowiki_tip'      => 'زه فرمت کردن یا شکل دادن ویکی چشم پوشی کن',
 'image_tip'       => 'فایل محاط وابید',
@@ -321,18 +317,18 @@ $1',
 'hr_tip'          => 'خط افقی (کم استفاده کنین)',
 
 # Edit pages
-'summary'                => 'خلاصه:',
-'subject'                => 'موضوع/سرخط:',
-'minoredit'              => 'ای یه اصلاح ریزه-رز',
-'watchthis'              => 'پیگیری ای صفحه',
-'savearticle'            => 'صفحه ضبط بوه',
-'preview'                => 'پیش نمایش',
-'showpreview'            => 'پیش‌نمایش',
-'showdiff'               => 'نشودادن تغییرات',
-'anoneditwarning'        => "'''توجه:''' ایسا داخل سیستم نوابیدین.
+'summary'                    => 'خلاصه:',
+'subject'                    => 'موضوع/سرخط:',
+'minoredit'                  => 'ای یه اصلاح ریزه-رز',
+'watchthis'                  => 'پیگیری ای صفحه',
+'savearticle'                => 'صفحه ضبط بوه',
+'preview'                    => 'پیش نمایش',
+'showpreview'                => 'پیش‌نمایش',
+'showdiff'                   => 'نشودادن تغییرات',
+'anoneditwarning'            => "'''توجه:''' ایسا داخل سیستم نوابیدین.
 آی پی آدرستو درگزارش اصلاح صفحه ضبط ابوه.",
-'summary-preview'        => 'پیش نمایش - خلاصه:',
-'blockedtext'            => ' "\'\'\'دسترسی نام کاربری یا نشانی اینترنتی ایسا بسته وابیده.\'\'\'
+'summary-preview'            => 'پیش نمایش - خلاصه:',
+'blockedtext'                => ' "\'\'\'دسترسی نام کاربری یا نشانی اینترنتی ایسا بسته وابیده.\'\'\'
 ای کار توسط $1 انجام شده‌است.
 دلیلی که گده اینه: $2\'\'
 * آغاز قطع دسترسی: $8
@@ -345,37 +341,34 @@ $1',
 دقت کنین که سی ارسال پست الکترونیکی در ویکی، وا پست الکترونیکی خود را زه طریق صفحه[[Special:Preferences|تنظیمات]] فعال کرده بوین، و نیز، وا امکان استفاده زه ای ویژگی سی ایساقطع نبوه.
 نشانی اینترنتی الان ایسا $3 است و شماره قطع دسترسی $5 است.
 لطفاً ای شماره را در هر درخواستی که در ای مورد مطرح اکنین ذکر کنین',
-'newarticle'             => '(تازه)',
-'newarticletext'         => 'ایسا لینکی را دنبال کردین و به صفحه‌ای رسیدین که هنی درست نوابیده.
+'newarticle'                 => '(تازه)',
+'newarticletext'             => 'ایسا لینکی را دنبال کردین و به صفحه‌ای رسیدین که هنی درست نوابیده.
 سی ایجاد صفحه، داخل مستطیل زیر شروع به تایپ کنین (سی اطلاعات بیشتر به [[{{ns:project}}:راهنما|صفحه راهنما]] برین).
 ایر اشتباهی ایچو اویدین دکمه «برگشت» مرورگرتو را بزنین.',
-'noarticletext'          => ' الان ای صفحه متنی نداره، ایسا ترین [[Special:Search/{{PAGENAME}}عنوان ای صفحه را در صفحه‌های دیگر جستجو کنین]] یا [{{fullurl:{{FULLPAGENAME}}|action=edit}} ای صفحه را اصلاح کنین].',
-'previewnote'            => "'''ای فقط یه پیش نمایشه;
+'noarticletext'              => ' الان ای صفحه متنی نداره، ایسا ترین [[Special:Search/{{PAGENAME}}عنوان ای صفحه را در صفحه‌های دیگر جستجو کنین]] یا [{{fullurl:{{FULLPAGENAME}}|action=edit}} ای صفحه را اصلاح کنین].',
+'previewnote'                => "'''ای فقط یه پیش نمایشه;
 تغییراتی که ایسا دادین هنی ضبط نوابیده!'''",
-'editing'                => 'درحال اصلاح $1',
-'editingsection'         => 'درحال اصلاح $1 (قسمت)',
-'copyrightwarning'       => "لطفاً دقت کنین که درنظر گریده ابوه که همه شراکتهای ایسا  {{SITENAME}} تحت «$2» منتشر ابون ). 
+'editing'                    => 'درحال اصلاح $1',
+'editingsection'             => 'درحال اصلاح $1 (قسمت)',
+'copyrightwarning'           => "لطفاً دقت کنین که درنظر گریده ابوه که همه شراکتهای ایسا  {{SITENAME}} تحت «$2» منتشر ابون ).
 
 
 (سی دیدن  جزئیات بیشتر به $1 برین
 
 ایر نه خوین نوشته‌هاتو بی‌رحمانه اصلاح بوه و به دلخواه ارسال بوه، ایچو نفرستن.<br />
 درضمن ایسادارین به ایما قول ادین که خودتو یونه نوشتین یا هونه زه یک منبع آزاد با مالکیت عمومی یا مثل هو ورداشتین. '''کارهای دارای کارهای دارای حق کپی رایت را بی‌اجازه نفرستین!'''',",
-'longpagewarning'        => "'''هشدار: ای صفحه $1 کیلوبایت طول داره؛
-بعضی زه مرورگرها ممکنه با اصلاح صفحات نزدیک به ۳۲ کیلوبایت یا طولانی‌تر زه آن مشکلاتی داشته بون.
-لطفاً درمورد خرد کردن ای صفحه به قسمت‌های کوچکتر فکر کنین.'''",
-'templatesused'          => 'قالبهای استفاده شده من ای صفحه:',
-'templatesusedpreview'   => 'قالبها  یا الگوهای استفاده وابیده در ای پیش نمایش:',
-'template-protected'     => '(تحت حمایت)',
-'template-semiprotected' => '(نیمه حمایت وابیده)',
-'nocreatetext'           => '{{SITENAME}}قابلیت درست کردن صفحات تازه را محدود کرده‌. ترین برگردین و صفحه‌ موجود را اصلاح کنین یا اینکه  [[Special:UserLogin|به سیستم داخل بوین یا حساب کاربری درست کنین]].',
-'recreate-deleted-warn'  => "'''هشدار: ایسا در حال درست کردن دوباره صفحه‌ای هدین که قبلاً حذف وابیده '''در نظر داشته بوین که ادامه اصلاح ای صفحه کار درستی هده یا نه. نمایه حذف مربوط به ای صفحه سی راحتی کار در ادامه اویده",
+'templatesused'              => 'قالبهای استفاده شده من ای صفحه:',
+'templatesusedpreview'       => 'قالبها  یا الگوهای استفاده وابیده در ای پیش نمایش:',
+'template-protected'         => '(تحت حمایت)',
+'template-semiprotected'     => '(نیمه حمایت وابیده)',
+'nocreatetext'               => '{{SITENAME}}قابلیت درست کردن صفحات تازه را محدود کرده‌. ترین برگردین و صفحه‌ موجود را اصلاح کنین یا اینکه  [[Special:UserLogin|به سیستم داخل بوین یا حساب کاربری درست کنین]].',
+'recreate-moveddeleted-warn' => "'''هشدار: ایسا در حال درست کردن دوباره صفحه‌ای هدین که قبلاً حذف وابیده '''در نظر داشته بوین که ادامه اصلاح ای صفحه کار درستی هده یا نه. نمایه حذف مربوط به ای صفحه سی راحتی کار در ادامه اویده",
 
 # History pages
 'viewpagelogs'        => 'نشودادن نمایه ها سی ای صفحه',
 'currentrev'          => 'نسخه جاری',
 'revisionasof'        => 'اصلاح $1',
-'revision-info'       => 'یه نسخه اصلاح شده درتاریخ  $1 بوسیله $2', # Additionally available: $3: revision id
+'revision-info'       => 'یه نسخه اصلاح شده درتاریخ  $1 بوسیله $2',
 'previousrevision'    => '← اصلاح قبلی',
 'nextrevision'        => 'نسخه بعدی →',
 'currentrevisionlink' => 'نسخه جاری',
@@ -390,7 +383,7 @@ $1',
 'histlast'            => 'تازه ترین',
 
 # Revision feed
-'history-feed-item-nocomment' => '$1 در $2', # user at time
+'history-feed-item-nocomment' => '$1 در $2',
 
 # Diffs
 'history-title'           => 'گزارش تاریخی نسخه زه "$1"',
@@ -401,17 +394,17 @@ $1',
 'diff-multi'              => '({{PLURAL:$1|یه اصلاح میانی|$1 اصلاحات میانی}} نشو داده نوابیده.)',
 
 # Search results
-'noexactmatch'   => "'''صفحه ای باای عنوان نه  \"\$1\".'''
-ایسا ترین [[:\$1| ای صفحه را ایجاد کنین]].",
-'prevn'          => 'قبلی $1',
-'nextn'          => 'بعدی $1',
-'viewprevnext'   => 'مشاهده ($1) ($2) ($3)',
+'prevn'          => 'قبلی {{PLURAL:$1|$1}}',
+'nextn'          => 'بعدی {{PLURAL:$1|$1}}',
+'viewprevnext'   => 'مشاهده ($1 {{int:pipe-separator}} $2) ($3)',
 'searchhelp-url' => 'Help:محتوا',
 'powersearch'    => 'جستجوی کاملتر',
 
 # Preferences page
-'preferences'   => 'اولویتها',
-'mypreferences' => 'اولویتهای مو',
+'preferences'         => 'اولویتها',
+'mypreferences'       => 'اولویتهای مو',
+'yourrealname'        => 'نام واقعی:',
+'prefs-help-realname' => 'ذکر نام واقعی اختیاریه ایر تصمیم به گدن بگیرین هنگام ارجاع به آثارتو و انتساب هونو به ایسا زه نام واقعیتو استفاده ابوه',
 
 'grouppage-sysop' => '{{ns:project}}:مدیران',
 
@@ -442,6 +435,8 @@ $1',
 
 # Recent changes linked
 'recentchangeslinked'          => 'تغییرات مرتبط',
+'recentchangeslinked-feed'     => 'تغییرات مرتبط',
+'recentchangeslinked-toolbox'  => 'تغییرات مرتبط',
 'recentchangeslinked-title'    => 'تغییرهای مرتبط با $1',
 'recentchangeslinked-noresult' => 'در دوره زمانی داده‌شده تغییری در صفحه‌های لینک داده رخ نداده‌',
 'recentchangeslinked-summary'  => " ای صفحه خاص تغییرات اخیر در صفحه‌های لینک داده شده به این صفحه را نشو اده.
@@ -457,6 +452,7 @@ $1',
 'listfiles' => 'لیست فایل',
 
 # File description page
+'file-anchor-link'          => 'فایل',
 'filehist'                  => 'گزارش تاریخی فایل',
 'filehist-help'             => 'رو تاریخ‌ها کلیک کنید تا نسخه مرتبط را ببینین.',
 'filehist-current'          => 'جاری',
@@ -468,9 +464,7 @@ $1',
 'imagelinks'                => 'لینکها',
 'linkstoimage'              => 'ذیل الذکر {{PLURAL:$1|لینکهای صفحه|$1 لینک صفحات}} به ای فایل:',
 'nolinkstoimage'            => 'هیچ صفحه ای نه که لینک وابیده بوه به ای فایل',
-'sharedupload'              => 'ای فایل یک آپلود اشتراکی هده و ممکنه زه طریق  پروژه‌های دیگه  هم قابل دسترسی بوه', # $1 is the repo name, $2 is shareduploadwiki(-desc)
-'noimage'                   => 'هیچ فایلی با ای نام موجود نه اما ترین $1.',
-'noimage-linktext'          => 'آپلود کنین',
+'sharedupload'              => 'ای فایل یک آپلود اشتراکی هده و ممکنه زه طریق  پروژه‌های دیگه  هم قابل دسترسی بوه',
 'uploadnewversion-linktext' => 'آپلود کردن یه نسخه تازه زه ای فایل',
 
 # MIME search
@@ -542,7 +536,7 @@ $1',
 
 # Special:AllPages
 'allpages'       => 'همه صفحات',
-'alphaindexline' => '$1 به 
+'alphaindexline' => '$1 به
 $2',
 'nextpage'       => 'صفحه بعدی ($1)',
 'prevpage'       => 'صفحه قبلی($1)',
@@ -560,14 +554,11 @@ $2',
 # Watchlist
 'watchlist'         => 'لیست پیگیریهای مو',
 'mywatchlist'       => 'لیست پیگیریهای مو',
-'watchlistfor'      => "(سی '''$1''')",
-'addedwatch'        => 'اضاف وابید به لیست پیگیری',
-'addedwatchtext'    => "صفحه «<nowiki>$1</nowiki>» به [[Special:Watchlist|لیست پی‌گیری‌های ]] ایسا   
+'addedwatchtext'    => "صفحه «<nowiki>$1</nowiki>» به [[Special:Watchlist|لیست پی‌گیری‌های ]] ایسا
 اضاف وابید.
 تغییرات این صفحه و صفحه صحبت مر بوطه اش در آینده ایچو لیست ابوه. به‌علاوه، ای صفحه، سی واضح‌تر دیده وابیدن در [[Special:RecentChanges|فهرست تغییرات اخیر]] به شکل <b>سیاه</b> ایا.
 
 ایر بعدا خواستین ای  صفحه زه لیست پی‌گیریهاتو ورداشته بوه، رو «'''عدم پی‌گیری'''» در بالای صفحه کلیک کنین.",
-'removedwatch'      => 'زه لیست پیگیری حذف وابید',
 'removedwatchtext'  => 'آن صفحه"[[:$1]]" جابجا وابیده زه[[Special:لیست پیگیری|لیست پیگیری ایسا]].',
 'watch'             => 'پی‌گیری',
 'watchthispage'     => 'پیگیری ای صفحه',
@@ -585,9 +576,8 @@ $2',
 'confirmdeletetext'     => 'ایسا اخوین یه صفحه بلند با همه گزارش تاریخی هونه حذف کنین.
 لطفا کانفیرم یا تائید کنین که تمایل وقصد ای کار را دارین, وایسا دوین یا می دانید نتایج وآثار ای کار را, و ایسا انجام ادین ای کار را مطابق با [[{{MediaWiki:Policy-url}}|سیاست‌ها]].',
 'actioncomplete'        => 'عمل  مربوطه راکامل کن',
-'deletedtext'           => '"<nowiki>$1</nowiki>" حذف وابیده.
+'deletedtext'           => '"$1" حذف وابیده.
 بوین $2 سی ثبت حذف آخر.',
-'deletedarticle'        => 'حذف وابید "[[$1]]"',
 'dellogpage'            => 'نمایه _ حذف',
 'deletecomment'         => 'دلیل:',
 'deleteotherreason'     => 'دیه/دلیل اضافی:',
@@ -603,13 +593,12 @@ $2',
 'protectexpiry'               => 'سپری وابیده ها:',
 'protect_expiry_invalid'      => 'با سپری وابیدن وقت غیر معتبره.',
 'protect_expiry_old'          => 'سپری وابیدن وقت مربوط به گذشته.',
-'protect-unchain'             => 'واز کردن جابجایی با اجازه گرئدن',
-'protect-text'                => "ایسا ممکنه بوینین وتغییر بدین سطح حمایت زه ای صفحه'''<nowiki>$1</nowiki>'''.",
+'protect-text'                => "ایسا ممکنه بوینین وتغییر بدین سطح حمایت زه ای صفحه'''$1'''.",
 'protect-locked-access'       => "حساب کاربری ایسا اجازه تغییر سطح حمایت ای صفحه را نداره.
 ای چونه تنظیمات جاری سی آن صفحه '''$1''':",
 'protect-cascadeon'           => 'ای صفحه  در حال حاضر حفاظت وحمایت وابیده چون که در {{PLURAL:$1|صفحه|صفحات}}
 زیر که گزینه حفاظت وحمایت موجی {{PLURAL:$1|آن|آن‌ها}} فعال هده ،
-ایسا ترین سطح حفاظت ای صفحه را تغییر بدین اما ای کارنتره تاثیری رو 
+ایسا ترین سطح حفاظت ای صفحه را تغییر بدین اما ای کارنتره تاثیری رو
 حفاظت وحمایت موجی صفحه داشته بوه.',
 'protect-default'             => '(پیش فرض)',
 'protect-fallback'            => 'درخواست"$1" اجازه',
@@ -619,7 +608,7 @@ $2',
 'protect-expiring'            => 'سپری وابیده $1 (UTC)',
 'protect-cascade'             => 'حمایت صفحات دربرگیرنده در ای صفحه (cascading protection)',
 'protect-cantedit'            => 'ایسا نترین تغییر بدین سطوح حمایتی ای صفحه را, زیرا ایسا اجازه اصلاح آن را ندارین.',
-'protect-expiry-options'      => '۲ ساعت:2 hours,۱ روز:1 day,۳ روز:3 days,۱ هفته:1 week,۲ هفته:2 weeks,۱ ماه:1 month,۳ ماه:3 months,۶ ماه:6 months,۱ سال:1 year,بی‌پایان:infinite', # display1:time1,display2:time2,...
+'protect-expiry-options'      => '۱ ساعت:1 hour,۱ روز:1 day,۱ هفته:1 week,۲ هفته:2 weeks,۱ ماه:1 month,۳ ماه:3 months,۶ ماه:6 months,۱ سال:1 year,بی‌نهایت:infinite',
 'restriction-type'            => 'اجازه:',
 'restriction-level'           => 'سطح محدودیت:',
 
@@ -641,6 +630,7 @@ $2',
 
 'sp-contributions-newbies-sub' => 'سی حسابهای کاربری تازه',
 'sp-contributions-blocklog'    => 'نمایه بسته وابیده ها',
+'sp-contributions-talk'        => 'صحبت',
 
 # What links here
 'whatlinkshere'       => 'لینک های ای صفحه',
@@ -655,7 +645,7 @@ $2',
 
 # Block/unblock
 'blockip'       => 'بستن کاربر',
-'ipboptions'    => '۲ ساعت:2 hours,۱ روز:1 day,۳ روز:3 days,۱ هفته:1 week,۲ هفته:2 weeks,۱ ماه:1 month,۳ ماه:3 months,۶ ماه:6 months,۱ سال:1 year,بی‌پایان:infinite', # display1:time1,display2:time2,...
+'ipboptions'    => '۲ ساعت:2 hours,۱ روز:1 day,۳ روز:3 days,۱ هفته:1 week,۲ هفته:2 weeks,۱ ماه:1 month,۳ ماه:3 months,۶ ماه:6 months,۱ سال:1 year,بی‌نهایت:infinite',
 'ipblocklist'   => 'آدرسهای  آی پی وکاربران بسته وابیدند',
 'blocklink'     => 'بسته بوه !',
 'unblocklink'   => 'باز بوه',
@@ -692,14 +682,13 @@ $2',
 'move-watch'       => 'پیگیری ای صفحه',
 'movepagebtn'      => 'جابجایی صفحه',
 'pagemovedsub'     => 'جابجایی با بخت وتوفیق انجام وابید',
-'movepage-moved'   => '\'\'\'"$1" جابجا وابیده به "$2"\'\'\'', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
+'movepage-moved'   => '\'\'\'"$1" جابجا وابیده به "$2"\'\'\'',
 'articleexists'    => 'یه صفحه زه ای  نوم تقریبا موجوده, یا نومی که ایسا انتخاب کردین غیر  معتبره
 لطفا نوم دیه انتخاب کنین.',
-'talkexists'       => "'''آن صفحه خوس با بخت وتوفیق جابجا وابید, ولی صفحه صحبت نتره جابجا بوه چونکه یکی تقریبا موجوده درعنوان تازه 
+'talkexists'       => "'''آن صفحه خوس با بخت وتوفیق جابجا وابید, ولی صفحه صحبت نتره جابجا بوه چونکه یکی تقریبا موجوده درعنوان تازه
 لطفا به صورت دستی آنها را ترکیب کنین.'''",
 'movedto'          => 'جابجا وابید به',
 'movetalk'         => 'جابجایی صفحه صحبت مربوطه',
-'1movedto2'        => '[[$1]] جابجا وابید به[[$2]]',
 'movelogpage'      => 'نمایه جابجایی',
 'movereason'       => 'دلیل:',
 'revertmove'       => 'واگردانی',
@@ -776,11 +765,10 @@ $2',
 'nextdiff'     => 'تفاوت بعدی→',
 
 # Media information
-'file-info-size'       => '($1 × $2 پیکسل, اندازه فایل: $3, MIME نوع: $4)',
-'file-nohires'         => '<small>قابلیت تفکیک بالاتری در دسترس نه.</small>',
-'svg-long-desc'        => '(SVG فایل, تقریبا$1 × $2 پیکسل, اندازه فایل: $3)',
-'show-big-image'       => 'تصویر با قابلیت تفکیک کامل',
-'show-big-image-thumb' => '<کوچیک>اندازه پیش نمایش: $1 × $2 پیکسلها</کوچیک>',
+'file-info-size' => '$1 × $2 پیکسل, اندازه فایل: $3, MIME نوع: $4',
+'file-nohires'   => 'قابلیت تفکیک بالاتری در دسترس نه.',
+'svg-long-desc'  => 'SVG فایل, تقریبا$1 × $2 پیکسل, اندازه فایل: $3',
+'show-big-image' => 'تصویر با قابلیت تفکیک کامل',
 
 # Special:NewFiles
 'newimages' => 'گالری فایلهای تازه',
@@ -788,7 +776,7 @@ $2',
 # Bad image list
 'bad_image_list' => 'اطلاعات را وا به ای شکل وارد کنین:
 
-فقط سطرهایی که با * آغاز ابون در نظر گریده ابون. اولین لینک در هر سطر، باید لینکی به یک تصویر بد باشد. 
+فقط سطرهایی که با * آغاز ابون در نظر گریده ابون. اولین لینک در هر سطر، باید لینکی به یک تصویر بد باشد.
 لینکهای بعدی در همان سطر، به عنوان موارد استثنا در نظر گریده ابون',
 
 # Metadata
@@ -804,11 +792,17 @@ $2',
 * exposuretime
 * fnumber
 * isospeedratings
-* focallength', # Do not translate list items
+* focallength
+* artist
+* copyright
+* imagedescription
+* gpslatitude
+* gpslongitude
+* gpsaltitude',
 
 # External editor support
 'edit-externally'      => 'اصلاح ای صفحه با استفاده زه یه ویرایشگر خارجی',
-'edit-externally-help' => ' سی اطلاعات بیشتر [http://www.mediawiki.org/wiki/Manual:External_editors راهنمایی‌های تنظیمات] اصلاح کننده خارجی را بوینین.',
+'edit-externally-help' => ' سی اطلاعات بیشتر [//www.mediawiki.org/wiki/Manual:External_editors راهنمایی‌های تنظیمات] اصلاح کننده خارجی را بوینین.',
 
 # 'all' in various places, this might be different for inflected languages
 'watchlistall2' => 'همه',
@@ -821,7 +815,7 @@ $2',
 'watchlisttools-raw'  => 'اصلاح لیست خام پی‌گیری‌ها',
 
 # Special:Version
-'version' => 'ترجمه یا تفسیر', # Not used as normal message but as header for the special page itself
+'version' => 'ترجمه یا تفسیر',
 
 # Special:SpecialPages
 'specialpages' => 'صفحات ویژه',
