@@ -305,14 +305,13 @@ L'administrateur qui l'a barrée a donné cette explication: $1",
 'cannotdelete'         => "Impossible d'ôter la page ou le dossier choisi.  (Il est possible que quèqu'une d'autre l'a déjà ôté.)",
 'badtitle'             => 'Mauvais titre',
 'badtitletext'         => 'Le titre que vous avez demandé était pas bon, vide, ou y avait un mauvais titre entre-langue ou entre-wiki.  Ça pourrait avoir des caractères qui pouvont pas être usés dans les titres.',
-'perfcached'           => 'Cette information est en cache et pourrait pas être courante.',
-'perfcachedts'         => 'Cette information est en cache et le dernier changement a été fait $1.',
+'perfcached'           => 'Cette information est en cache et pourrait pas être courante. A maximum of {{PLURAL:$1|one result is|$1 results are}} available in the cache.',
+'perfcachedts'         => 'Cette information est en cache et le dernier changement a été fait $1. A maximum of {{PLURAL:$4|one result is|$4 results are}} available in the cache.',
 'querypage-no-updates' => "À présent, les renouvelages pour cette page sont barrés.  L'information ici va pas être renouvelée t'à l'heure.",
 'wrong_wfQuery_params' => 'Informaton incorrecte sus le wfQuery()<br />
 Fonction: $1<br />
 Demande: $2',
 'viewsource'           => 'Voir la source',
-'viewsourcefor'        => 'pour $1',
 'protectedpagetext'    => 'Cette page est barrée pour empêcher des changements.',
 'viewsourcetext'       => 'Vous pouvez voir et copier la source de cette page:',
 'protectedinterface'   => "Cette page crée le texte de l'interface pour le software, et est barrée pour empêcher l'abus.",
@@ -455,9 +454,6 @@ Vous pouvez contacter $1 ou un autre [[{{MediaWiki:Grouppage-sysop}}|administrat
 Notez donc que vous pouvez pas user la fonction 'envoyer un e-mail à cet useur' hormis que vous avez une adresse e-mail confirmée dans votre [[Special:Preferences|réglage de compte]] et vous avez la permission de l'user.
 
 Votre numéro de blocage est #$5.  Mettez donc cette information dans toutes vos demandes.",
-'blockedoriginalsource'            => "La source de '''$1''' est montrée en bas.",
-'blockededitsource'                => "Le texte de '''votres changements''' à '''$1''' est montré en bas.",
-'whitelistedittitle'               => 'Il faut connecter pour faire des changements.',
 'whitelistedittext'                => 'Il faut $1 pour faire des changements.',
 'confirmedittext'                  => "Il faut confirmer votre adresse e-mail pour faire des changements.  Mettez et confirmez un adresse e-mail dans votre [[Special:Preferences|réglage de compte]], s'il vous plaît.",
 'nosuchsectiontitle'               => 'Aucune section pareille',
@@ -592,8 +588,6 @@ Des autres administrateurs sus ce wiki ont la permission de voir et de rétablir
 'revdelete-unsuppress'        => 'Enlever les restrictions des versions rétablies',
 'revdelete-log'               => 'Raison:',
 'revdelete-submit'            => 'Appliquer à la version choisie',
-'revdelete-logentry'          => 'La visibilité pour la version a été changée pour [[$1]]',
-'logdelete-logentry'          => "La visibilité de l'événement a été changée pour [[$1]]",
 'revdelete-success'           => "'''Vous avez bien changé la visibilité des versions.'''",
 'logdelete-success'           => "'''Vous avez bien changé la visibilité des événements.'''",
 
@@ -680,9 +674,6 @@ Des autres administrateurs sus ce wiki ont la permission de voir et de rétablir
 'contribslink'             => 'changes',
 'block-log-flags-nocreate' => 'création de compte interdite',
 
-# Move page
-'1movedto2_redir' => 'déplacé [[$1]] vers [[$2]] en écrasant sa redirection',
-
 # Tooltip help for the actions
 'tooltip-pt-login'        => 'Vous êtes encouragé{{GENDER:||e|(e)}} à vous identifier mais ce n’est pas obligatoire.',
 'tooltip-ca-talk'         => 'Discussion de cette page de contenu',
