@@ -8,7 +8,9 @@
  * @file
  *
  * @author Jocke Pirat
+ * @author Michawiki
  * @author Node ue
+ * @author Sajasazi (on got.wikipedia.org)
  * @author Zylbath
  */
 
@@ -158,6 +160,7 @@ $messages = array(
 'newmessagesdifflink' => '𐍃𐍀𐌴𐌳𐌿𐌼𐌹𐍃𐍄𐍃 𐌼𐌰𐌹𐌳𐌴𐌹𐌽𐍃',
 'editsection'         => '𐌼𐌰𐌹𐌳𐌾𐌰𐌽',
 'editold'             => '𐌼𐌰𐌹𐌳𐌾𐌰𐌽',
+'editlink'            => 'máidjan',
 'editsectionhint'     => '𐌼𐌰𐌹𐌳𐌾𐌰𐌽 𐌰𐍆 𐍆𐌴𐍂𐌰: $1',
 'toc'                 => '𐌹𐌽𐌽𐌰𐌽𐌰',
 'showtoc'             => '𐌰𐌿𐌲𐌾𐌰',
@@ -176,8 +179,7 @@ $messages = array(
 'nstab-category' => '𐌺𐌿𐌽𐌾𐌰',
 
 # General errors
-'viewsource'    => '𐍃𐌰𐌹𐍈𐌰 𐌹𐌽𐌽𐌰𐌽𐌰',
-'viewsourcefor' => 'fáur $1',
+'viewsource' => '𐍃𐌰𐌹𐍈𐌰 𐌹𐌽𐌽𐌰𐌽𐌰',
 
 # Login and logout pages
 'yourname'                => '𐌽𐌹𐌿𐍄𐌰𐌽𐌳𐌹𐍃𐌽𐌰𐌼𐍉:',
@@ -387,7 +389,6 @@ $messages = array(
 'deletepage'            => '𐍄𐌰𐌹𐍂𐌰 𐍃𐌴𐌹𐌳𐍉',
 'delete-legend'         => '𐍄𐌰𐌹𐍂𐌰𐌽',
 'actioncomplete'        => '𐍅𐌰𐍃𐌿𐌷 𐌹𐍄𐌰 𐌲𐌰𐌿𐍃𐍄𐌹𐌿𐌷𐌰𐌽',
-'deletedarticle'        => '𐍄𐌰𐌹𐍂𐌹𐌸 "[[$1]]"',
 'dellogpage'            => '𐍄𐌰𐌹𐍂𐌰 𐌰𐌹𐍂𐍅𐌱𐍉𐌺𐌰',
 'deleteotherreason'     => '𐌰𐌽𐌸𐌰𐍂/𐌼𐌰𐌹𐍃 𐌼𐌹𐍄𐍉𐌽𐍃:',
 'deletereasonotherlist' => '𐌰𐌽𐌸𐌰𐍂 𐌼𐌹𐍄𐍉𐌽𐍃',
@@ -449,16 +450,14 @@ $messages = array(
 'blocklogentry'      => '𐌰𐍆𐌳𐍂𐌰𐌿𐍃𐌹𐌸 [[$1]] 𐍆𐌰𐌿𐍂 $2 $3',
 
 # Move page
-'movearticle'     => '𐍃𐌺𐌹𐌿𐌱𐌰 𐍃𐌴𐌹𐌳𐍉:',
-'newtitle'        => '𐌳𐌿 𐌽𐌹𐌿𐌾𐌹𐍃 𐌽𐌰𐌼𐍉𐍃:',
-'move-watch'      => '𐍅𐌹𐍄𐌰𐌽 𐍃𐍉 𐍃𐌴𐌹𐌳𐍉',
-'movepagebtn'     => '𐍃𐌺𐌹𐌿𐌱𐌰 𐍃𐌴𐌹𐌳𐍉',
-'movedto'         => 'skiubiþ du',
-'1movedto2'       => '[[$1]] 𐍃𐌺𐌹𐌿𐌱𐌹𐌸 𐌳𐌿 [[$2]]',
-'1movedto2_redir' => '[[$1]] 𐍃𐌺𐌹𐌿𐌱𐌹𐌸 𐌳𐌿 [[$2]] 𐌿𐍆𐌰𐍂 𐍄𐌰𐌹𐌺𐌾𐌰𐌽𐌱𐌰𐌽𐌳𐌹',
-'movelogpage'     => 'Log af skiubans',
-'movereason'      => '𐍆𐌰𐌹𐍂𐌹𐌽𐌰:',
-'revertmove'      => 'ráidjan',
+'movearticle' => '𐍃𐌺𐌹𐌿𐌱𐌰 𐍃𐌴𐌹𐌳𐍉:',
+'newtitle'    => '𐌳𐌿 𐌽𐌹𐌿𐌾𐌹𐍃 𐌽𐌰𐌼𐍉𐍃:',
+'move-watch'  => '𐍅𐌹𐍄𐌰𐌽 𐍃𐍉 𐍃𐌴𐌹𐌳𐍉',
+'movepagebtn' => '𐍃𐌺𐌹𐌿𐌱𐌰 𐍃𐌴𐌹𐌳𐍉',
+'movedto'     => 'skiubiþ du',
+'movelogpage' => 'Log af skiubans',
+'movereason'  => '𐍆𐌰𐌹𐍂𐌹𐌽𐌰:',
+'revertmove'  => 'ráidjan',
 
 # Thumbnails
 'thumbnail-more' => 'Biáuknan',
