@@ -28,8 +28,7 @@ $messages = array(
 'tog-editsection'             => 'Redigær åfsnet ve hjælp åf [redigær]-henvesnenger',
 'tog-editsectiononrightclick' => 'Redigær åfsnet ve at klikke på deres titler (JavaScript)',
 'tog-showtoc'                 => 'Ves endholtsførtegnelse (i artikler ve mære end tre åfsnet)',
-'tog-rememberpassword'        => 'Husk adgengskode til næste besøĝ frå denne kompjuter',
-'tog-editwidth'               => 'Redigærengsboksen har fuld bredde',
+'tog-rememberpassword'        => 'Husk adgengskode til næste besøĝ frå denne kompjuter (for a maximum of $1 {{PLURAL:$1|day|days}})',
 'tog-watchcreations'          => 'Tilføj sider a åpretter til miin åvervågnengsliste',
 'tog-watchdefault'            => 'Tilføj sider a redigærer til miin åvervågnengsliste',
 'tog-watchmoves'              => 'Tilføj sider a flytter til miin åvervågnengsliste',
@@ -119,16 +118,21 @@ $messages = array(
 'category-media-header'    => "Medier i'n klynge „$1“",
 'category-empty'           => "''Denne klynge endeholter før øjeblikket æ verke sider æller medie-gøret.''",
 'hidden-categories'        => '{{PLURAL:$1|Skjult klynge|Skjulte klynger}}',
-'hidden-category-category' => 'Skjulte klynger', # Name of the category where hidden categories will be listed
+'hidden-category-category' => 'Skjulte klynger',
 'listingcontinuesabbrev'   => 'førtgøte',
 
-'mainpagetext'      => "'''MediaWiki er nu installeret.'''",
-'mainpagedocfooter' => "Se vores engelskspråĝede [http://meta.wikimedia.org/wiki/MediaWiki_localisation dokumentåsje tilpasnenge'm åf æ brugergrænseflade] og [http://meta.wikimedia.org/wiki/MediaWiki_User%27s_Guide æ brugervejlednenge] før åplysnenger åpsætnenge'm og anvendelse.",
+'about'         => 'Åm',
+'article'       => 'Ertikel',
+'newwindow'     => '(åbner i et nyt vendue)',
+'cancel'        => 'Åfbryd',
+'moredotdotdot' => 'Mære...',
+'mypage'        => 'Miin side',
+'mytalk'        => 'Min diskusje',
+'anontalk'      => 'Diskusjeside før denne IP-adresse',
+'navigation'    => 'Navigasje',
+'and'           => '&#32;og',
 
-'about'          => 'Åm',
-'article'        => 'Ertikel',
-'newwindow'      => '(åbner i et nyt vendue)',
-'cancel'         => 'Åfbryd',
+# Cologne Blue skin
 'qbfind'         => 'Søĝ',
 'qbbrowse'       => 'Gennemse',
 'qbedit'         => 'Redigær',
@@ -136,15 +140,8 @@ $messages = array(
 'qbpageinfo'     => "Informåsje side'm",
 'qbmyoptions'    => 'Miine endstellenger',
 'qbspecialpages' => 'Sonst sider',
-'moredotdotdot'  => 'Mære...',
-'mypage'         => 'Miin side',
-'mytalk'         => 'Min diskusje',
-'anontalk'       => 'Diskusjeside før denne IP-adresse',
-'navigation'     => 'Navigasje',
-'and'            => '&#32;og',
-
-# Metadata in edit box
-'metadata_help' => 'Metadata:',
+'faq'            => 'VSF',
+'faqpage'        => 'Project:Vøl stellen fråĝer (VSF)',
 
 'errorpagetitle'    => 'Fejl',
 'returnto'          => 'Tilbage til $1.',
@@ -157,7 +154,6 @@ $messages = array(
 'history'           => 'Skigt',
 'history_short'     => 'Skigte',
 'updatedmarker'     => '(ændret)',
-'info_short'        => 'Informåsje',
 'printableversion'  => 'Utskreftsvelig utgåf',
 'permalink'         => 'Permanent henvesnenge',
 'print'             => 'Udskrev',
@@ -194,7 +190,7 @@ $messages = array(
 'otherlanguages'    => 'Andre språĝ',
 'redirectedfrom'    => '(Åmstyret frå $1)',
 'redirectpagesub'   => 'Åmstyrenge',
-'lastmodifiedat'    => 'Denne side blev senest ændret den $2, $1.', # $1 date, $2 time
+'lastmodifiedat'    => 'Denne side blev senest ændret den $2, $1.',
 'viewcount'         => 'Æ side er vest i alt $1 {{PLURAL:$1|geng|genger}}.',
 'protectedpage'     => 'Beskyttet side',
 'jumpto'            => 'Skeft til:',
@@ -205,7 +201,6 @@ $messages = array(
 'aboutsite'            => "{{SITENAME}}'m",
 'aboutpage'            => 'Project:Åm',
 'copyright'            => 'Endholtet er udgævet under $1.',
-'copyrightpagename'    => '{{SITENAME}} åphavsret',
 'copyrightpage'        => '{{ns:project}}:Åphavsret',
 'currentevents'        => 'Nænte begevenheder',
 'currentevents-url'    => 'Project:Nænte begevenheder',
@@ -213,8 +208,6 @@ $messages = array(
 'disclaimerpage'       => 'Project:Huses førbeholt',
 'edithelp'             => 'Hjælp til redigærenge',
 'edithelppage'         => "Help:Vordan redigærer a'n side",
-'faq'                  => 'VSF',
-'faqpage'              => 'Project:Vøl stellen fråĝer (VSF)',
 'helppage'             => 'Help:Hjælpførside',
 'mainpage'             => 'Førsit',
 'mainpage-description' => 'Førsit',
@@ -279,17 +272,14 @@ $messages = array(
 'databaseerror'        => 'Databasefejl',
 'dberrortext'          => 'Der er åpstået en syntaksfejl i en databaseførespørgsel.
 Dette ken være på grund åf en ugyldeg førespørgsel,
-æller det ken betyde en fejl i\'n softwær. 
+æller det ken betyde en fejl i\'n softwær.
 Den seneste førsøĝte databaseførespørgsel var:
 <blockquote><tt>$1</tt></blockquote>
-frå\'n funksje "<tt>$2</tt>". 
+frå\'n funksje "<tt>$2</tt>".
 MySQL æ returnerede fejl "<tt>$3: $4</tt>".',
-'dberrortextcl'        => 'Der er åpstået en syntaksfejl i en databaseførespørgsel. 
-Den seneste førsøĝte databaseførespørgsel var: "$1" frå\'n funksje "$2". 
+'dberrortextcl'        => 'Der er åpstået en syntaksfejl i en databaseførespørgsel.
+Den seneste førsøĝte databaseførespørgsel var: "$1" frå\'n funksje "$2".
 MySQL æ returnerede fejl "$3: $4".',
-'noconnect'            => "Der er pråblæmer ve {{SITENAME}} han database, vi kan desværre ekke kåm i kontakt ve den før øjeblikket. Prøv ig'n senere. <br />$1",
-'nodb'                 => "Kan ekke vælge'n database $1",
-'cachederror'          => 'Det følgende er en gemt kopi åf den ønskede side, og er måske ekke helt åpdateret.',
 'laggedslavemode'      => 'Bemærk: Den veste side endholter mulegves ekke de nyeste ændrenger.',
 'readonly'             => 'Æ database er skrevebeskyttet',
 'enterlockreason'      => "Skrev en begrundelse før æ skrevebeskyttelse, ve samt en vurderenge åf, hvornår æ skrevebeskyttelse åphæves ig'n",
@@ -313,13 +303,12 @@ MySQL æ returnerede fejl "$3: $4".',
 Funksje: $1<br />
 Førespørgsel: $2',
 'viewsource'           => 'Ves æ kelde',
-'viewsourcefor'        => 'før $1',
 'viewsourcetext'       => "Du ken dog se og åfskreve'n keldekode til æ side:",
 
 # Login and logout pages
 'yourname'                => 'Dit brugernav',
 'yourpassword'            => 'Din adgangskode',
-'remembermypassword'      => 'Husk min adgangskode til næste gang.',
+'remembermypassword'      => 'Husk min adgangskode til næste gang (for a maximum of $1 {{PLURAL:$1|day|days}})',
 'login'                   => 'Loĝ på',
 'nav-login-createaccount' => 'Åpret æ konto æller loĝ på',
 'loginprompt'             => 'Du skal have cookies slået til før at kunne loĝge på {{SITENAME}}.',
@@ -331,13 +320,10 @@ Førespørgsel: $2',
 'createaccount'           => 'Åpret en ny konto',
 'gotaccount'              => "Du har ålerede en brugerkonto? '''$1'''.",
 'gotaccountlink'          => 'Loĝ på',
-'youremail'               => 'E-mail:',
-'yourrealname'            => 'Dit rigtege navn*',
-'prefs-help-realname'     => '* <strong>Dit rigtege navn</strong> (valgfrit): Hves du vælger at åplyse dit navn hvil dette bleve brugt til at tilskreve dig dit arbejde.',
 'loginsuccesstitle'       => 'Du er nu loĝget på',
 'loginsuccess'            => 'Du er nu loĝget på {{SITENAME}} søm "$1".',
 'nosuchuser'              => 'Der er ig\'n bruger ve navnet "$1". Kontrollér æ stavemåde ig\'n, æller brug æ formulår herunder til at åprette en ny brugerkonto.',
-'nosuchusershort'         => 'Der er ig\'n bruger ve navn "<nowiki>$1</nowiki>". Tjek din stavnenge.',
+'nosuchusershort'         => 'Der er ig\'n bruger ve navn "$1". Tjek din stavnenge.',
 'nouserspecified'         => 'Angæv venlegst et brugernavn.',
 'wrongpassword'           => "Den endtastede adgangskode var førkert. Prøv ig'n.",
 'wrongpasswordempty'      => "Du glemte at endtaste password. Prøv ig'n.",
@@ -349,7 +335,7 @@ har bedt at vi sender dig en ny adgangskode til at loĝge på {{SITENAME}} ($4)\
 Æ adgangskode før bruger "$2" er nu "$3".
 Du bør loĝge på nu og ændre din adgangskode.,
 
-Hves en anden har bestilt den nye adgangskode æller hves du er kåmet i tanke dit gamle password og ekke mære vil ændre det\'m, 
+Hves en anden har bestilt den nye adgangskode æller hves du er kåmet i tanke dit gamle password og ekke mære vil ændre det\'m,
 kenst du bare ignorere denne mail og førtsætte ve at bruge dit gamle password.',
 'noemail'                 => 'Der er ekke åplyst en e-mail-adresse før bruger "$1".',
 'passwordsent'            => 'En ny adgangskode er sendt til æ e-mail-adresse,
@@ -359,7 +345,7 @@ Du bør loĝge på og ændre din adgangskode straks æfter du harst modtaget æ
 
 Før en e-mail ken modtages åf andre brugere åf æ {{SITENAME}}-mailfunksje, skel æ adresse og dens tilhørsførholt til denne bruger bekræftes. Følg venlegst anvesnengerne i denne mail.',
 
-# Password reset dialog
+# Change password dialog
 'retypenew' => 'Gentag ny adgangskode',
 
 # Edit page toolbar
@@ -373,8 +359,6 @@ Før en e-mail ken modtages åf andre brugere åf æ {{SITENAME}}-mailfunksje, s
 'extlink_tip'     => 'Utsende henvesnenge (husk http:// førgøret)',
 'headline_sample' => 'Skrevselenger til åverskreft',
 'headline_tip'    => 'Skå 2 åverskreft',
-'math_sample'     => 'Endsæt åpstælsel her (LaTeX)',
-'math_tip'        => 'Matematisk åpstælsel (LaTeX)',
 'nowiki_sample'   => 'Endsæt skrevselenger her søm ekke skal redigær påke wikiskrevselenger',
 'nowiki_tip'      => 'Ekke wikiskrevselenger utse',
 'image_tip'       => 'Endlejret billet',
@@ -383,17 +367,17 @@ Før en e-mail ken modtages åf andre brugere åf æ {{SITENAME}}-mailfunksje, s
 'hr_tip'          => 'Plat lenje (brug den sparsåmt)',
 
 # Edit pages
-'summary'                => 'Beskrevelse:',
-'subject'                => 'Emne/åverskreft:',
-'minoredit'              => "Dette'r en mendre æller lile ændrenge.",
-'watchthis'              => 'Åvervåg denne ertikel',
-'savearticle'            => 'Gem side',
-'preview'                => 'Førhåndsvesnenge',
-'showpreview'            => 'Førhåndsvesnenge',
-'showdiff'               => 'Ves ændrenger',
-'anoneditwarning'        => "Du arbejder uden at være loĝget på. Estedet før brugernav veses så'n IP-adresse i'n hersenengerskigt.",
-'summary-preview'        => 'Førhåndsvesnenge åf beskrevelselejne:',
-'blockedtext'            => "'''Dit brugernav æller din IP-adresse er blevet blokeret.'''
+'summary'                    => 'Beskrevelse:',
+'subject'                    => 'Emne/åverskreft:',
+'minoredit'                  => "Dette'r en mendre æller lile ændrenge.",
+'watchthis'                  => 'Åvervåg denne ertikel',
+'savearticle'                => 'Gem side',
+'preview'                    => 'Førhåndsvesnenge',
+'showpreview'                => 'Førhåndsvesnenge',
+'showdiff'                   => 'Ves ændrenger',
+'anoneditwarning'            => "Du arbejder uden at være loĝget på. Estedet før brugernav veses så'n IP-adresse i'n hersenengerskigt.",
+'summary-preview'            => 'Førhåndsvesnenge åf beskrevelselejne:',
+'blockedtext'                => "'''Dit brugernav æller din IP-adresse er blevet blokeret.'''
 
 Æ blokerenge er lavet åf $1. Æ begrundelse er ''$2''.
 
@@ -404,36 +388,34 @@ Før en e-mail ken modtages åf andre brugere åf æ {{SITENAME}}-mailfunksje, s
 Du ken kåle $1 æller en åf de andre [[{{MediaWiki:Grouppage-sysop}}|administratårer]] før at diskutere æ blokerenge.
 Du ken ekke bruge æ funksje 'e-mail til denne bruger' vemendre der er ångevet en gyldig email-addresse i dine
 [[Special:Preferences|kontoendstellenger]]. Din nuværende IP-addresse er $3, og blokerengs-ID er #$5. Ångev venlegst en æller begge i åle henvendelser.",
-'newarticle'             => '(Ny)',
-'newarticletext'         => "'''{{SITENAME}} har endnu ekke nogen {{NAMESPACE}}-side ve nav {{PAGENAME}}.'''<br /> Du ken begynde en side ve at skreve i'n boks herunder. (se'n [[{{MediaWiki:Helppage}}|hjælp]] før yderligere åplysnenger).<br /> Æller du ken [[Special:Search/{{PAGENAME}}|søĝe æfter {{PAGENAME}} i {{SITENAME}}]].<br /> Ves det ekke var din meneng, så tryk på æ '''Tilbage'''- æller æ '''Back'''-knåp.",
-'noarticletext'          => "'''{{SITENAME}} har ekke nogen side ve prånt dette nav.''' 
-* Du ken '''[{{fullurl:{{FULLPAGENAME}}|action=edit}} starte æ side {{PAGENAME}}]''' 
-* Æller [[Special:Search/{{PAGENAME}}|søĝe æfter {{PAGENAME}}]] i andre ertikler 
----- 
+'newarticle'                 => '(Ny)',
+'newarticletext'             => "'''{{SITENAME}} har endnu ekke nogen {{NAMESPACE}}-side ve nav {{PAGENAME}}.'''<br /> Du ken begynde en side ve at skreve i'n boks herunder. (se'n [[{{MediaWiki:Helppage}}|hjælp]] før yderligere åplysnenger).<br /> Æller du ken [[Special:Search/{{PAGENAME}}|søĝe æfter {{PAGENAME}} i {{SITENAME}}]].<br /> Ves det ekke var din meneng, så tryk på æ '''Tilbage'''- æller æ '''Back'''-knåp.",
+'noarticletext'              => "'''{{SITENAME}} har ekke nogen side ve prånt dette nav.'''
+* Du ken '''[{{fullurl:{{FULLPAGENAME}}|action=edit}} starte æ side {{PAGENAME}}]'''
+* Æller [[Special:Search/{{PAGENAME}}|søĝe æfter {{PAGENAME}}]] i andre ertikler
+----
 * Ves du har åprettet denne ertikel endenfør de sedste få minutter, så ken de skyldes at der er ledt førsenkelse i'n åpdaterenge åf {{SITENAME}}s cache. Vent venligst og tjek igen senere'n ertikel'm dukker åp, enden du førsøĝer at åprette'n ertikel igen.",
-'previewnote'            => "'''Husk at dette er kun en førhåndsvesnenge, æ side er ekke gemt endnu!'''",
-'editing'                => 'Redigærer $1',
-'editingsection'         => 'Redigærer $1 (åfsnet)',
-'copyrightwarning'       => "'''Husk: åpskrev engen websider, søm ekke tilhører dig selv, brug engen åphavsretsligt beskyttede værker uden tilladelse frå'n ejer!'''<br />
+'previewnote'                => "'''Husk at dette er kun en førhåndsvesnenge, æ side er ekke gemt endnu!'''",
+'editing'                    => 'Redigærer $1',
+'editingsection'             => 'Redigærer $1 (åfsnet)',
+'copyrightwarning'           => "'''Husk: åpskrev engen websider, søm ekke tilhører dig selv, brug engen åphavsretsligt beskyttede værker uden tilladelse frå'n ejer!'''<br />
 Du lover os hermed, at du selv '''har skrevet skrevselenger''', at skrevselenger tilhører ålmenheden, er ('''åpværer hus'''), æller at æ '''åphavsrets-endehaver''' har gevet sen '''tilladelse'''. Ves denne skrevselenger ålerede er åfentliggkort andre steder, skrev det venligst på æ diskusjesside.
 <i>Bemærk venligst, at ål {{SITENAME}}-ertikler åtomatisk står under „$2“ (se $1 før lileskrevselenger). Ves du ekke vel, at dit arbejde her ændres og udbredes åf andre, så tryk ekke på „Gem“.</i>",
-'longpagewarning'        => "'''ADVARSEL: Denne side er $1 kilobyte stor; nogle browsere ken have pårblæmer ve at redigære sider der nærmer sig æller er større end 32 kb. 
-Åvervej æ side'm ken åpdeles i mendre dæle.'''",
-'templatesused'          => 'Skablåner der er brugt på denne side:',
-'templatesusedpreview'   => 'Følgende skablåner bruges åf denne ertikelførhåndsvesnenge:',
-'template-protected'     => '(skrevebeskyttet)',
-'template-semiprotected' => '(skrevebeskyttet før ekke ånmeldte og nye brugere)',
-'nocreatetext'           => "Æ'n åpdiin har begrænset åprettelse åf nye sider. Bestående sider ken ændres æller [[Special:UserLogin|loĝge på]].",
-'recreate-deleted-warn'  => "'''Advarsel: Du er ve at genskabe en tidligere slettet side.'''
- 
-Åvervej det'm er passende at genåprette'n side. De slettede hersenenger før 
+'templatesused'              => 'Skablåner der er brugt på denne side:',
+'templatesusedpreview'       => 'Følgende skablåner bruges åf denne ertikelførhåndsvesnenge:',
+'template-protected'         => '(skrevebeskyttet)',
+'template-semiprotected'     => '(skrevebeskyttet før ekke ånmeldte og nye brugere)',
+'nocreatetext'               => "Æ'n åpdiin har begrænset åprettelse åf nye sider. Bestående sider ken ændres æller [[Special:UserLogin|loĝge på]].",
+'recreate-moveddeleted-warn' => "'''Advarsel: Du er ve at genskabe en tidligere slettet side.'''
+
+Åvervej det'm er passende at genåprette'n side. De slettede hersenenger før
 denne side er vest nedenfør:",
 
 # History pages
 'viewpagelogs'        => 'Ves loglister før denne side',
 'currentrev'          => 'Nuværende hersenenge',
 'revisionasof'        => 'Hersenenger frå $1',
-'revision-info'       => 'Hersenenge frå $1 til $2', # Additionally available: $3: revision id
+'revision-info'       => 'Hersenenge frå $1 til $2',
 'previousrevision'    => '←Ældre hersenenge',
 'nextrevision'        => 'Nyere hersenenge→',
 'currentrevisionlink' => 'se nuværende hersenenge',
@@ -447,7 +429,7 @@ hersenenge, (førge) = førskel til den førge hersenenge, l = lile til mendre 
 'histlast'            => 'Nyeste',
 
 # Revision feed
-'history-feed-item-nocomment' => '$1 ve $2', # user at time
+'history-feed-item-nocomment' => '$1 ve $2',
 
 # Diffs
 'history-title'           => 'Hersengsskigte før "$1"',
@@ -458,18 +440,20 @@ hersenenge, (førge) = førskel til den førge hersenenge, l = lile til mendre 
 'diff-multi'              => '(Æ hersenengssammenlegnenge vetåger {{PLURAL:$1|en mellemleggende hersenenge|$1 mellemleggende hersenenger}}.)',
 
 # Search results
-'noexactmatch'   => "'''{{SITENAME}} har engen ertikel ve dette nav.''' Du ken [[:$1|åprette en ertikel ve dette nav]].",
-'prevn'          => 'førge $1',
-'nextn'          => 'nægste $1',
-'viewprevnext'   => 'Ves ($1) ($2) ($3)',
+'prevn'          => 'førge {{PLURAL:$1|$1}}',
+'nextn'          => 'nægste {{PLURAL:$1|$1}}',
+'viewprevnext'   => 'Ves ($1 {{int:pipe-separator}} $2) ($3)',
 'searchhelp-url' => 'Help:Hjælpførside',
 'searchall'      => 'ål',
 'powersearch'    => 'Søĝ',
 
 # Preferences page
-'preferences'   => 'Endstellenger',
-'mypreferences' => 'Endstellenger',
-'skin-preview'  => 'Førhåndsvesnenge',
+'preferences'         => 'Endstellenger',
+'mypreferences'       => 'Endstellenger',
+'skin-preview'        => 'Førhåndsvesnenge',
+'youremail'           => 'E-mail:',
+'yourrealname'        => 'Dit rigtege navn*',
+'prefs-help-realname' => '* <strong>Dit rigtege navn</strong> (valgfrit): Hves du vælger at åplyse dit navn hvil dette bleve brugt til at tilskreve dig dit arbejde.',
 
 'grouppage-sysop' => '{{ns:project}}:Administråtorer',
 
@@ -500,6 +484,8 @@ hersenenge, (førge) = førskel til den førge hersenenge, l = lile til mendre 
 
 # Recent changes linked
 'recentchangeslinked'          => 'Relaterede ændrenger',
+'recentchangeslinked-feed'     => 'Relaterede ændrenger',
+'recentchangeslinked-toolbox'  => 'Relaterede ændrenger',
 'recentchangeslinked-title'    => 'Ændrenger der vegånde til "$1"',
 'recentchangeslinked-noresult' => 'I det udvalgte tidsrum blev der ekke føretaget ændrenger på siderne der henveses til.',
 'recentchangeslinked-summary'  => "Denne sonstside beser de seneste ændrenger på de sider der henveses til. Sider på din åvervågnengsliste er vest ve '''fed''' skreft.",
@@ -514,6 +500,7 @@ hersenenge, (førge) = førskel til den førge hersenenge, l = lile til mendre 
 'listfiles' => 'Billetliste',
 
 # File description page
+'file-anchor-link'          => 'Billet',
 'filehist'                  => 'Billetskigt',
 'filehist-help'             => "Klik på'n dato/tid før at se den hersenenge åf gøret.",
 'filehist-current'          => 'nuværende',
@@ -525,9 +512,7 @@ hersenenge, (førge) = førskel til den førge hersenenge, l = lile til mendre 
 'imagelinks'                => 'Billethenvesnenger',
 'linkstoimage'              => 'De følgende sider henveser til dette billet:',
 'nolinkstoimage'            => 'Der er engen sider der henveser til dette billet.',
-'sharedupload'              => 'Denne gøret er en fælles læĝenge og ken bruges åf andre projekter.', # $1 is the repo name, $2 is shareduploadwiki(-desc)
-'noimage'                   => 'Der er engen gøret ve dette nav, du ken $1',
-'noimage-linktext'          => 'læĝge den åp',
+'sharedupload'              => 'Denne gøret er en fælles læĝenge og ken bruges åf andre projekter.',
 'uploadnewversion-linktext' => 'Læĝ en ny hersenenge åf denne gøret åp',
 
 # MIME search
@@ -624,11 +609,8 @@ hersenenge, (førge) = førskel til den førge hersenenge, l = lile til mendre 
 'linksearch-error' => "Wildkårter må ken benyttes i'n stårt åf håstnavnet.",
 
 # Special:Log/newusers
-'newuserlogpage'           => 'Brugeråprettelseslog',
-'newuserlogpagetext'       => "Dett'er en log åver de senest åprettede brugere.",
-'newuserlog-byemail'       => 'kodeort tilsend via e-mail',
-'newuserlog-create-entry'  => 'Ny bruger',
-'newuserlog-create2-entry' => 'åprettede brugerkonto før $1',
+'newuserlogpage'     => 'Brugeråprettelseslog',
+'newuserlogpagetext' => "Dett'er en log åver de senest åprettede brugere.",
 
 # E-mail user
 'emailuser' => 'E-mail til denne bruger',
@@ -636,10 +618,7 @@ hersenenge, (førge) = førskel til den førge hersenenge, l = lile til mendre 
 # Watchlist
 'watchlist'         => 'Åvervågnengsliste',
 'mywatchlist'       => 'Åvervågnengsliste',
-'watchlistfor'      => "(før '''$1''')",
-'addedwatch'        => 'Tilføjet til din åvervågnengsliste',
 'addedwatchtext'    => "Æ side \"[[:\$1]]\" er blevet tilføjet til din [[Special:Watchlist|åvervågningsliste]]. Fremtidige ændrenger til denne side og den tilhørende diskusjeside hvil bleve listet der, og æ side hvil fremstå '''fremhævet''' i'n [[Special:RecentChanges|liste ve de seneste ændrenger]] før at gøre det lettere at finde den. Hves du senere hvilst fjerne'n side frå din åvervågningsliste, så klik \"Fjern åvervågnenge\".",
-'removedwatch'      => 'Fjernet frå åvervågnengsliste',
 'removedwatchtext'  => 'Æ side "[[:$1]]" er blevet fjernet frå din åvervågnengsliste.',
 'watch'             => 'Åvervåg',
 'watchthispage'     => 'Åvervåg side',
@@ -658,8 +637,7 @@ hersenenge, (førge) = førskel til den førge hersenenge, l = lile til mendre 
 æller et billet sammen ve hæle den tilhørende skigte frå'n database. Bekræft venlegst at du virkelg hvilst gøre dette, at du førstårst konsekvenserne, og at du gør dette i åverensstemmelse ve
 [[{{MediaWiki:Policy-url}}]].",
 'actioncomplete'        => 'Gennemført',
-'deletedtext'           => '"<nowiki>$1</nowiki>" er slettet. Sæg $2 før en førtegnelse åver de nyeste sletnenger.',
-'deletedarticle'        => 'slettede "[[$1]]"',
+'deletedtext'           => '"$1" er slettet. Sæg $2 før en førtegnelse åver de nyeste sletnenger.',
 'dellogpage'            => 'Sletnengslog',
 'deletecomment'         => 'Begrundelse:',
 'deleteotherreason'     => 'Anden/uddybende begrundelse:',
@@ -675,8 +653,7 @@ hersenenge, (førge) = førskel til den førge hersenenge, l = lile til mendre 
 'protectexpiry'               => 'Udløb:',
 'protect_expiry_invalid'      => 'Æ udløbstiid er ugyldeg.',
 'protect_expiry_old'          => "Æ udløbstiid legger i'n førtiid.",
-'protect-unchain'             => 'Ændre flytnengsbeskyttelse',
-'protect-text'                => "Her ken beskyttelsesståt før æ side '''<nowiki>$1</nowiki>''' ses og ændres.",
+'protect-text'                => "Her ken beskyttelsesståt før æ side '''$1''' ses og ændres.",
 'protect-locked-access'       => "Den brugerkonto har ekke de nødvendege rettegheder til at æ ændre sidebeskyttelse. Her er de aktuelle beskyttelsesendstellenger før æ side '''„$1“:'''",
 'protect-cascadeon'           => 'Denne side er del åf en nedarvet skrevebeskyttelse. Wen er endeholt i nedenstående {{PLURAL:$1|side|sider}}, søm er skrevebeskyttet ve tilvalg åf "nedarvende sidebeskyttelse" Æ sidebeskyttelse ken ændres før denne side, det påverker dog ekke\'n kaskadespærrenge:',
 'protect-default'             => 'Ål (standård)',
@@ -687,7 +664,7 @@ hersenenge, (førge) = førskel til den førge hersenenge, l = lile til mendre 
 'protect-expiring'            => 'til $1 (UTC)',
 'protect-cascade'             => 'Nedarvende spærrenge – ål skabelåner, søm er endbundet i denne side spærres også.',
 'protect-cantedit'            => 'Du kenst ekke ændre beskyttelsesnivå før denne side, da du ekke kenst redigære føden.',
-'protect-expiry-options'      => '1 tême:1 hour,1 dåĝ:1 day,1 uge:1 week,2 uger:2 weeks,1 måned:1 month,3 måneder:3 months,6 måneder:6 months,1 år:1 year,ubegrænset:indefinite', # display1:time1,display2:time2,...
+'protect-expiry-options'      => '1 tême:1 hour,1 dåĝ:1 day,1 uge:1 week,2 uger:2 weeks,1 måned:1 month,3 måneder:3 months,6 måneder:6 months,1 år:1 year,ubegrænset:indefinite',
 'restriction-type'            => 'Beskyttelsesståt',
 'restriction-level'           => 'Beskyttelseshøjde',
 
@@ -709,6 +686,8 @@ hersenenge, (førge) = førskel til den førge hersenenge, l = lile til mendre 
 
 'sp-contributions-newbies-sub' => 'Før nybegyndere',
 'sp-contributions-blocklog'    => 'Blokerengslog',
+'sp-contributions-deleted'     => 'Slettede brugerbidråg',
+'sp-contributions-talk'        => 'diskusje',
 
 # What links here
 'whatlinkshere'       => 'Vat henveser hertil',
@@ -723,7 +702,7 @@ hersenenge, (førge) = førskel til den førge hersenenge, l = lile til mendre 
 
 # Block/unblock
 'blockip'       => 'Bloker bruger',
-'ipboptions'    => '1 tême:1 hour,2 têmer:2 hours,6 têmer:6 hours,1 dåĝ:1 day,3 dåĝ:3 days,1 uge:1 week,2 uger:2 weeks,1 måned:1 month,3 måneder:3 months,1 år:1 year,ubegrænset:indefinite', # display1:time1,display2:time2,...
+'ipboptions'    => '1 tême:1 hour,2 têmer:2 hours,6 têmer:6 hours,1 dåĝ:1 day,3 dåĝ:3 days,1 uge:1 week,2 uger:2 weeks,1 måned:1 month,3 måneder:3 months,1 år:1 year,ubegrænset:indefinite',
 'ipblocklist'   => 'Blokerede IP-adresser og brugernave',
 'blocklink'     => 'blåker',
 'unblocklink'   => 'åphæv blokerenge',
@@ -743,7 +722,7 @@ Det betyder at du kenst flytte en side tilbåge hvår den kåm frå, hves du kå
 
 '''ADVARSEL!'''
 Dette ken være en drastisk og uventet ændrenge før en populær side; vær sekker på, at du førstår konsekvenserne åf dette før du førtsætter.",
-'movepagetalktext' => "Den tilhørende diskusjeside, hves der er en, hvil åtåmatisk bleve flyttet ve'n side '''medmendre:''' 
+'movepagetalktext' => "Den tilhørende diskusjeside, hves der er en, hvil åtåmatisk bleve flyttet ve'n side '''medmendre:'''
 *Du flytter æ side til et andet navnerum,
 *En ekke-tøm diskusjeside ålrede eksisterer under det nye navn, æller
 *Du fjerner æ markærenge i'n boks nedenunder.
@@ -754,13 +733,12 @@ I disse tilfælde er du nødt til at flytte æller sammenflette'n side manuelt."
 'move-watch'       => 'Denne side åvervåges',
 'movepagebtn'      => 'Flyt side',
 'pagemovedsub'     => 'Flytnenge gennemført',
-'movepage-moved'   => 'Æ side \'\'\'"$1" er flyttet til "$2"\'\'\'', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
+'movepage-moved'   => 'Æ side \'\'\'"$1" er flyttet til "$2"\'\'\'',
 'articleexists'    => 'En side ve det navn eksisterer ålrede, æller det
 navn du harst valgt er ekke gyldegt. Vælg et andet navn.',
 'talkexists'       => 'Æ side blev flyttet korrekt, men den tilhørende diskusjeside ken ekke flyttes, førdi der ålrede eksisterer en ve den nye titel. Du erst nødt til at flette dem sammen manuelt.',
 'movedto'          => 'flyttet til',
 'movetalk'         => 'Flyt også\'n "diskusjeside", hves den eksisterer.',
-'1movedto2'        => '[[$1]] flyttet til [[$2]]',
 'movelogpage'      => 'Flyttelog',
 'movereason'       => 'Begrundelse:',
 'revertmove'       => 'gendan',
@@ -825,11 +803,10 @@ navn du harst valgt er ekke gyldegt. Vælg et andet navn.',
 'nextdiff'     => 'Gå til næste førskel →',
 
 # Media information
-'file-info-size'       => '($1 × $2 pixel, gøretstørrelse: $3, MIME-senenge: $4)',
-'file-nohires'         => '<small>Engen højere åpløsnenge fundet.</small>',
-'svg-long-desc'        => '(SVG gøret, wønetstørrelse $1 × $2 pixel, gøretstørrelse: $3)',
-'show-big-image'       => 'Hersenenge i større åpløsnenge',
-'show-big-image-thumb' => '<small>Størrelse åf førhåndsvesnenge: $1 × $2 pixel</small>',
+'file-info-size' => '$1 × $2 pixel, gøretstørrelse: $3, MIME-senenge: $4',
+'file-nohires'   => 'Engen højere åpløsnenge fundet.',
+'svg-long-desc'  => 'SVG gøret, wønetstørrelse $1 × $2 pixel, gøretstørrelse: $3',
+'show-big-image' => 'Hersenenge i større åpløsnenge',
 
 # Special:NewFiles
 'newimages' => 'Liste ve de nyeste billeter',
@@ -844,18 +821,24 @@ Kun endholtet åf æ liste (lenjer startende ve *) bliver brugt. Den første hen
 'metadata-help'     => "Denne gøret endeholder yderligere informasje, der søm regel stammer frå lysnåmer æller den brugte skænner. Ve'n æfterføgende bearbejdnenge ken nogle data være ændret.",
 'metadata-expand'   => 'Ves udvedede data',
 'metadata-collapse' => 'Skjul udvedede data',
-'metadata-fields'   => 'Æ følgende felter frå EXIF-metadata i denne MediaWiki-beskedskrevselenger veses på billetbeskrevelsessider; yderligere lileskrevselenger ken veses. 
+'metadata-fields'   => 'Æ følgende felter frå EXIF-metadata i denne MediaWiki-beskedskrevselenger veses på billetbeskrevelsessider; yderligere lileskrevselenger ken veses.
 * make
 * model
 * datetimeoriginal
 * exposuretime
 * fnumber
 * isospeedratings
-* focallength', # Do not translate list items
+* focallength
+* artist
+* copyright
+* imagedescription
+* gpslatitude
+* gpslongitude
+* gpsaltitude',
 
 # External editor support
 'edit-externally'      => "Redigær denne gøret ve'n utsende redigærstøme",
-'edit-externally-help' => 'Se [http://www.mediawiki.org/wiki/Manual:External_editors setup hjælpje] før mære informasje.',
+'edit-externally-help' => 'Se [//www.mediawiki.org/wiki/Manual:External_editors setup hjælpje] før mære informasje.',
 
 # 'all' in various places, this might be different for inflected languages
 'watchlistall2' => 'åle',
@@ -868,9 +851,12 @@ Kun endholtet åf æ liste (lenjer startende ve *) bliver brugt. Den første hen
 'watchlisttools-raw'  => 'Redigær rå åvervågnengsliste',
 
 # Special:Version
-'version' => "Informasje MediaWiki'm", # Not used as normal message but as header for the special page itself
+'version' => "Informasje MediaWiki'm",
 
 # Special:SpecialPages
 'specialpages' => 'Sonst sider',
 
+# New logging system
+'newuserlog-byemail' => 'kodeort tilsend via e-mail',
+
 );
