@@ -201,7 +201,6 @@ $messages = array(
 'badtitletext'       => 'Талап кылынган барак аталышы туура эмес, бош, же тилдер-аралык же уики-аралык аталышы туура эмес шилтемеленген.
 Балким аталышта колдонулбай турган бир же андан көп белги камтылган.',
 'viewsource'         => 'Байкоо',
-'viewsourcefor'      => '$1 үчүн',
 
 # Login and logout pages
 'welcomecreation'         => '== Кош келиңиз, $1! ==
@@ -264,7 +263,6 @@ $messages = array(
 'showdiff'                         => 'Өзгөртүүлөрдү көрсөт',
 'anoneditwarning'                  => "'''Эскертүү:''' Сиз каттоодон өткөн жоксуз.
 IP дарегиңиз бул барактын оңдоо тарыхына жазылат.",
-'whitelistedittitle'               => 'Оңдоо үчүн катоодон өтүү зарыл',
 'accmailtitle'                     => 'Сырсөз жөнөтүлдү.',
 'accmailtext'                      => '"$1" үчүн сырсөз $2 ге жөнөтүлдү.',
 'newarticle'                       => '(Жаңы)',
@@ -504,6 +502,7 @@ IP дарегиңиз бул барактын оңдоо тарыхына жаз
 'prefixindex'      => 'Префикс менен бардык барактар',
 'shortpages'       => 'Кыска макалалар',
 'listusers'        => 'Колдонуучулар тизмеси',
+'usercreated'      => "$1 күнү $2'да {{GENDER:$3|катталды}}.",
 'newpages'         => 'Жаңы барактар',
 'ancientpages'     => 'Эң эски барактар',
 'move'             => 'Аталышын өзгөртүү',
@@ -568,7 +567,6 @@ IP дарегиңиз бул барактын оңдоо тарыхына жаз
 'confirm'        => 'Ырастоо',
 'actioncomplete' => 'Иш-аракет жыйынтыкталды',
 'actionfailed'   => 'Аракет натыйжасыз болду',
-'deletedarticle' => 'өчүрүлдү "[[$1]]"',
 'dellogpage'     => 'Өчүрүлгөндөрдүн тизмеси',
 'deletecomment'  => 'Себеп',
 
@@ -730,6 +728,7 @@ IP дарегиңиз бул барактын оңдоо тарыхына жаз
 
 # Media information
 'file-info-size' => '$1 × $2 пиксел, файлдын көлөмү: $3, MIME тиби: $4',
+'file-nohires'   => 'Мындан дагы толук чечилиши жок.',
 'svg-long-desc'  => 'SVG файл, шарттуу түрдө $1 × $2 пиксел, файлдын көлөмү: $3',
 'show-big-image' => 'Толук чечилиши',
 
