@@ -14,19 +14,23 @@
  * @author Reedy
  */
 
+$fallback = 'ru';
+
 $messages = array(
 # User preference toggles
 'tog-underline'               => 'ЭлячIунрин кIаникай цIар чIугун',
 'tog-justify'                 => 'Ччинин гьяркьуьвилихъ текст дуьзрун',
 'tog-hideminor'               => 'Мукьвара хьайи дегишвилера авай гъвечIи дуьзар хъувунар чуьнуьхун',
 'tog-hidepatrolled'           => 'Мукьвара хьайи дегишвилера авай къаравулвал авунвай дуьзар хъувунар чуьнуьхун',
+'tog-newpageshidepatrolled'   => 'ЦIийи ччинрин сиягьда къаравулвал авунвай ччинар чуьнуьхун',
 'tog-usenewrc'                => 'ЦIийи дегишвилерин сиягь кардик кутун (JavaScript герекзава)',
 'tog-numberheadings'          => 'КЬилин цIарариз автоматдаказ номерар эцигун',
 'tog-showtoolbar'             => 'Дуьзар хъувунин алатрин кьвати къалура (JavaScript)',
 'tog-editondblclick'          => 'Ччинар кьве тIампIуналди дуьзар хъувун (JavaScript герекзава)',
 'tog-editsection'             => 'Пай [дуьзар хъувун] патал элячIун къалура',
 'tog-editsectiononrightclick' => 'Пайдин кьилин цIардиз эрчIи патан тIампI авуна дуьзар хъувундиз мумкинвал гун (JavaScript герекзава)',
-'tog-rememberpassword'        => 'И браузерда зи логин рикlел хуьхь (лап гзаф 1$ {{PLURAL:$1|югъ|йикъар}})',
+'tog-showtoc'                 => 'КЪенеавайбурун сиягь къалурун (3-й гзаф кьилинцIарар авай ччинар патал)',
+'tog-rememberpassword'        => 'И браузерда зи логин рикlел хуьхь (лап гзаф $1 {{PLURAL:$1|югъ|йикъар}})',
 'tog-watchcreations'          => 'За туькIуьрнавай ччинар зи гуьзетунин сиягьдиз алава авун',
 'tog-watchdefault'            => 'За дуьзар хъувунвай ччинар зи гуьзетунин сиягьдиз алава авун',
 'tog-watchmoves'              => 'За тIвар эхцигай ччинар зи гуьзетунин сиягьдиз алава авун',
@@ -34,8 +38,14 @@ $messages = array(
 'tog-previewontop'            => 'Сифтедин килигун дуьзар хъувундин дакIардин вилик эцига',
 'tog-enotifusertalkpages'     => 'КЬилди жуван веревирдрин ччина хьанвай дегишвилерикай э-почтадиз чар ракъурун.',
 
-'underline-always' => 'Гьамиша',
-'underline-never'  => 'Садрани',
+'underline-always'  => 'Гьамиша',
+'underline-never'   => 'Садрани',
+'underline-default' => 'Браузердин низамарунар кардик кутун',
+
+# Font style option in Special:Preferences
+'editfont-style'     => 'Дуьзар хъувунин чкадин шрифтдин жуьре',
+'editfont-monospace' => 'Моногьяркьуьвилер авай шрифт',
+'editfont-sansserif' => 'КЬацI авачир шрифт',
 
 # Dates
 'sunday'        => 'Гьяд',
@@ -90,31 +100,42 @@ $messages = array(
 'dec'           => 'Фaн',
 
 # Categories related messages
-'pagecategories'         => '{{PLURAL:$1|Категория|Категории}}',
-'category_header'        => '"$1" категориядин ччинар',
-'subcategories'          => 'субкатегорияр',
-'category-media-header'  => '"$1" категорияда медиа',
-'category-empty'         => "''Алай чIава и категория ичIи я.\"",
-'hidden-categories'      => '{{PLURAL:$1|Чуьнуьхай категория |Чуьнуьхай категорияр }}',
-'category-subcat-count'  => '{{PLURAL:$2|И категорияда анжах гуьгъуьна авай подкатегория ава.|$2-кай {{PLURAL:$1|подкатегория|$1 подкатегория}} къалурнава }}',
-'category-article-count' => '{{PLURAL:$2|И категорияда анжах гуьгъуьна авайди ччин ава |$2-кай къалурнавай {{PLURAL:$1|ччин|$1 ччин}} гьа а категориядин ччин я}}',
-'category-file-count'    => '{{PLURAL:$2|И категорияда анжах гуьгъуьна авайди файл ава |$2-кай къалурнавай {{PLURAL:$1|файл|$1 файлар}} гьа а категориядин файл я}}',
-'listingcontinuesabbrev' => '(кьатI)',
-'noindex-category'       => 'Индекстежезвай ччин',
+'pagecategories'           => '{{PLURAL:$1|Категория|Категории}}',
+'category_header'          => '"$1" категориядин ччинар',
+'subcategories'            => 'субкатегорияр',
+'category-media-header'    => '"$1" категорияда медиа',
+'category-empty'           => "''Алай чIава и категория ичIи я.\"",
+'hidden-categories'        => '{{PLURAL:$1|Чуьнуьхай категория |Чуьнуьхай категорияр }}',
+'hidden-category-category' => 'Чуьнуьхай категорияр',
+'category-subcat-count'    => '{{PLURAL:$2|И категорияда анжах гуьгъуьна авай подкатегория ава.|$2-кай {{PLURAL:$1|подкатегория|$1 подкатегория}} къалурнава }}',
+'category-article-count'   => '{{PLURAL:$2|И категорияда анжах гуьгъуьна авайди ччин ава |$2-кай къалурнавай {{PLURAL:$1|ччин|$1 ччин}} гьа а категориядин ччин я}}',
+'category-file-count'      => '{{PLURAL:$2|И категорияда анжах гуьгъуьна авайди файл ава |$2-кай къалурнавай {{PLURAL:$1|файл|$1 файлар}} гьа а категориядин файл я}}',
+'listingcontinuesabbrev'   => '(кьатI)',
+'index-category'           => 'Индексавунвай ччинар',
+'noindex-category'         => 'Индекстежезвай ччин',
+'broken-file-category'     => 'ЧIуру файлдин элячIунар авай ччинар',
 
-'about'      => 'ГЬакъиндай',
-'newwindow'  => '(цlийи дакlарда ахъа жезва)',
-'cancel'     => 'Гьич авун',
-'mypage'     => 'Зин чар',
-'mytalk'     => 'Зи веревирдрин ччин',
-'navigation' => 'КЪекъуьнар',
+'about'         => 'ГЬакъиндай',
+'article'       => 'Макъала',
+'newwindow'     => '(цlийи дакlарда ахъа жезва)',
+'cancel'        => 'Гьич авун',
+'moredotdotdot' => 'Мад...',
+'mypage'        => 'Зин чар',
+'mytalk'        => 'Зи веревирдрин ччин',
+'anontalk'      => 'И IP-адресдиз талукь веревирд.',
+'navigation'    => 'КЪекъуьнар',
+'and'           => '&#32;ва',
 
 # Cologne Blue skin
 'qbfind'         => 'Жугъун',
+'qbbrowse'       => 'Килигун',
 'qbedit'         => 'Дегишарун',
+'qbpageoptions'  => 'Ччинин низамарунар',
+'qbpageinfo'     => 'Ччиникай малумат',
 'qbmyoptions'    => 'Зи ччинар',
 'qbspecialpages' => 'Кьетlен хъувун',
 'faq'            => 'Фад-фад гузвай жузунар (ФГЖ)',
+'faqpage'        => 'Project:ФГС',
 
 # Vector skin
 'vector-action-addsection' => 'Тема алава авун',
@@ -122,6 +143,7 @@ $messages = array(
 'vector-action-move'       => 'ТIвар эхцигун',
 'vector-action-protect'    => 'Хуьн',
 'vector-action-undelete'   => 'ТуькIуьр хъувун',
+'vector-action-unprotect'  => 'Хуьн дегишарун',
 'vector-view-create'       => 'Туькlуьрун',
 'vector-view-edit'         => 'Дуьзар хъувун',
 'vector-view-history'      => 'Тарихдиз килигун',
@@ -131,42 +153,57 @@ $messages = array(
 'namespaces'               => 'Тlварарин генгвилер',
 'variants'                 => 'Жуьреяр',
 
-'errorpagetitle'   => 'ГъалатI',
-'returnto'         => '$1 ччиниз элкъвена хтун',
-'tagline'          => '{{SITENAME}} Cайтдихъай',
-'help'             => 'Куьмек',
-'search'           => 'Жугъурун',
-'searchbutton'     => 'Жугъурун',
-'go'               => 'ЭлячIун',
-'searcharticle'    => 'ЭлячIун',
-'history'          => 'Ччинин тарих',
-'history_short'    => 'Тарих',
-'printableversion' => 'Басма авун патал жуьре',
-'permalink'        => 'ГЬамишан элячIун',
-'print'            => 'Басма авун',
-'view'             => 'Килигун',
-'edit'             => 'Дуьзар хъувун',
-'create'           => 'Туькlуьрун',
-'editthispage'     => 'И ччин дуьзар хъувун',
-'delete'           => 'Алудун',
-'deletethispage'   => 'И ччин алудун',
-'protect'          => 'Xуьн',
-'protect_change'   => 'Дегишун',
-'protectthispage'  => 'И ччин блокарун',
-'newpage'          => 'ЦIийи ччин',
-'talkpage'         => 'И ччин веревирдун',
-'talkpagelinktext' => 'Рахун',
-'personaltools'    => '-КЬилди вичин алатар',
-'talk'             => 'Веревирд авун',
-'views'            => 'Килигунар',
-'toolbox'          => 'Алатрин кьвати',
-'otherlanguages'   => 'Маса чIаларал',
-'redirectedfrom'   => '($1-кай рахкъурнава )',
-'redirectpagesub'  => 'Рахкъурунин ччин',
-'lastmodifiedat'   => 'Ччинин эхиримжи дегиш хьун:  $1,  $2',
-'jumpto'           => 'ЭлячIун иниз:',
-'jumptonavigation' => 'Навигация',
-'jumptosearch'     => 'Жугъурун',
+'errorpagetitle'    => 'ГъалатI',
+'returnto'          => '$1 ччиниз элкъвена хтун',
+'tagline'           => '{{SITENAME}} Cайтдихъай',
+'help'              => 'Куьмек',
+'search'            => 'Жугъурун',
+'searchbutton'      => 'Жугъурун',
+'go'                => 'ЭлячIун',
+'searcharticle'     => 'ЭлячIун',
+'history'           => 'Ччинин тарих',
+'history_short'     => 'Тарих',
+'printableversion'  => 'Басма авун патал жуьре',
+'permalink'         => 'ГЬамишан элячIун',
+'print'             => 'Басма авун',
+'view'              => 'Килигун',
+'edit'              => 'Дуьзар хъувун',
+'create'            => 'Туькlуьрун',
+'editthispage'      => 'И ччин дуьзар хъувун',
+'create-this-page'  => 'И ччин туькIуьрун',
+'delete'            => 'Алудун',
+'deletethispage'    => 'И ччин алудун',
+'protect'           => 'Xуьн',
+'protect_change'    => 'Дегишун',
+'protectthispage'   => 'И ччин блокарун',
+'unprotect'         => 'Хуьн дегишарун',
+'unprotectthispage' => 'И ччинин хуьн дегишарун',
+'newpage'           => 'ЦIийи ччин',
+'talkpage'          => 'И ччин веревирдун',
+'talkpagelinktext'  => 'Рахун',
+'specialpage'       => 'Куьмекчи ччин',
+'personaltools'     => '-КЬилди вичин алатар',
+'postcomment'       => 'ЦIйий пай',
+'articlepage'       => 'КЪене авайбурун ччиндиз  килигун',
+'talk'              => 'Веревирд авун',
+'views'             => 'Килигунар',
+'toolbox'           => 'Алатрин кьвати',
+'userpage'          => 'Иштракчидин ччиниз килигун',
+'projectpage'       => 'Проектдин ччиниз килигун',
+'imagepage'         => 'Файлдин ччиниз килигун',
+'mediawikipage'     => 'Чардин ччиниз килигун',
+'templatepage'      => 'Чешнедин ччиниз килигун',
+'viewhelppage'      => 'Куьмекдин ччиниз килигун',
+'categorypage'      => 'Категориядин ччиниз килигун',
+'viewtalkpage'      => 'Веревирдриз килигун',
+'otherlanguages'    => 'Маса чIаларал',
+'redirectedfrom'    => '($1-кай рахкъурнава )',
+'redirectpagesub'   => 'Рахкъурунин ччин',
+'lastmodifiedat'    => 'Ччинин эхиримжи дегиш хьун:  $1,  $2',
+'jumpto'            => 'ЭлячIун иниз:',
+'jumptonavigation'  => 'Навигация',
+'jumptosearch'      => 'Жугъурун',
+'pool-errorunknown' => 'Малумтушир гъалатI',
 
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
 'aboutsite'            => 'ГЬакъиндай {{SITENAME}}',
@@ -189,25 +226,30 @@ $messages = array(
 
 'badaccess' => 'ГЬатунин гъалатlдин',
 
-'ok'                  => 'ОК',
-'retrievedfrom'       => 'Чешне "$1" я',
-'youhavenewmessages'  => 'Квез  $1 ($2) атанва.',
-'newmessageslink'     => 'цlийи чарар',
-'newmessagesdifflink' => 'Эхиримжи дегишарунар',
-'editsection'         => 'дуьзар хъувун',
-'editold'             => 'Дуьзар хъувун',
-'viewsourceold'       => 'сифте кьилин коддиз килига',
-'editlink'            => 'Дуьзар хъувун',
-'viewsourcelink'      => 'Сифте кьилин коддиз килига',
-'editsectionhint'     => 'Пай дуьзар хъувун: $1',
-'toc'                 => 'КЪене авайбур',
-'showtoc'             => 'къалурун',
-'hidetoc'             => 'чуьнуьхун',
-'site-rss-feed'       => '$1 — RSS-зул',
-'site-atom-feed'      => '$1 -  атом-зул',
-'page-rss-feed'       => '"$1" РСС Xуьрек',
-'page-atom-feed'      => '"$1" Атом-зул',
-'red-link-title'      => '$1 (ихьтин ччин авайд туш)',
+'ok'                   => 'ОК',
+'retrievedfrom'        => 'Чешне "$1" я',
+'youhavenewmessages'   => 'Квез  $1 ($2) атанва.',
+'newmessageslink'      => 'цlийи чарар',
+'newmessagesdifflink'  => 'Эхиримжи дегишарунар',
+'editsection'          => 'дуьзар хъувун',
+'editold'              => 'Дуьзар хъувун',
+'viewsourceold'        => 'сифте кьилин коддиз килига',
+'editlink'             => 'Дуьзар хъувун',
+'viewsourcelink'       => 'Сифте кьилин коддиз килига',
+'editsectionhint'      => 'Пай дуьзар хъувун: $1',
+'toc'                  => 'КЪене авайбур',
+'showtoc'              => 'къалурун',
+'hidetoc'              => 'чуьнуьхун',
+'collapsible-collapse' => 'Алчудрун',
+'collapsible-expand'   => 'Гегьеншрун',
+'thisisdeleted'        => '$1 килигун ва я туькIуьр хъувун?',
+'viewdeleted'          => '$1 килигун?',
+'feedlinks'            => 'Хулан жуьре',
+'site-rss-feed'        => '$1 — RSS-зул',
+'site-atom-feed'       => '$1 -  атом-зул',
+'page-rss-feed'        => '"$1" РСС Xуьрек',
+'page-atom-feed'       => '"$1" Атом-зул',
+'red-link-title'       => '$1 (ихьтин ччин авайд туш)',
 
 # Short words for each namespace, by default used in the namespace tab in monobook
 'nstab-main'      => 'Ччин',
@@ -231,13 +273,15 @@ $messages = array(
 'badtitle'           => 'Ииже текъвер тIвар',
 'badtitletext'       => 'ТIалабзавай ччин  я вичел амал алачир я,  я  ичIи я,  ва я чIаларарадин ва я викиарадин кьилин цlарар чlурукlа къалурнава. Мумкин я, кьилин цlарара сад ва я адалай гзаф рехъ гун виже текъвер символар кардик кутунвайди я.',
 'viewsource'         => 'Килигун',
-'viewsourcefor'      => 'идаз $1',
+
+# Virus scanner
+'virus-unknownscanner' => 'Малумтушир антивирус',
 
 # Login and logout pages
 'yourname'                => 'Иштиракчидин тlвар',
 'yourpassword'            => 'Парол',
 'yourpasswordagain'       => 'Парол кхьин хъувун:',
-'remembermypassword'      => 'И браузерда зи логин рикlел хуьхь (лап гзаф 1$ {{PLURAL:$1|югъ|йикъар}})',
+'remembermypassword'      => 'И браузерда зи логин рикlел хуьхь (лап гзаф $1 {{PLURAL:$1|югъ|йикъар}})',
 'login'                   => 'Гьахьун',
 'nav-login-createaccount' => 'ГЬахьун/аккаунт туькlуьрун',
 'loginprompt'             => 'Системадиз гьахьун патал "куки" -яр куькlуьрна кIанзава',
@@ -290,6 +334,7 @@ $messages = array(
 'showdiff'                         => 'Дегишвилер къалурун',
 'anoneditwarning'                  => "'''Дикъет:''' Куьне системадиз жув вуж ятIа лагьанвач. Куь IP-адрес и ччинин дегишвилерин тарихдиз  кхьида.",
 'summary-preview'                  => 'Сифте килигун паталди:',
+'nosuchsectiontitle'               => 'Пай жугъуриз жезвач',
 'loginreqlink'                     => 'гьахьун',
 'newarticle'                       => '(ЦIийи)',
 'newarticletext'                   => 'Куьне гьеле авачир ччиниз элячlнава.  
@@ -306,10 +351,10 @@ $messages = array(
 Куь дегишунар гьеле хвенвач!",
 'editing'                          => '$1 Дуьзар хъувун',
 'editingsection'                   => 'Дуьзар хъувун $1  (пай)',
-'copyrightwarning'                 => "Тавакъу ийида, фагьум аф хьи, {{SITENAME}}-диз кутунвай вири крариз $2 лицензиядин шартунал акъуднавайбур хьиз килигда. (гегьеншдиз $1-з килига). 
+'copyrightwarning'                 => "Тавакъу ийида, фагьум ая хьи, {{SITENAME}}-диз кутунвай вири крариз $2 лицензиядин шартунал акъуднавайбур хьиз килигда. (гегьеншдиз $1-з килига). 
 Квез куьне кхьенвайбур азаддаказ чкIун ва гьар са кас  патахъай дуьзар хъувун кIанзавачтIа, а кхьенвайбур иниз эцигмир.<br />
 ГЬакIни, куьне тестикьзава хьи, кутазвай алавайрин автор кьун я, я тахьайтIа, куьне а алаваяр чпин къенеавайбур азад чкIунни дегишун ихтияр гузвай чешмедикай ччин къачунва.<br />
-'''АВТОРДИН ИХТИЯР ХУЬЗВАЙ МАЛУМАТАР ИХТИЯР ГАЛАЧИЗ ЭЦТИГМИР!'''",
+'''АВТОРДИН ИХТИЯР ХУЬЗВАЙ МАЛУМАТАР ИХТИЯР ГАЛАЧИЗ ЭЦИГМИР!'''",
 'templatesused'                    => 'И ччина кардик кутунвай {{PLURAL:$1|Чешне|Чешнеяр}}:',
 'templatesusedpreview'             => '{{PLURAL:$1|Шаблон|Шаблонар}},илемишзавай дуьз клигунра:',
 'template-protected'               => '(хвенвай)',
@@ -356,22 +401,26 @@ $messages = array(
 # Revision deletion
 'rev-delundel'               => 'къалурун/кIевирун',
 'revdelete-show-file-submit' => 'Эхь',
+'revdelete-hide-image'       => 'Файлдин къенеавайбур чуьнуьхун',
+'revdelete-hide-name'        => 'Карни адан объект чуьнуьхун',
+'revdelete-radio-set'        => 'Эхь',
+'revdelete-radio-unset'      => 'Ваъ',
 'revdelete-log'              => 'Кар',
-'revdelete-logentry'         => 'Дегишарна акунвал "[[$1]]"',
 'revdel-restore'             => 'Аквадайвал дегишарун',
 'revdel-restore-deleted'     => 'Алуднавай жуьреяр',
 'revdel-restore-visible'     => 'Аквадай дегишвилер',
 'pagehist'                   => 'Ччинин тарих',
-'revdelete-content'          => 'Къйеда',
-'revdelete-uname'            => 'ишлемишчидин тIар',
-'revdelete-hid'              => 'чуьнуьх авунай $1',
-'revdelete-log-message'      => '$1 идай $2 {{PLURAL:$2|Жуьре|Жуьреяр}}',
+'revdelete-edit-reasonlist'  => 'Алудунин себебар дуьзар хъувун',
 'revdelete-offender'         => 'Автордин жуьре:',
 
 # History merging
+'mergehistory-from'   => 'Сифте кьилин ччин:',
+'mergehistory-into'   => 'Мураддин ччин',
+'mergehistory-submit' => 'Дуьзар хъувунар сад авун',
 'mergehistory-reason' => 'Себеб',
 
 # Merge log
+'mergelog'    => 'Сад авунин журнал',
 'revertmerge' => 'Ччара авун',
 
 # Diffs
@@ -396,8 +445,10 @@ $messages = array(
 'nextn-title'                      => 'КЪведай $1 {{PLURAL:$1|нетижа|нетижаяр}}',
 'shown-title'                      => 'Ччина $1 {{PLURAL:$1|нетижа|нетижаяр}} къалура',
 'viewprevnext'                     => 'Килигун ($1 {{int:pipe-separator}} $2) ($3)',
+'searchmenu-legend'                => 'Жагъурунин низамарунар',
 'searchmenu-exists'                => "'''И вики-проектда \"[[:\$1]]\" тlвар алай ччин ава.'''",
 'searchmenu-new'                   => "'''И вики-проектда \"[[:\$1]]\" ччин туькlуьрун !'''",
+'searchhelp-url'                   => 'Help:КЪене авайбур',
 'searchprofile-articles'           => 'Асул ччинар',
 'searchprofile-project'            => 'Куьмек гунин ва проектдин ччинар',
 'searchprofile-images'             => 'Мультимедиа',
@@ -430,14 +481,46 @@ $messages = array(
 'powersearch-redir'                => 'Рахкъурунар къалура',
 'powersearch-field'                => 'Идаз жагъурун',
 'powersearch-toggleall'            => 'Вири',
+'powersearch-togglenone'           => 'Садни',
+
+# Quickbar
+'qbsettings-none'          => 'Садни',
+'qbsettings-fixedleft'     => 'Чапла патахъай юзан тийир',
+'qbsettings-fixedright'    => 'ЭрчIи патахъай юзан тийир',
+'qbsettings-floatingleft'  => 'Чапла патаз алгъурзава',
+'qbsettings-floatingright' => 'ЭрчIи патаз алгъурзава',
 
 # Preferences page
 'preferences'               => 'Туькlуьрун',
 'mypreferences'             => 'Зи низамарунар',
+'prefs-edits'               => 'Дьузар хъувунрин кьадар',
+'prefsnologin'              => 'Куьне гьахьнавач',
+'changepassword'            => 'Парол дегишарун',
+'prefs-skin'                => 'КЪайдадиз ттунин тема',
+'skin-preview'              => 'Сифтедин килигун',
 'datedefault'               => 'Туькlуьрмир',
+'prefs-beta'                => 'Бета-мумкинвилер',
 'prefs-datetime'            => 'Нумра ва вахт',
+'prefs-personal'            => 'Иштиракчидин профил',
+'prefs-rc'                  => 'Mукьвара хьайи дегишвилер',
+'prefs-watchlist'           => 'Гуьзетунин сиягь',
+'prefs-watchlist-edits-max' => 'Максимум кьадар: 1000',
+'prefs-watchlist-token'     => 'Гуьзетунин сиягьдин лишан',
+'prefs-misc'                => 'Муькуь низамарунар',
+'prefs-resetpass'           => 'Парол дегишарун',
+'prefs-changeemail'         => 'Э-почта дегишарун',
+'prefs-setemail'            => 'Э-почта эцигна туькIуьрун',
 'prefs-email'               => 'E-mail туькlуьрунин кьадарар',
+'prefs-rendering'           => 'КЪецепатан  акунар',
+'saveprefs'                 => 'Хуьн',
+'resetprefs'                => 'Хуьн тавунвай дегишвилер алудун',
+'restoreprefs'              => 'Авайл хьиз кьунвай низамарунар туькIуьр хъувун',
+'prefs-editing'             => 'Дуьзар хъувун',
+'prefs-edit-boxsize'        => 'Дуьзар хъувунин дакIардин кьадар',
+'rows'                      => 'ЦIарар',
+'columns'                   => 'Гулар:',
 'searchresultshead'         => 'Ахтармишун',
+'resultsperpage'            => 'Са ччиниз талукь тир жагъанвай нетижаяр',
 'timezonelegend'            => 'Вахтунин минзил',
 'timezoneregion-africa'     => 'Африка',
 'timezoneregion-america'    => 'Америка',
@@ -457,8 +540,12 @@ $messages = array(
 'gender-female'             => 'Фамили',
 'email'                     => 'E-mail',
 'prefs-help-email'          => 'Электрон почтунин адрес кхьи  мажбури туш, амма куьне парол рикIелай ракъурдатIа, ам герек жеда.',
-'prefs-help-email-others'   => 'Квевай жезва хкягъиз, масабриг кхьиз квез электр пучтадай, алукьунай куьн ихтилатдинчарчел алай.
-Куьн адрес электрон пучтадин гьатнавач, маса ишлемишчийри квез кхьидайла.',
+'prefs-help-email-others'   => 'Квевай куь иштиракчидин, ва я куь веревирдрин ччина элячIун къалурна мукуь иштиракчияр галаз электрон почтадин куькмедалди алакъа хуьз жеда.
+Муькуь иштиракчийриз квез электрондин чар кхьидайла куь элетрондин почтадин адрес аквадач.',
+'prefs-advancedediting'     => 'Гегьенш низамарунар',
+'prefs-advancedrc'          => 'Гегьенш низамарунар',
+'prefs-advancedrendering'   => 'Гегьенш низамарунар',
+'prefs-advancedwatchlist'   => 'Гегьенш низамарунар',
 
 # User rights
 'userrights-reason' => 'Кар',
@@ -467,9 +554,10 @@ $messages = array(
 'group-sysop' => 'Къавха',
 'group-all'   => '(вири)',
 
-'group-user-member' => 'ишлемишчи',
-'group-bot-member'  => 'бот',
+'group-user-member' => '{{GENDER:$1|иштиракчи}}',
+'group-bot-member'  => '{{GENDER:$1|бот}}',
 
+'grouppage-user'  => '{{ns:project}}:Иштиракчияр',
 'grouppage-sysop' => '{{ns:project}}:Къавхаяр',
 
 # Rights
@@ -492,7 +580,7 @@ $messages = array(
 'recentchanges-label-bot'         => 'И дуьзар хъувун ботди авунвайд я',
 'recentchanges-label-unpatrolled' => 'И дуьзар хъувундин винел патрулвал авунвач',
 'rcnote'                          => "$5, $4 чIавун кьатIдиз талукь {{PLURAL:$2|югъ|'''$2''' йикъар}} къене{{PLURAL:$1|эхиримжи'''1''' дегишун|эхиримжи '''$1''' дегишунар}}",
-'rcnotefrom'                      => "Кlеник къалурна дегишунар идлай '''$2''' (идалди '''$1''' къалурна).",
+'rcnotefrom'                      => "Агъадихъ '''$2'''-ай эгечIна дегишвилер къалурнава ( '''$1''' кьван  къалурнава).",
 'rclistfrom'                      => '$1-ла эгечIна цIийи дегишвилер къалура',
 'rcshowhideminor'                 => '$1 гъвечlи дуьзар хъувунар',
 'rcshowhidebots'                  => '$1 ботар',
@@ -586,7 +674,7 @@ $messages = array(
 'prefixindex'   => 'Префикс галай вири ччинар',
 'shortpages'    => 'Куьруь хъувун',
 'longpages'     => 'Яргъи хъувун',
-'usercreated'   => 'И чIава туькlуьрнава: $1 $2',
+'usercreated'   => '{{GENDER:$3|Created}} идав $1 идал $2',
 'newpages'      => 'ЦIийи ччинар',
 'move'          => 'ТIвар эхцигун',
 'movethispage'  => 'Юзун и хъувун',
@@ -620,8 +708,7 @@ $messages = array(
 'linksearch-line' => '$2-ай $1-аз элячlун',
 
 # Special:Log/newusers
-'newuserlogpage'          => 'Иштиракчийрин туькlуьрунин журнал',
-'newuserlog-create-entry' => 'ЦIийи ишлемишчидин чин',
+'newuserlogpage' => 'Иштиракчийрин туькlуьрунин журнал',
 
 # Special:ListGroupRights
 'listgrouprights-members' => '(уьзвийрин сиягь)',
@@ -654,7 +741,6 @@ $messages = array(
 'actioncomplete'        => 'Кар авунва',
 'actionfailed'          => 'Кар йиз алакьнавач',
 'deletedtext'           => '"$1" чlурнайтир.                                                                                                                                                       Килиг $2 эхиримжи  чlурунар ахтармишун.',
-'deletedarticle'        => 'къакъудун "[[$1]]"',
 'dellogpage'            => 'Алудунин журнал',
 'deletecomment'         => 'Кар',
 'deleteotherreason'     => 'Масса/ ва мад кар',
@@ -692,7 +778,6 @@ $messages = array(
 'undeletelink'              => 'Килигун/гуьнгуьна хтун',
 'undeleteviewlink'          => 'Килигун',
 'undeletecomment'           => 'Кар',
-'undeletedarticle'          => 'Туькlуьр хъувуна "[[$1]]"',
 'undelete-show-file-submit' => 'Э',
 
 # Namespace form on various pages
@@ -774,8 +859,6 @@ $messages = array(
 'talkexists'       => "'''Чарчин тlар дегишарна, чарчин ихтилатар дегишар жезатуш, вучиз лагьайтlа ихтилатар цlийи чарчел фена.Галкlура гълелди.'''",
 'movedto'          => 'хтана иниз',
 'movetalk'         => 'Югъун,галкlана рахун',
-'1movedto2'        => 'хъфена [[$1]] идал [[$2]]',
-'1movedto2_redir'  => 'къфена [[$1]] идаз [[$2]] ракъурунар',
 'movelogpage'      => 'Тlвар эхцигунрин журнал',
 'movereason'       => 'Фагьум:',
 'revertmove'       => 'Рахкъурун',
@@ -852,17 +935,13 @@ $messages = array(
 'tooltip-undo'                    => '«ГЬич авун»  авунвай  дуьзар хъувун paxкурзава ва сифтедин килигунин режимда  дуьзар хъувундин форма ахъа йийзва. Им нетижадиз себеб алава йийз  мумкинвал гузва',
 'tooltip-summary'                 => 'Куьруь нетижа гьадрун',
 
-# Patrol log
-'patrol-log-line' => 'кхьена  $1 идай $2 ахтармишнава $3',
-'patrol-log-diff' => 'жуьре $1',
-
 # Browsing diffs
 'previousdiff' => 'Вилик алатай дуьзар хъувун',
 'nextdiff'     => 'ЦIийи дегишунар',
 
 # Media information
 'file-info-size' => '$1 × $2 пикселар, файлдин кьадар: $3, MIME жуьре: $4',
-'file-nohires'   => '<small>Чlехи ахъаюн авай жуьре авач.</small>',
+'file-nohires'   => 'Идалайни хъсан ери авайд туш',
 'svg-long-desc'  => 'SVG файл, номилдаказ $1 $2 × пикселяр, файлдин кьадар: $3',
 'show-big-image' => 'Мадни хъсан еридин шикил',
 
@@ -942,7 +1021,7 @@ $messages = array(
 
 # External image whitelist
 'external_image_whitelist' => ' #И цIар авайд хьиз тур</pre>
-#Агъада вахт акадар тийиз жезвай лугьунрин кьатIар эцига (// арада авай кIус).
+#Агъада вахт акадар тийиз жезвай (гьамиша къайдадалди ) лугьунрин кьатIар эцига (// арада авай кIус).
 #Ибур кьецепатан суьретрин URL галаз гекъигда.
 #Дуьзкъвезвайбур суьретар хьиз къалурда, муькуьбур суьретриз тухузвай элячIунар хьиз къалурда.
 # "#" галаз эгечIзавай цIарариз къейдериз хьиз килигда.
