@@ -8,6 +8,7 @@
  * @file
  *
  * @author Fluence
+ * @author Kaganer
  * @author Reedy
  * @author Ricardo gs
  * @author Rob Church <robchur@gmail.com>
@@ -118,20 +119,20 @@ $messages = array(
 'editfont-serif'     => 'Serif machiyōtlahtōliztli',
 
 # Dates
-'sunday'        => 'tōnatiuhtōnal',
-'monday'        => 'mētztlitōnal',
-'tuesday'       => 'huītzilōpōchtōnal',
-'wednesday'     => 'yacatlipotōnal',
-'thursday'      => 'tezcatlipotōnal',
-'friday'        => 'quetzalcōātōnal',
-'saturday'      => 'tlāloctitōnal',
-'sun'           => 'tōn',
-'mon'           => 'mētz',
-'tue'           => 'huītz',
-'wed'           => 'yac',
-'thu'           => 'tez',
-'fri'           => 'quetz',
-'sat'           => 'tlāl',
+'sunday'        => 'ic cemilhuitl',
+'monday'        => 'ic ōmilhuitl',
+'tuesday'       => 'ic ēyilhuitl',
+'wednesday'     => 'ic nāhuilhuitl',
+'thursday'      => 'ic mācuīlilhuitl',
+'friday'        => 'ic chicuacemilhuitl',
+'saturday'      => 'ic chicōmilhuitl',
+'sun'           => 'cemilhui',
+'mon'           => 'ōmilhui',
+'tue'           => 'ēyilhui',
+'wed'           => 'nāhuilhui',
+'thu'           => 'mācuīlilhui',
+'fri'           => 'chicuacemilhui',
+'sat'           => 'chicōmilhui',
 'january'       => 'Àtemòstli',
 'february'      => 'Iskalli',
 'march'         => 'Àtlakàwalo',
@@ -144,30 +145,30 @@ $messages = array(
 'october'       => 'Teòtlêko',
 'november'      => 'Tepèilwitl',
 'december'      => 'Pànketzalistli',
-'january-gen'   => 'tlacēnti',
-'february-gen'  => 'tlaōnti',
-'march-gen'     => 'tlayēti',
-'april-gen'     => 'tlanāuhti',
-'may-gen'       => 'tlamācuīlti',
-'june-gen'      => 'tlachicuazti',
-'july-gen'      => 'tlachicōnti',
-'august-gen'    => 'tlachicuēiti',
-'september-gen' => 'tlachiucnāuhti',
-'october-gen'   => 'tlamahtlācti',
-'november-gen'  => 'tlamahtlāccēti',
-'december-gen'  => 'tlamahtlācōnti',
-'jan'           => 'cēn',
-'feb'           => 'ōnt',
-'mar'           => 'yēt',
-'apr'           => 'nāuh',
-'may'           => 'mācuīl',
-'jun'           => 'chicuacē',
-'jul'           => 'chicōn',
-'aug'           => 'chicuēyi',
-'sep'           => 'chiucnāuh',
-'oct'           => 'mahtlāc',
-'nov'           => 'oncē',
-'dec'           => 'omōme',
+'january-gen'   => 'ic cē mētztli',
+'february-gen'  => 'ic ōme mētztli',
+'march-gen'     => 'ic ēyi mētztli',
+'april-gen'     => 'ic nāuhtetl mētztli',
+'may-gen'       => 'ic mācuīlli mētztli',
+'june-gen'      => 'ic chicuacen mētztli',
+'july-gen'      => 'ic chicōme mētztli',
+'august-gen'    => 'ic chicuēyi mētztli',
+'september-gen' => 'ic chiucnāhui mētztli',
+'october-gen'   => 'ic mahtlāctetl mētztli',
+'november-gen'  => 'ic mahtlāctetl oncē mētztli',
+'december-gen'  => 'ic mahtlāctetl omōme mētztli',
+'jan'           => 'ic cē',
+'feb'           => 'ic ōme',
+'mar'           => 'ic ēyi',
+'apr'           => 'ic nāuh',
+'may'           => 'ic mācuīl',
+'jun'           => 'ic chicuacē',
+'jul'           => 'ic chicōme',
+'aug'           => 'ic chicuēyi',
+'sep'           => 'ic chiucnāuh',
+'oct'           => 'ic mahtlāc',
+'nov'           => 'ic mahtlāctli oncē',
+'dec'           => 'ic mahtlāctli onōme',
 
 # Categories related messages
 'pagecategories'                 => '{{PLURAL:$1|Tlaìxmatkàtlàlilòtl|Tlaìxmatkàtlàlilòmë}}',
@@ -216,9 +217,10 @@ $messages = array(
 'vector-view-history'    => 'Tlahcuilōlli tlahcuilōlloh',
 'vector-view-view'       => 'Tāmapōhuaz',
 'vector-view-viewsource' => 'Tiquittāz in mēyalli',
+'actions'                => 'Āyiliztli',
 'namespaces'             => 'Tòkâyeyàntìn',
 
-'errorpagetitle'    => 'Ahcuallōtl',
+'errorpagetitle'    => 'Aiuhcāyōtl',
 'returnto'          => 'Timocuepāz īhuīc $1.',
 'tagline'           => 'Īhuīcpa {{SITENAME}}',
 'help'              => 'Tēpalēhuiliztli',
@@ -362,7 +364,6 @@ Hueli tlein āquin ōquipolo achtopa.',
 'badtitletext'        => 'Zāzanilli ticnequi in ītōca cah ahcualli, ahtlein quipiya nozo ahcualtzonhuiliztli interwiki tōcāhuicpa.
 Hueliz quimpiya tlahtōl tlein ahmo mohuelītih motequitiltia tōcāpan.',
 'viewsource'          => 'Tiquittāz tlahtōlcaquiliztilōni',
-'viewsourcefor'       => '$1 ītechcopa',
 'actionthrottled'     => 'Tlachīhualiztli ōmotzacuili',
 'viewsourcetext'      => 'Tihuelīti tiquitta auh ticcopīna inīn zāzanilli ītlahtōlcaquiliztilōni:',
 'sqlhidden'           => '(Tlatēmoliztli SQL omotlāti)',
@@ -474,9 +475,6 @@ Occeppa xicalaqui niman ticmatīz.',
 'summary-preview'                  => 'Tlahcuilōltōn achtochīhualiztli:',
 'blockedtitle'                     => 'Ōmotzacuili tlatequitiltilīlli',
 'blockednoreason'                  => 'ahmo cah īxtlamatiliztli',
-'blockedoriginalsource'            => "Nicān motta '''$1''' ītlahtōlcaquiliztilōni:",
-'blockededitsource'                => "'''Mopatlaliz''' ītlahtōl īpan '''$1''' motta nicān:",
-'whitelistedittitle'               => 'Tihuīquilia timocalaqui ic patla',
 'whitelistedittext'                => 'Tihuīquilia $1 ic ticpatla zāzaniltin.',
 'nosuchsectiontitle'               => 'In xeliuhcāyōtl ahmo ōquināmic',
 'loginreqtitle'                    => 'Ximocalaqui',
@@ -507,7 +505,7 @@ Tihuelīti [[Special:Search/{{PAGENAME}}|tictēmoa inīn zāzaniltōcācopa]] oc
 'yourdiff'                         => 'Ahneneuhquiliztli',
 'copyrightwarning'                 => "<small>Timitztlātlauhtiah xiquitta mochi mopatlaliz cana {{SITENAME}} tlatzayāna īpan $2 (huēhca ōmpa xiquitta $1). Āqueh tlācah quipatlazqueh in motlahcuilōl auh tlatzayāna occeppa; intlā ahmō ticnequi, zātēpan ahmō titlahcuilōz nicān. Nō mitzihtoah in ōtitlahcuiloh ahmō quipiya in copyright nozo in yōllōxoxouhqui tlahcuilōlli. '''¡AHMŌ XITĒQUITILTIA AHYŌLLŌXOXOUHQUI TLAHCUILŌLLI!'''</small>",
 'copyrightwarning2'                => "<small>Āqueh tlācah quipatlazqueh in motlahcuilōl auh tlatzayāna occeppa; intlā ahmō ticnequi, zātēpan ahmō titlahcuilōz nicān {{SITENAME}}. Nō mitzihtoah in ōtitlahcuiloh ahmō quipiya in copyright nozo in yōllōxoxouhqui tlahcuilōlli (huēhca ōmpa xiquitta $1). '''¡AHMŌ TIQUINTEQUITILTIA AHYŌLLŌXOXOUHQUI TLAHCUILŌLLI!'''</small>",
-'longpageerror'                    => "'''AHCUALLŌTL: Motlahcuilōl cah huēiyac $1 KB, huehca ōmpa $2 KB. Ahmo mopiyāz.'''",
+'longpageerror'                    => "'''Aiuhcāyōtl: In tlahcuilōlli tlein ōtiquihuah tlatamachīhua {{PLURAL:$1|cē kilobyte|$1 kilobyte}}, tzonēhua {{PLURAL:$2|cē kilobyte|$2 kilobyte}}. Ahmo mopiyāz.'''",
 'templatesused'                    => '{{PLURAL:$1|Nemachiòtl tlèn motekìuhtia|Nemachiòmë tlèn mokìntekìuhtiä}} ìpan inìn tlaìxtlapalli:',
 'templatesusedpreview'             => '{{PLURAL:$1|Nemachiòtl tlèn motekìuhtia|Nemachiòmë tlèn mokìntekìuhtiä}} ìpan inìn achtochìwalistli:',
 'templatesusedsection'             => '{{PLURAL:$1|Nemachiòtl tlèn motekìuhtia|Nemachiòmë tlèn mokìntekìuhtiä}} ìpan inìn tlaxélòlistli:',
@@ -574,13 +572,6 @@ Hueliz ōmopolo huiqui nozo ōmozacac.
 'revdel-restore'             => 'Ticpatlāz tlattaliztli',
 'pagehist'                   => 'Zāzanilli tlahcuilōlloh',
 'deletedhist'                => 'Ōtlapolo tlahcuilōlloh',
-'revdelete-content'          => 'tlapiyaliztli',
-'revdelete-summary'          => 'ticpatlāz tlahcuilōltōn',
-'revdelete-uname'            => 'tlatēquitiltilīltōcāitl',
-'revdelete-hid'              => 'xictlātia $1',
-'revdelete-unhid'            => 'tiquittāz $1',
-'revdelete-log-message'      => '$1 ic $2 {{PLURAL:$2|tlachiyaliztli|tlachiyaliztli}}',
-'logdelete-log-message'      => '$1 īhuīc $2 {{PLURAL:$2|tlachīhualiztli|tlachīhualiztli}}',
 'revdelete-edit-reasonlist'  => 'Tiquimpatlāz īxtlamatiliztli tlapoloaliztechcopa',
 
 # History merging
@@ -917,7 +908,7 @@ Timitztlātlauhtiah, xitlahcuiloa occē tōcāitl.",
 'statistics-views-peredit' => 'Tlahpololiztli ic tlapatlaliztli',
 
 'disambiguations'     => 'Āmatl tlein motzonhuiliah īca tlahtōlmelāhuacātlāliztli āmatl',
-'disambiguationspage' => 'Template:Tlahtōlmelāhuacātlāliztli',
+'disambiguationspage' => 'Template:Tlahtōlmelāhuacātlālīliztli',
 
 'doubleredirects' => 'Ōntetl tlacuepaliztli',
 
@@ -1008,17 +999,13 @@ Nò mà mỏta in tlèn [[Special:WantedCategories|ìpan kineki tlaìxmatkàtlà
 # Special:ListUsers
 'listusers-submit' => 'Tiquittāz',
 
-# Special:Log/newusers
-'newuserlog-create-entry'  => 'Yancuīc tlatequitiltilīlli',
-'newuserlog-create2-entry' => 'Yancuīc cuenta ōmochīuh $1',
-
 # Special:ListGroupRights
 'listgrouprights-group'  => 'Olōlli',
 'listgrouprights-rights' => 'Huelītiliztli',
 
 # E-mail user
 'emailuser'       => 'Tique-mailīz inīn tlatequitiltilīlli',
-'defemailsubject' => '{{SITENAME}} e-mail',
+'defemailsubject' => '{{SITENAME}} correo tlatequitiltilīlhuīc $1',
 'emailfrom'       => 'Īhuīcpa:',
 'emailto'         => 'Īhuīc:',
 'emailmessage'    => 'Tlahcuilōltzintli:',
@@ -1083,7 +1070,6 @@ Tētlamachītīliztli īhuān oc yeh tēpalehuiliztli:
 'actioncomplete'         => 'Cēntetl',
 'deletedtext'            => '"$1" ōmopolo.
 Xiquitta $2 ic yancuīc tlapololiztli.',
-'deletedarticle'         => 'ōmopolo "[[$1]]"',
 'dellogpage'             => 'Tlapololiztli tlahcuilōlloh',
 'deletionlog'            => 'tlapololiztli tlahcuilōlloh',
 'deletecomment'          => 'Īxtlamatiliztli:',
@@ -1123,7 +1109,6 @@ Xiquitta $2 ic yancuīc tlapololiztli.',
 'undeletebtn'               => 'Ahticpolōz',
 'undeletelink'              => 'tiquittaz/ticpahtīz',
 'undeleteviewlink'          => 'tiquittāz',
-'undeletedarticle'          => 'ōticcualtilih "[[$1]]"',
 'undelete-search-box'       => 'Tiquintlatēmōz zāzaniltin ōmopolōz',
 'undelete-search-prefix'    => 'Tiquittāz zāzaniltin mopēhua īca:',
 'undelete-search-submit'    => 'Tlatēmōz',
@@ -1148,6 +1133,7 @@ Xiquitta $2 ic yancuīc tlapololiztli.',
 'sp-contributions-newbies-sub'   => 'Ic yancuīc',
 'sp-contributions-newbies-title' => 'Yancuīc tlatequitiltilīlli ītlahcuilōl',
 'sp-contributions-blocklog'      => 'Tlatzacuiliztli tlahcuilōlloh',
+'sp-contributions-uploads'       => 'tlahcuilōlquetzaliztli',
 'sp-contributions-talk'          => 'tēixnāmiquiliztli',
 'sp-contributions-search'        => 'Tiquintlatēmōz tlapatlaliztli',
 'sp-contributions-username'      => 'IP nozo tlatequitiltilīlli ītōcā:',
@@ -1223,8 +1209,6 @@ Hueliz cah inīn huēyi tlapatlaliztli. Timitztlātlauhtia ticmatīz cuallōtl a
 'movetalk'                  => 'Ticzacāz nō tēixnāmiquiliztli tlahcuilōltechcopa.',
 'movepage-page-moved'       => 'Zāzanilli $1 ōmozacac īhuīc $2.',
 'movepage-page-unmoved'     => 'Ahmo huelīti $1 mozaca īhuīc $2.',
-'1movedto2'                 => '[[$1]] ōmozacac īhuīc [[$2]]',
-'1movedto2_redir'           => '[[$1]] ōmozacac īhuīc [[$2]] tlacuepalpampa',
 'movelogpage'               => 'Tlazacaliztli tlahcuilōlloh',
 'movereason'                => 'Īxtlamatiliztli:',
 'revertmove'                => 'tlacuepāz',
@@ -1253,7 +1237,7 @@ Hueliz cah inīn huēyi tlapatlaliztli. Timitztlātlauhtia ticmatīz cuallōtl a
 
 # Thumbnails
 'thumbnail-more'  => 'Tiquihuēyiyāz',
-'thumbnail_error' => 'Ahcuallōtl ihcuāc mochīhuaya tepitōntli: $1',
+'thumbnail_error' => 'Aiuhcāyōtl ihcuāc mochīhuaya tepitōntli: $1',
 
 # Special:Import
 'import'                  => 'Tiquincōhuāz zāzaniltin',
@@ -1339,9 +1323,9 @@ Hueliz cah inīn huēyi tlapatlaliztli. Timitztlātlauhtia ticmatīz cuallōtl a
 'nextdiff'     => 'Oc ye cencah yancuīc tlapatlaliztli →',
 
 # Media information
-'widthheightpage' => '$1×$2, $3 {{PLURAL:|zāzanilli|zāzanilli}}',
+'widthheightpage' => '$1 × $2, $3 {{PLURAL:|zāzanilli|zāzanilli}}',
 'file-info-size'  => '$1 × $2 pixel; zāzanilli octacayōtl: $3; machiyōtl MIME: $4',
-'file-nohires'    => '<small>Ahmo ia achi cualli ahmo occē īxiptli.</small>',
+'file-nohires'    => 'Ahmo ia achi cualli ahmo occē īxiptli.',
 'show-big-image'  => 'Mochi cuallōtl',
 
 # Special:NewFiles
@@ -1434,9 +1418,6 @@ Niman tihuelīti [[Special:UserLogin|timocalaqui]] auh ticpactiāz huiquitica.',
 # Scary transclusion
 'scarytranscludetoolong' => '[In URL achi huel huēiyac ca]',
 
-# Trackbacks
-'trackbackremove' => '([$1 Ticpolōz])',
-
 # Delete conflict
 'recreate' => 'Ticchīhuāz occeppa',
 
@@ -1502,9 +1483,9 @@ Niman tihuelīti [[Special:UserLogin|timocalaqui]] auh ticpactiāz huiquitica.',
 # Special:SpecialPages
 'specialpages'                 => 'Nònkuâkìskàtlaìxtlapaltìn',
 'specialpages-note'            => '----
-* Kèn sanỉman nònkuâkìskàtlaìxtlapaltìn.
-* <span class="mw-specialpagerestricted>Âmò tlakàwiltìn nònkuâkìskàtlaìxtlapaltìn.</span>
-* <span class="mw-specialpagecached">Tlatlaìxkopìnèuhtìn nònkuâkìskàtlaìxtlapaltìn.</span>',
+* Yeliztli nōncuahquīzqui āmatl.
+* <span class="mw-specialpagerestricted">Tlaquīxtīlli nōncuahquīzqui āmatl.</span>
+* <span class="mw-specialpagecached">Tlatlātīlli nōncuahquīzqui āmatl (aocmo monemitīa).</span>',
 'specialpages-group-other'     => 'Oksẻki nònkuâkìskàtlaìxtlapaltìn',
 'specialpages-group-login'     => 'Ximocalaqui / ximomachiyōmaca',
 'specialpages-group-changes'   => 'Yancuīc tlapatlaliztli īhuān tlahcuilōlloh',
