@@ -7,6 +7,7 @@
  * @ingroup Language
  * @file
  *
+ * @author Kaganer
  * @author Mohau
  * @author Urhixidur
  */
@@ -31,14 +32,14 @@ $namespaceNames = array(
 );
 
 $magicWords = array(
-	'currentmonth'          => array( '1', 'KGWEDI_BJALE', 'CURRENTMONTH', 'CURRENTMONTH2' ),
-	'currentmonthname'      => array( '1', 'LEINA_KGWEDI_BJALE', 'CURRENTMONTHNAME' ),
-	'currentday'            => array( '1', 'LEHONO_LETSATSI', 'CURRENTDAY' ),
-	'currentday2'           => array( '1', 'LEHONO_LETSATSI2', 'CURRENTDAY2' ),
-	'currentdayname'        => array( '1', 'LEHONO_LETSATSILEINA', 'CURRENTDAYNAME' ),
-	'currentyear'           => array( '1', 'NGWAGA_BJALE', 'CURRENTYEAR' ),
-	'currenttime'           => array( '1', 'NAKO_BJALE', 'CURRENTTIME' ),
-	'currenthour'           => array( '1', 'IRI_BJALE', 'CURRENTHOUR' ),
+	'currentmonth'            => array( '1', 'KGWEDI_BJALE', 'CURRENTMONTH', 'CURRENTMONTH2' ),
+	'currentmonthname'        => array( '1', 'LEINA_KGWEDI_BJALE', 'CURRENTMONTHNAME' ),
+	'currentday'              => array( '1', 'LEHONO_LETSATSI', 'CURRENTDAY' ),
+	'currentday2'             => array( '1', 'LEHONO_LETSATSI2', 'CURRENTDAY2' ),
+	'currentdayname'          => array( '1', 'LEHONO_LETSATSILEINA', 'CURRENTDAYNAME' ),
+	'currentyear'             => array( '1', 'NGWAGA_BJALE', 'CURRENTYEAR' ),
+	'currenttime'             => array( '1', 'NAKO_BJALE', 'CURRENTTIME' ),
+	'currenthour'             => array( '1', 'IRI_BJALE', 'CURRENTHOUR' ),
 );
 
 $messages = array(
@@ -312,7 +313,6 @@ Bega se go  [[Special:ListUsers/sysop|administrator]], o fana ka URL.',
 'badtitle'           => 'Taetlile ya bošula',
 'badtitletext'       => 'Letlakala le ga la dumelelwa, ga le na ditlhaka, goba hlomaganyo ya bogare-dipolelo goba bogare-wiki taetlele ga ya loka. Ekaba mohlomong taetlele enale hlaka goba dihlaka tšago sedumelelwe.',
 'viewsource'         => 'Lebelela mothopo',
-'viewsourcefor'      => 'ya $1',
 'protectedpagetext'  => 'Letlakala le le notletšwe go thibela diphetogo.',
 'viewsourcetext'     => 'O ka lebelela goba wa kôpiša mothapo wa letlakala le:',
 'namespaceprotected' => "Ga ona tokelo ya go fetola matlakala  go  '''$1''' .",
@@ -434,8 +434,6 @@ O ka se kgone go šumiša thulusu ya 'romela mošomiši molaetša' ka ntle gage
 [[Special:Preferences|dikgatlhegelo]] gape ge o sa thibelwa go e šomiša.
 IP atrese ya gago ke $3, ge ID ya go thiba ele #$5. Ka kgopelo šumiša ID le IP go dipoledišano ka moka tšeo dilego mabapi le go go thiba.",
 'blockednoreason'                  => 'gago lebaka leo le filwego',
-'blockedoriginalsource'            => "Mothopo wa '''$1''' oa botšhwa tlase:",
-'whitelistedittitle'               => 'O swanela ke go tsena go fetola',
 'whitelistedittext'                => 'O swanela ke go $1 go fetola matlakala.',
 'confirmedittext'                  => 'E-mail e swanetše ke go tiišetšwa pele ge o ka fetola matlakala. Ka kgopelo, tiišetša e-mail atrese ya gago go [[Special:Preferences|dikgatlhego tša mošomiši]].',
 'nosuchsectiontitle'               => 'Sekgao ga se humanege',
@@ -529,15 +527,11 @@ Leka [[Special:Search|go fetleka wikii]] go humana matlakala a mapsha.',
 'rev-delundel'           => 'Bontšha/Fihla',
 'revdelete-hide-text'    => 'Fihla dihlaka tša poeletšo',
 'revdelete-log'          => 'Lebaka:',
-'revdelete-logentry'     => 'dipheto tša dipušeletšo tša ponagalo ya "[[$1]]"',
 'revdel-restore'         => '
 fetola tshenolo',
 'revdel-restore-deleted' => 'pušeletšo tšago phumulwa',
 'revdel-restore-visible' => 'pušeletšo tšago bonagala',
 'pagehist'               => 'Histori ya letlakala',
-'revdelete-content'      => 'mateng',
-'revdelete-hid'          => 'fihlilwe $1',
-'revdelete-log-message'  => '$1 ya $2 {{PLURAL:$2|pušeletšo|ya dipušeletšo}}',
 
 # History merging
 'mergehistory-from'   => 'Letlakala la mothopo:',
@@ -638,7 +632,7 @@ Ga re fane ka e-poso ya gago go bašumiši ba bangwe ge ba polela le wena ka yon
 
 # User rights
 'editusergroup'            => 'Fetola sehlopha sa bašomiši',
-'editinguser'              => "Fetola mošomiši '''[[User:$1|$1]]''' ([[User talk:$1|{{int:talkpagelinktext}}]] | [[Special:Contributions/$1|{{int:contribslink}}]])",
+'editinguser'              => "O fetola mošomiši '''[[User:$1|$1]]''' $2",
 'userrights-editusergroup' => 'Fetola sehlopha sa bašomiši',
 'saveusergroups'           => 'Boloko Dihlopha tša bašomiši',
 'userrights-groupsmember'  => 'Leloko la:',
@@ -734,7 +728,7 @@ Matlakala ago ba [[Special:Watchlist|lenanong la gago la matlakala ditlhapetšo]
 'filehist'                  => 'Histori ya faele',
 'filehist-help'             => 'Pinyeletša go letšatšikgwedi/nako go bona faela ka tsela yeo ebego e le ka gona nakong yeo.',
 'filehist-deleteall'        => 'phumula ka moka',
-'filehist-deleteone'        => 'phumula ye',
+'filehist-deleteone'        => 'phumula',
 'filehist-revert'           => 'bušetša',
 'filehist-current'          => 'bjale',
 'filehist-datetime'         => 'LetšatšiKgwedi/Nako',
@@ -753,7 +747,7 @@ Matlakala ago ba [[Special:Watchlist|lenanong la gago la matlakala ditlhapetšo]
 'uploadnewversion-linktext' => 'Lokela peoletšo ye mphsa ya faele',
 
 # File reversion
-'filerevert-comment'        => 'Ahlaahla:',
+'filerevert-comment'        => 'Lebaka:',
 'filerevert-defaultcomment' => 'Boela go poeletšo ya go tloga go $2, $1',
 
 # File deletion
@@ -874,8 +868,7 @@ Matlakala ago ba [[Special:Watchlist|lenanong la gago la matlakala ditlhapetšo]
 'listusers-submit' => 'Bontšha',
 
 # Special:Log/newusers
-'newuserlogpage'          => '"Log" yago hlola mošumiši',
-'newuserlog-create-entry' => 'Tšhupaleloko ya mošumiši ye mphsa',
+'newuserlogpage' => '"Log" yago hlola mošumiši',
 
 # Special:ListGroupRights
 'listgrouprights-members' => '(Lenano la ditho)',
@@ -926,14 +919,13 @@ Ga eba o nyaka go hloša letlaka le go lenano la ditlhapetšo tša gago, šomiš
 'deletepage'            => 'Phumula letlakala',
 'excontent'             => "mateng ebe e le: '$1'",
 'delete-legend'         => 'Phumula',
-'historywarning'        => 'Temošo: Letlakala leo o lekago go lephumula le nale histori:',
+'historywarning'        => "'''Temošo:''' Letlakala leo o lekago go lephumula le nale histori le {{:$1|phetogo|diphetogo}}:",
 'confirmdeletetext'     => 'O phumula letlakala le histori ka moka ya lona.
 Ka kgopela sitlediša gore ke se o nyakago  go sedira, le gore o kwešiša ditla morago tša se, le gore seo o se dirago se latela melawana le ditaelo go ya ka [[{{MediaWiki:Policy-url}}|polisi]].',
 'actioncomplete'        => 'Kgopelo e phetilwe ka katlego',
 'actionfailed'          => 'Tiro e padile',
 'deletedtext'           => '"$1" e phumutšwe.
 Lebelela $2 go hweetša sedi ka diphulo tša bjale.',
-'deletedarticle'        => 'E phumutšwe "[[$1]]"',
 'dellogpage'            => "''Log'' yago phumula",
 'deletecomment'         => 'Lebaka:',
 'deleteotherreason'     => 'Mabaka a mangwe:',
@@ -980,8 +972,7 @@ Seemo sa go lota ga letlakala '''$1''':",
 'undeletebtn'            => 'Hlaphola',
 'undeletelink'           => 'Nyakorela/hlaphola',
 'undeleteviewlink'       => 'ponagalo',
-'undeletecomment'        => 'Ahlaahla:',
-'undeletedarticle'       => 'hlaphola "[[$1]]"',
+'undeletecomment'        => 'Lebaka:',
 'undelete-search-prefix' => 'Laetśa matlakala a go thoma ka:',
 'undelete-search-submit' => 'Fetleka',
 
@@ -1084,8 +1075,6 @@ Ka kgopelo, kgetha leina le lengwe.',
 'talkexists'              => "'''Letlakala le hudugile ka katlego, efele letlakala la dipolešano ga la huduga kage gobe go ina letlakala leineng le lemphsa. Ka kgopelo, a gahlanye ka bowena.'''",
 'movedto'                 => 'hudugetše go',
 'movetalk'                => 'Huduša letlakala la dipoledišano la go hlobana le letlakala le',
-'1movedto2'               => '[[$1]] e hudugile goya go [[$2]]',
-'1movedto2_redir'         => 'hudušitše [[$1]] go [[$2]] godimo ga "redirect"',
 'movelogpage'             => "''log'' yago huduša",
 'movereason'              => 'Lebaka:',
 'revertmove'              => 'bušetša',
@@ -1173,11 +1162,7 @@ Ka kgopelo, kgetha leina le lengwe.',
 'siteuser'         => '{{SITENAME}} mošumiši $1',
 'lastmodifiedatby' => 'Letlakala le  fetotšwe la mafelelo ka $2, $1 ke $3.',
 'others'           => 'tše dingwe',
-'siteusers'        => '{{SITENAME}} mošumiši/bašumiši $1',
-
-# Patrol log
-'patrol-log-line' => 'maraka $1 ya $2 "patrolwa" ke $3',
-'patrol-log-diff' => 'Pušeletšo $1',
+'siteusers'        => '{{SITENAME}} {{PLURAL:$2|mošumiši|bašumiši}} $1',
 
 # Image deletion
 'filedeleteerror-short' => 'Phošo go phumuleng faele: $1',
@@ -1191,9 +1176,9 @@ $1',
 'nextdiff'     => 'Diphapano tše dimpšha →',
 
 # Media information
-'widthheightpage' => '$1×$2, $3 {{PLURAL:$3|letlakala|matlakala}}',
+'widthheightpage' => '$1 × $2, $3 {{PLURAL:$3|letlakala|matlakala}}',
 'file-info-size'  => '$1 × $2 pixel, bogolo ba faele: $3, Mohuta wa MIME: $4',
-'file-nohires'    => "<small>Gago ''resolution'' ya go feta mo.</small>",
+'file-nohires'    => "Gago ''resolution'' ya go feta mo.",
 'svg-long-desc'   => 'SVG faele, nominally $1 × $2 pixels, bogolo ba faele: $3',
 'show-big-image'  => "''resolution'' ya gofella",
 
