@@ -17,16 +17,16 @@
 $fallback = 'ru';
 
 $namespaceNames = array(
-	NS_MEDIA            => 'Media',
+	NS_MEDIA            => 'Медиа',
 	NS_SPECIAL          => 'Сæрмагонд',
 	NS_TALK             => 'Тæрхон',
 	NS_USER             => 'Архайæг',
 	NS_USER_TALK        => 'Архайæджы_ныхас',
-	NS_PROJECT_TALK     => 'Дискусси_$1',
-	NS_FILE             => 'Ныв',
-	NS_FILE_TALK        => 'Нывы_тæрхон',
+	NS_PROJECT_TALK     => '{{GRAMMAR:genitive|$1}}_тæрхон',
+	NS_FILE             => 'Файл',
+	NS_FILE_TALK        => 'Файлы_тæрхон',
 	NS_MEDIAWIKI        => 'MediaWiki',
-	NS_MEDIAWIKI_TALK   => 'Тæрхон_MediaWiki',
+	NS_MEDIAWIKI_TALK   => 'MediaWiki-йы_тæрхон',
 	NS_TEMPLATE         => 'Шаблон',
 	NS_TEMPLATE_TALK    => 'Шаблоны_тæрхон',
 	NS_HELP             => 'Æххуыс',
@@ -38,18 +38,24 @@ $namespaceNames = array(
 $namespaceAliases = array(
 	'Дискусси'                    => NS_TALK,
 	'Архайæджы_дискусси'          => NS_USER_TALK,
+	'Дискусси_$1'                 => NS_PROJECT_TALK,
+	'Ныв'                         => NS_FILE,
+	'Нывы_тæрхон'                 => NS_FILE_TALK,
 	'Нывы_тыххæй_дискусси'        => NS_FILE_TALK,
 	'Дискусси_MediaWiki'          => NS_MEDIAWIKI_TALK,
+	'Тæрхон_MediaWiki'            => NS_MEDIAWIKI_TALK,
 	'Шаблоны_тыххæй_дискусси'     => NS_TEMPLATE_TALK,
 	'Æххуысы_тыххæй_дискусси'     => NS_HELP_TALK,
 	'Категорийы_тыххæй_дискусси'  => NS_CATEGORY_TALK,
 );
 
+// Remove Russian aliases
+$namespaceGenderAliases = array();
 
 $magicWords = array(
-	'redirect'              => array( '0', '#РАРВЫСТ', '#перенаправление', '#перенапр', '#REDIRECT' ),
-	'img_right'             => array( '1', 'рахиз', 'справа', 'right' ),
-	'img_left'              => array( '1', 'галиу', 'слева', 'left' ),
+	'redirect'                => array( '0', '#РАРВЫСТ', '#перенаправление', '#перенапр', '#REDIRECT' ),
+	'img_right'               => array( '1', 'рахиз', 'справа', 'right' ),
+	'img_left'                => array( '1', 'галиу', 'слева', 'left' ),
 );
 
 $linkTrail = '/^((?:[a-z]|а|æ|б|в|г|д|е|ё|ж|з|и|й|к|л|м|н|о|п|р|с|т|у|ф|х|ц|ч|ш|щ|ъ|ы|ь|э|ю|я|“|»)+)(.*)$/sDu';
@@ -58,31 +64,40 @@ $fallback8bitEncoding =  'windows-1251';
 $messages = array(
 # User preference toggles
 'tog-underline'               => 'Æрвитæнты бын хахх',
+'tog-highlightbroken'         => 'Нысан кæнын саст æрвитæнтæ <a href="" class="new">куыд ай</a> (кæнæ та афтæ<a href="" class="internal">?</a>)',
 'tog-justify'                 => 'Æмвæз абзацтæ',
 'tog-hideminor'               => 'Чысыл ивддзинæдтæ фæстаг ивддзинæдты номхыгъды мауал æвдис',
+'tog-hidepatrolled'           => 'Айсын бæрæггонд ивдтытæ фæстаг ивдтытæй',
 'tog-newpageshidepatrolled'   => 'Басгæрст фæрстæ ног фæрсты номхыгъдæй æмбæхс',
+'tog-extendwatchlist'         => 'Стырдæр цæстдард номхыгъд алы ивдимæ дæр, æрмæст фæстагимæ нал.',
+'tog-usenewrc'                => 'Хуыздæр фæстаг ивдтыты номхыгъд (домы JavaScript)',
 'tog-numberheadings'          => 'Сæргæндты автоматикон нумераци',
+'tog-showtoolbar'             => 'Æвдисын ивыны панел (домы JavaScript)',
 'tog-editondblclick'          => 'Фæрстæ дыкъæппæй ив (JavaScript)',
 'tog-editsection'             => 'Равдис «баив æй» æрвитæн тексты алы хайы дæр',
 'tog-editsectiononrightclick' => 'Сæргондыл рахиз æркъæппæй фарсы хæйттæ ив (JavaScript)',
 'tog-showtoc'                 => 'Сæргæндты номхыгъд æвдис (æртæ сæргондæй фылдæр цы фарсы ис, уым)',
-'tog-rememberpassword'        => 'Системæ бахъуыды кæнæд мæ пароль ацы компьютерыл ($1 бонæй къаддæр æмгъуыдмæ)',
+'tog-rememberpassword'        => 'Бахъуыды мæ кæнæд ацы браузер ($1 {{PLURAL:$1|бонмæ|бонмæ}})',
 'tog-watchcreations'          => 'Æз цы фæрстæ райдайын, уыдонмæ мæ цæст дарын мæ фæнды',
 'tog-watchdefault'            => 'Æз цы фæрстæ ивын, уыдонмæ мæ цæст дарын мæ фæнды',
 'tog-watchmoves'              => 'Æз цы фæрсты нæмттæ ивын, уыдонмæ мæ цæст дарын мæ фæнды',
 'tog-watchdeletion'           => 'Æз цы фæрстæ аппарын, уыдонмæ мæ цæст дарын мæ фæнды',
 'tog-minordefault'            => 'Æппæт ивддзинæдтæ банысан кæн куыд чысылтæ',
 'tog-previewontop'            => 'Разæркасты рудзынг ивыны рудзынджы уæлдæр',
+'tog-nocache'                 => 'Ахицæн кæнын браузеры кешкæнынад',
 'tog-enotifwatchlistpages'    => 'Электронон постæй мæм хъуысынгæнинаг æрвыст уа, æз цы фæрстæм мæ цæст дарын, уыдонæй иу куы ивд æрцæуа, уæд',
 'tog-enotifusertalkpages'     => 'Электронон постæй мæм хъуысынгæнинаг æрвыст уа, мæ тæрхоны фарс куы ивд æрцæуа, уæд',
 'tog-enotifminoredits'        => 'Кæд ивддзинад чысыл у, уæддæр мæм электронон фыстæг æрбацæуа',
+'tog-enotifrevealaddr'        => 'Æвдисын мæ e-mail хъусын кæныны фыстæджыты',
 'tog-shownumberswatching'     => 'Цал архайæджы фарсмæ сæ цæст дарынц, уый равдис',
 'tog-oldsig'                  => 'Ныры къухæрфыст:',
+'tog-fancysig'                => 'Сæвæрын къухæрфыст викитекстæй (æнæ хæдæвзæргæ æрвитæнæй)',
+'tog-externaleditor'          => 'Архайын æддаг ивæнæй (æрмæст эксперттæн, домы сæрмагонд æвæрдтытæ компьютерыл. [//www.mediawiki.org/wiki/Manual:External_editors Лæмбынæг.])',
 'tog-showjumplinks'           => 'Тагъд æрвитæнтæй пайда кæн',
-'tog-watchlisthideown'        => 'Мæ цæстдарды номхыгъды, мæхæдæг цы ивддзинæдтæ бахæстон, уыдон бамбæхс',
+'tog-watchlisthideown'        => 'Айсын мæ ивдтытæ цæстдардæй',
 'tog-watchlisthidebots'       => 'Мæ цæстдарды номхыгъды роботты куыст бамбæхс',
 'tog-watchlisthideminor'      => 'Мæ цæстдарды номхыгъды чысыл ивддзинæдтæ бамбæхс',
-'tog-watchlisthidepatrolled'  => 'Басгæрст ивддзинæдтæ, дæ цæст кæмæ дарыс, уыцы номхыгъды ма ’вдис',
+'tog-watchlisthidepatrolled'  => 'Айсын сгæрст ивдтытæ цæстдардæй',
 'tog-ccmeonemails'            => 'Æз электронон фыстæг æндæр архайæгæн куы рарвитын, уæд уыцы иу фыстæг мæхи адрисмæ дæр æрбацæуæд.',
 'tog-showhiddencats'          => 'Æмбæхст категоритæ æвдис',
 
@@ -169,7 +184,7 @@ $messages = array(
 'newwindow'     => '(кæны ног рудзынджы)',
 'cancel'        => 'Ныууадзын',
 'moredotdotdot' => 'Фылдæр…',
-'mypage'        => 'Дæхи фарс',
+'mypage'        => 'Мæ фарс',
 'mytalk'        => 'Мæ ныхас',
 'anontalk'      => 'Ацы IP-адрисы тæрхон',
 'navigation'    => 'Навигаци',
@@ -184,12 +199,14 @@ $messages = array(
 'qbmyoptions'    => 'Мæ фæрстæ',
 'qbspecialpages' => 'Сæрмагонд фæрстæ',
 'faq'            => 'FAQ',
+'faqpage'        => 'Project:FAQ',
 
 # Vector skin
 'vector-action-addsection' => 'Нæуæг ныхас бакæнын',
 'vector-action-delete'     => 'Аппарын',
 'vector-action-move'       => 'Ном ивын',
 'vector-action-protect'    => 'Сæхгæнын',
+'vector-action-undelete'   => 'Рацаразын',
 'vector-view-create'       => 'Скæнын',
 'vector-view-edit'         => 'Ивын',
 'vector-view-history'      => 'Истори',
@@ -219,11 +236,12 @@ $messages = array(
 'create-this-page'  => 'Ацы фарс скæнын',
 'delete'            => 'Аппар',
 'deletethispage'    => 'Аппарын ацы фарс',
+'undelete_short'    => 'Рацаразын {{PLURAL:$1|иу ивд|$1 ивды}}',
 'protect'           => 'Сæхгæнын',
 'protect_change'    => 'баивын',
 'protectthispage'   => 'Сæхгæн ацы фарс',
-'unprotect'         => 'Мауал хъахъхъæн',
-'unprotectthispage' => 'Ацы фарс ивынмæ байгом',
+'unprotect'         => 'Ивын хъахъхъæд',
+'unprotectthispage' => 'Ивын ацы фарсы хъахъхъæд',
 'newpage'           => 'Ног фарс',
 'talkpage'          => 'Ацы фарсы тыххæй ныхас',
 'talkpagelinktext'  => 'Ныхас',
@@ -261,7 +279,7 @@ $messages = array(
 'currentevents-url'    => 'Project:Xabar',
 'disclaimers'          => 'Бæрн нæ исыны тыххæй',
 'disclaimerpage'       => 'Project:Нæ бæрн исыны тыххæй',
-'edithelp'             => 'Ивын æххуыс',
+'edithelp'             => 'Ивынæн æххуыс',
 'edithelppage'         => 'Help:Ивд',
 'helppage'             => 'Help:Сæргæндтæ',
 'mainpage'             => 'Сæйраг фарс',
@@ -289,7 +307,7 @@ $messages = array(
 'viewsourcelink'      => 'Код кæсын',
 'editsectionhint'     => 'Ив хай: $1',
 'toc'                 => 'Сæргæндтæ',
-'showtoc'             => 'равдис',
+'showtoc'             => 'равдисын',
 'hidetoc'             => 'бамбæхсын',
 'viewdeleted'         => '$1 фенын дæ фæнды?',
 'feedlinks'           => 'Лæсæн:',
@@ -305,7 +323,7 @@ $messages = array(
 'nstab-media'     => 'Мультимеди',
 'nstab-special'   => 'Сæрмагонд фарс',
 'nstab-project'   => 'Проекты тыххæй',
-'nstab-image'     => 'Ныв',
+'nstab-image'     => 'Файл',
 'nstab-mediawiki' => 'Фыстæг',
 'nstab-template'  => 'Шаблон',
 'nstab-help'      => 'Æххуысы фарс',
@@ -319,8 +337,8 @@ $messages = array(
 
 # General errors
 'error'                => 'Рæдыд',
-'databaseerror'        => 'Бæрæггæнæнты базæйы рæдыд',
-'readonly'             => 'Бæрæггæнæнты базæ фыссынæн æхгæд у',
+'databaseerror'        => 'Рарддоны рæдыд',
+'readonly'             => 'Рарддон æхгæд у',
 'missingarticle-rev'   => '(фæлтæр № $1)',
 'missingarticle-diff'  => '(хъауджы: $1, $2)',
 'internalerror'        => 'Мидæг рæдыд',
@@ -335,7 +353,6 @@ $messages = array(
 Æндæр исчи йæ аппæрста мыййаг.',
 'badtitle'             => 'Æнæмбæлон сæргонд',
 'viewsource'           => 'Код кæсын',
-'viewsourcefor'        => 'Фарс «$1»',
 'protectedpagetext'    => 'Ацы фарс у ивынæй æхгæд.',
 'viewsourcetext'       => 'Ацы фарсы код фенæн æмæ халдих кæнæн ис:',
 'ns-specialprotected'  => 'Сæрмагонд фæрстæ ({{ns:special}}) баивæн нæй.',
@@ -350,10 +367,11 @@ $messages = array(
 'yourpasswordagain'       => 'Дæ пароль иу хатт ма:',
 'remembermypassword'      => 'Бахъуыды мæ кæнæд ашы браузеры (максимум $1 {{PLURAL:$1|бонмæ|бонмæ}})',
 'yourdomainname'          => 'Дæ домен:',
-'login'                   => 'Мæхи бацамонын',
+'login'                   => 'Бахизын',
 'nav-login-createaccount' => 'Бахизын / срегистраци кæнын',
 'loginprompt'             => 'Дæ cookies хъуамæ иу уой цæмæй дæ бон уа бахизын {{grammar:allative|{{SITENAME}}}}.',
 'userlogin'               => 'Бахизын / регистраци кæнын',
+'userloginnocreate'       => 'Бахизын',
 'logout'                  => 'Номсусæг суын',
 'userlogout'              => 'Рахизын',
 'notloggedin'             => 'Системæйæн дæхи нæ бацамыдтай',
@@ -364,12 +382,14 @@ $messages = array(
 'gotaccountlink'          => 'Бахизын',
 'userlogin-resetlink'     => 'Ферох дæ сты дæ бахизæнтæ?',
 'createaccountmail'       => 'адрисмæ гæсгæ',
+'createaccountreason'     => 'Бындур:',
 'badretype'               => 'Дыууæ хатты иу пароль хъуамæ ныффыстаис',
 'loginsuccess'            => "'''Ныр ды дæ хыст {{grammar:genitive|{{SITENAME}}}} куыд \"\$1\".'''",
-'nouserspecified'         => 'Дæхи бацамонын хъæуы: дæ архайæджы ном цы у.',
+'nouserspecified'         => 'Ды хъуамæ зæгъай дæ ном.',
 'wrongpassword'           => 'Цы пароль ныффыстай, уый раст нæу.
 Лæмбынæгæй ныффысс дæ пароль',
-'wrongpasswordempty'      => 'Пароль афтид уыд. Афтæ нæ баззы, ныффыс-ма исты пароль.',
+'wrongpasswordempty'      => 'Пароль афтид у.
+Бафæлвар ногæй.',
 'mailmypassword'          => 'Рарвит мæм ног пароль',
 'passwordremindertitle'   => 'Ног рæстæгмæ пароль {{grammar:dative|{{SITENAME}}}}',
 'noemail'                 => 'Архайæг $1 йæ электрон посты адрис нæ ныууагъта.',
@@ -392,6 +412,9 @@ $messages = array(
 'passwordreset-emailelement' => 'Архайæджы ном: $1
 Рæстæгмæ пароль: $2',
 
+# Special:ChangeEmail
+'changeemail-cancel' => 'Ныууадзын',
+
 # Edit page toolbar
 'bold_sample'     => 'Бæзджын текст',
 'bold_tip'        => 'Бæзджын текст',
@@ -411,22 +434,21 @@ $messages = array(
 'hr_tip'          => 'Горизонталон хахх (арæх дзы ма пайда кæн)',
 
 # Edit pages
-'summary'                          => 'Ивдтыты мидис:',
+'summary'                          => 'Бындур:',
 'subject'                          => 'Темæ/сæргонд:',
 'minoredit'                        => 'Ай чысыл ивд у.',
 'watchthis'                        => 'Цæст дарын ацы фарсмæ',
-'savearticle'                      => 'Фæивын',
+'savearticle'                      => 'Бавæрын',
 'preview'                          => 'Разæркаст',
-'showpreview'                      => 'Разбакаст равдисын',
+'showpreview'                      => 'Фенын',
 'showlivepreview'                  => 'Тагъд разæркаст',
-'showdiff'                         => 'Ивд æвдисын',
+'showdiff'                         => 'Иртасын',
 'anoneditwarning'                  => "'''Сындæггай:''' Ды системæйы нæ дæ.
 Дæ IP адрес фыст æрцæудзæнис фарсы историйы.",
 'summary-preview'                  => 'Ивд афыст уыдзæн:',
 'blockedtitle'                     => 'Архайæг хъодыгонд æрцыд',
 'blockednoreason'                  => 'аххос амынд не ’рцыд',
-'whitelistedittitle'               => 'Ацы текст ивынмæ хъуамæ дæхи бацамонай системæйæн',
-'loginreqtitle'                    => 'Хъуамæ дæхи бацамонай',
+'loginreqtitle'                    => 'Хъæуы бахизын',
 'accmailtitle'                     => 'Пароль рарвыст у.',
 'newarticle'                       => '(Ног)',
 'noarticletext'                    => 'Ацы фарсы нырмæ текст нæй.
@@ -439,10 +461,10 @@ $messages = array(
 'note'                             => "'''Бафиппай:'''",
 'previewnote'                      => "'''Зон æй, æмæ ай у æрмæстдæр разбакаст.'''
 Дæ ивдтытæ нырмæ æвæрд не рцыдысты!",
-'editing'                          => 'Ивыс: $1',
+'editing'                          => 'Ивд цæуы $1',
 'editingsection'                   => 'Ивыс $1 (фарсы хай)',
 'editconflict'                     => 'Ивыны конфликт: $1',
-'yourtext'                         => 'Дæхи текст',
+'yourtext'                         => 'Дæ текст',
 'yourdiff'                         => 'Хицæндзинæдтæ',
 'templatesused'                    => 'Ацы фарсы ис {{PLURAL:$1|шаблон|шаблоны}}:',
 'template-protected'               => '(æхгæд)',
@@ -497,10 +519,6 @@ $messages = array(
 'revdel-restore-deleted'    => 'хафт ивдтытæ',
 'revdel-restore-visible'    => 'зынгæ ивдтытæ',
 'pagehist'                  => 'Фарсы истори',
-'revdelete-content'         => 'мидис',
-'revdelete-summary'         => 'ивддзинады мидис',
-'revdelete-uname'           => 'архайæджы ном',
-'revdelete-hid'             => 'Ист $1',
 'revdelete-reasonotherlist' => 'Æндæр аххос',
 'revdelete-offender'        => 'Фарсы фæлтæры автор:',
 
@@ -569,43 +587,64 @@ $messages = array(
 
 # Preferences page
 'mypreferences'             => 'Мæ фадæттæ',
+'prefs-edits'               => 'Ивдтыты нымæц:',
 'prefsnologin'              => 'Системæйæн дæхи нæ бацамыдтай',
 'changepassword'            => 'Пароль ивæн',
+'prefs-skin'                => 'Фæлыст',
 'skin-preview'              => 'Разæркаст',
+'prefs-beta'                => 'Бета фадæттæ',
 'prefs-datetime'            => 'Датæ æмæ рæстæг',
-'prefs-watchlist'           => 'Дæ цæст кæмæ дарыс, уыцы фæрсты номхыгъд',
-'prefs-watchlist-days'      => 'Цал боны ивддзинæдтæ æвдисын:',
-'saveprefs'                 => 'Афтæ уæд',
-'rows'                      => 'Рæнхътæ:',
+'prefs-labs'                => 'Лабораторон фадæттæ',
+'prefs-personal'            => 'Архайæджы профил',
+'prefs-rc'                  => 'Фæстаг ивдтытæ',
+'prefs-watchlist'           => 'Цæстдард',
+'prefs-watchlist-days'      => 'Бонты бæрц æвдисынæн:',
+'prefs-misc'                => 'Æндæртæ',
+'prefs-rendering'           => 'Фæлгонц',
+'saveprefs'                 => 'Бавæрын',
+'prefs-editing'             => 'Ивын',
+'rows'                      => 'Рæнхъытæ:',
+'searchresultshead'         => 'Агуырд',
+'stub-threshold-disabled'   => 'Хицæн',
 'timezonelegend'            => 'Сахаты таг:',
 'localtime'                 => 'Бынæттон рæстæг:',
-'timezoneoffset'            => 'Хъауджыдæрдзинад',
+'timezoneuseserverdefault'  => 'Архайын серверы æвæрдæй ($1)',
+'timezoneuseoffset'         => 'Æндæр (бацамон гæпп)',
+'timezoneoffset'            => 'Гæпп¹:',
 'servertime'                => 'Серверы рæстæг:',
+'guesstimezone'             => 'Райсын браузерæй',
 'timezoneregion-africa'     => 'Африкæ',
 'timezoneregion-america'    => 'Америкæ',
 'timezoneregion-antarctica' => 'Антарктикæ',
 'timezoneregion-arctic'     => 'Арктикæ',
 'timezoneregion-asia'       => 'Ази',
+'timezoneregion-atlantic'   => 'Атлантикон Фурд',
 'timezoneregion-australia'  => 'Австрали',
 'timezoneregion-europe'     => 'Европæ',
 'timezoneregion-indian'     => 'Индийы фурд',
+'timezoneregion-pacific'    => 'Сабыр Фурд',
+'prefs-searchoptions'       => 'Агурыны фадæттæ',
 'prefs-namespaces'          => 'Номдæттæ',
+'prefs-files'               => 'Файлтæ',
+'prefs-custom-css'          => 'Хиæвæрд CSS',
+'prefs-custom-js'           => 'Хиæвæрд JavaScript',
 'youremail'                 => 'E-mail:',
 'username'                  => 'Регистрацигонд ном:',
+'uid'                       => 'Архайæджы ID:',
 'yourrealname'              => 'Æцæг ном:',
 'yourlanguage'              => 'Техникон фыстыты æвзаг:',
-'yourvariant'               => 'Æвзаджы вариант:',
-'yournick'                  => 'Фæсномыг (къухæрфыстытæм):',
+'yourvariant'               => 'Мидисы æвзаджы вариант:',
+'yournick'                  => 'Ног къухæрфыст:',
 'badsiglength'              => 'Æгæр даргъ къухæрфыст, хъуамæ {{PLURAL:$1|дамгъæйæ|дамгъæйæ}} къаддæр уа.',
 'yourgender'                => 'Æрд:',
 'gender-male'               => 'нæлгоймаг',
 'gender-female'             => 'сылгоймаг',
-'email'                     => 'Эл. посты адрис',
+'email'                     => 'E-mail',
 'prefs-help-email'          => 'E-mail адрес фæндонæй у, фæлæ дæ дæ пароль куы ферох уа, уæд хъæуджæнис нæуæг пароль æвæрынæн.',
 'prefs-help-email-required' => 'Электронон посты адрис хъæуы.',
 
 # User rights
-'userrights-nodatabase' => 'Бæрæггæнæнты базæ $1 нæй кæнæ уый у бынæттон базæ.',
+'userrights-nodatabase' => 'Рарддон $1 нæй кæнæ бынæттон нæу.',
 
 # Groups
 'group'            => 'Къорд:',
@@ -615,37 +654,45 @@ $messages = array(
 'group-bureaucrat' => 'Бюрократтæ',
 'group-all'        => '(æппæт)',
 
-'group-user-member'       => 'архайæг',
-'group-bot-member'        => 'робот',
-'group-sysop-member'      => 'админ',
-'group-bureaucrat-member' => 'бюрократ',
+'group-user-member'          => '{{GENDER:$1|архайæг}}',
+'group-autoconfirmed-member' => '{{GENDER:$1|хæдсгарст архайæг}}',
+'group-bot-member'           => '{{GENDER:$1|бот}}',
+'group-sysop-member'         => '{{GENDER:$1|администратор}}',
+'group-bureaucrat-member'    => '{{GENDER:$1|бюрократ}}',
+'group-suppress-member'      => '{{GENDER:$1|радгæс}}',
 
-'grouppage-user'       => '{{ns:project}}:Архайджытæ',
-'grouppage-bot'        => '{{ns:project}}:Роботтæ',
-'grouppage-sysop'      => '{{ns:project}}:Админтæ',
-'grouppage-bureaucrat' => '{{ns:project}}:Бюрократтæ',
+'grouppage-user'          => '{{ns:project}}:Архайджытæ',
+'grouppage-autoconfirmed' => '{{ns:project}}:Хæдсгарст архайджытæ',
+'grouppage-bot'           => '{{ns:project}}:Роботтæ',
+'grouppage-sysop'         => '{{ns:project}}:Администратортæ',
+'grouppage-bureaucrat'    => '{{ns:project}}:Бюрократтæ',
+'grouppage-suppress'      => '{{ns:project}}:Радгæстæ',
 
 # Rights
-'right-read'          => 'фæрстæ кæсын',
-'right-edit'          => 'фæрстæ ивын',
-'right-move'          => 'фæрсты нæмттæ ивын',
+'right-read'          => 'Фæрстæ кæсын',
+'right-edit'          => 'Фæрстæ ивын',
+'right-move'          => 'Фæрсты нæмттæ ивын',
 'right-move-subpages' => 'фæрсты æмæ сæ дæлфæрсты нæмттæ ивын',
 'right-movefile'      => 'файлты нæмттæ ивын',
-'right-upload'        => 'файлтæ сæвæрын',
+'right-upload'        => 'Файлтæ æвгæнын',
 'right-upload_by_url' => 'Бавгæнын файлтæ интернетæй',
-'right-delete'        => 'фæрстæ аппарын',
+'right-delete'        => 'Фæрстæ хафын',
 'right-bigdelete'     => 'фæрстæ æмæ сæ ивды истори аппарын',
 
 # User rights log
 'rightsnone' => '(нæй)',
 
 # Associated actions - in the sentence "You do not have permission to X"
-'action-read'       => 'ацы фарс кæсын',
-'action-edit'       => 'ацы фарс ивын',
-'action-createpage' => 'фæрстæ скæн',
-'action-move'       => 'ацы фарсы ном ивын',
-'action-movefile'   => 'ацы файлы ном ивын',
-'action-delete'     => 'ацы фарс аппарын',
+'action-read'          => 'ацы фарс кæсын',
+'action-edit'          => 'ацы фарс ивын',
+'action-createpage'    => 'фæрстæ кæнын',
+'action-createtalk'    => 'тæрхоны фæрстæ кæнын',
+'action-createaccount' => 'ацы архайæджы ном аразын',
+'action-minoredit'     => 'ацы ивд чысылæй нысан кæнын',
+'action-move'          => 'ацы фарсы ном ивын',
+'action-movefile'      => 'ацы файлы ном ивын',
+'action-upload'        => 'ацы файл æвгæнын',
+'action-delete'        => 'ацы фарс аппарын',
 
 # Recent changes
 'nchanges'                        => '$1 {{PLURAL:$1|ивд|ивды}}',
@@ -663,6 +710,7 @@ $messages = array(
 'rcshowhidebots'                  => '$1 роботты куыст',
 'rcshowhideliu'                   => '$1, йæхи чи бацамыдта, уыцы архайджыты',
 'rcshowhideanons'                 => '$1 æнæном архайджыты',
+'rcshowhidepatr'                  => '$1 бæрæггонд ивдтæ',
 'rcshowhidemine'                  => '$1 мæ ивдтытæ',
 'rclinks'                         => 'Фæстаг $1 ивдтытæ (афæстаг $2 боны дæргъы чи ’рцыдысты) равдис;
 $3',
@@ -673,7 +721,9 @@ $3',
 'minoreditletter'                 => 'ч',
 'newpageletter'                   => 'Н',
 'boteditletter'                   => 'б',
-'rc-enhanced-expand'              => 'Лæмбынæг информаци равдисын (JavaScript хъæуы)',
+'rc_categories_any'               => 'Кæцы фæнды',
+'newsectionsummary'               => '/* $1 */ ног хай',
+'rc-enhanced-expand'              => 'Лæмбынæг информаци равдисын (домы JavaScript)',
 'rc-enhanced-hide'                => 'Айсын лæмбынæг информаци',
 
 # Recent changes linked
@@ -687,8 +737,8 @@ $3',
 'recentchangeslinked-to'       => 'Уый бæсты равдисæт амынд фарсмæ æрвитгæ фæрсты ивдтытæ',
 
 # Upload
-'upload'              => 'Ног файл сæвæр',
-'uploadbtn'           => 'Ног файл сæвæр',
+'upload'              => 'Бавгæнын файл',
+'uploadbtn'           => 'Файл бавгæнын',
 'uploadnologin'       => 'Системæйæн дæхи нæ бацамыдтай',
 'uploaderror'         => 'Файл сæвæрыны рæдыд',
 'uploadlogpage'       => 'Æвгæндты лог',
@@ -712,22 +762,27 @@ $3',
 'listfiles_thumb' => 'Къаддæргонд',
 
 # File description page
-'file-anchor-link'    => 'Ныв',
-'filehist'            => 'Файлы истори',
-'filehist-help'       => 'Ныххæц датæ/рæстæг-ыл, цæмæй фенай еуæд куыд фæзындис.',
-'filehist-revert'     => 'раивын',
-'filehist-current'    => 'нырыккон',
-'filehist-datetime'   => 'Датæ/рæстæг',
-'filehist-thumb'      => 'Къаддæргонд',
-'filehist-thumbtext'  => 'Къаддæргонд уыцы версийæн: $1',
-'filehist-nothumb'    => 'Нæй ын къаддæргонд',
-'filehist-user'       => 'Архайæг',
-'filehist-dimensions' => 'Барæнтæ',
-'filehist-filesize'   => 'Файлы бæрцуат',
-'filehist-comment'    => 'Фиппаинаг',
-'imagelinks'          => 'Æрвитæнтæ файлмæ',
-'linkstoimage'        => 'Ацы нывæй пайда {{PLURAL:$1|кæны иу фарс|кæнынц ахæм фæрстæ}}:',
-'nolinkstoimage'      => 'Нæй ахæм фæрстæ, кæдон æрвитынц ацы файлмæ.',
+'file-anchor-link'        => 'Файл',
+'filehist'                => 'Файлы истори',
+'filehist-help'           => 'Ныххæц датæ/рæстæг-ыл, цæмæй фенай еуæд куыд фæзындис.',
+'filehist-revert'         => 'раивын',
+'filehist-current'        => 'нырыккон',
+'filehist-datetime'       => 'Датæ/рæстæг',
+'filehist-thumb'          => 'Къаддæргонд',
+'filehist-thumbtext'      => 'Къаддæргонд уыцы версийæн: $1',
+'filehist-nothumb'        => 'Нæй ын къаддæргонд',
+'filehist-user'           => 'Архайæг',
+'filehist-dimensions'     => 'Барæнтæ',
+'filehist-filesize'       => 'Файлы бæрцуат',
+'filehist-comment'        => 'Фиппаинаг',
+'imagelinks'              => 'Æрвитæнтæ файлмæ',
+'linkstoimage'            => 'Ацы нывæй пайда {{PLURAL:$1|кæны иу фарс|кæнынц ахæм фæрстæ}}:',
+'nolinkstoimage'          => 'Нæй ахæм фæрстæ, кæдон æрвитынц ацы файлмæ.',
+'sharedupload'            => 'Ацы файл у {{grammar:ablative|$1}} æмæ дзы гæнæн ис æндæр проекттæ дæр архайой.',
+'sharedupload-desc-there' => 'Ацы файл у {{grammar:ablative|$1}} æмæ дзы гæнæн ис æндæр проекттæ дæр архайой.
+Кæс [$2 файлы афысты фарс] фылдæр базонынæн.',
+'sharedupload-desc-here'  => 'Ацы файл у {{grammar:ablative|$1}} æмæ дзы гæнæн ис æндæр проекттæ дæр архайой.
+[$2 Йæ фарсæй] афыст у æвдыст бындæр',
 
 # File deletion
 'filedelete-submit'           => 'Аппар',
@@ -776,7 +831,7 @@ $3',
 'longpages'              => 'Даргъ фæрстæ',
 'protectedpages'         => 'Æхгæд фæрстæ',
 'listusers'              => 'Архайджыты номхыгъд',
-'usercreated'            => 'Фæзындис $1, {{grammar:superessive|$2}}',
+'usercreated'            => '{{GENDER:$3|Фæзындис}} $1, {{grammar:superessive|$2}}',
 'newpages'               => 'Ног фæрстæ',
 'newpages-username'      => 'Архайæг:',
 'ancientpages'           => 'Зæронддæр фæрстæ',
@@ -790,8 +845,8 @@ $3',
 'booksources-go'            => 'Агурын',
 
 # Special:Log
-'specialloguserlabel'  => 'Архайæг:',
-'speciallogtitlelabel' => 'Сæргонд:',
+'specialloguserlabel'  => 'Гæнæг:',
+'speciallogtitlelabel' => 'Мил (ном кæнæ архайæг):',
 'log'                  => 'Логтæ',
 'all-logs-page'        => 'Иууылдæр логтæ',
 
@@ -814,7 +869,7 @@ $3',
 'special-categories-sort-abc'   => 'алфавитмæ гæсгæ равæр',
 
 # Special:LinkSearch
-'linksearch'      => 'Æддаг æрвитæнтæ',
+'linksearch'      => 'Æддаг æрвитæнтæ агурын',
 'linksearch-ns'   => 'Номдон:',
 'linksearch-ok'   => 'Агурын',
 'linksearch-line' => '$2 æрвиты {{grammar:allative|$1}}',
@@ -823,8 +878,7 @@ $3',
 'listusers-submit' => 'Равдисын',
 
 # Special:Log/newusers
-'newuserlogpage'          => 'Архайджыты фæзындты лог',
-'newuserlog-create-entry' => 'Ног архайæджы аккаунт',
+'newuserlogpage' => 'Архайджыты фæзындты лог',
 
 # Special:ListGroupRights
 'listgrouprights-group'   => 'Къорд',
@@ -841,14 +895,14 @@ $3',
 'watchlistfor2'     => 'Архайæг: $1 $2',
 'nowatchlist'       => 'Иу статьямæ дæр дæ цæст нæ дарыс.',
 'watchnologin'      => 'Системæйæн дæхи нæ бацамыдтай',
-'watchnologintext'  => 'Ацы номхыгъд ивынмæ [[Special:UserLogin|хъуамæ дæхи бацамонай системæйæн]].',
-'removedwatchtext'  => 'Фарсмæ «[[:$1]]» нал [[Special:Watchlist|дарыс дæ цæст]].',
+'watchnologintext'  => 'Ацы номхыгъд ивынæн хъæуы [[Special:UserLogin|бахизын]].',
+'removedwatchtext'  => '«[[:$1]]» фарсмæ [[Special:Watchlist|дæ цæст]] нал дарыс.',
 'watch'             => 'Цæст æрдарын',
 'watchthispage'     => 'Цæст дарын ацы фарсмæ',
 'unwatch'           => 'Нал дарын цæст',
-'watchnochange'     => 'Дæ цæст кæмæ дарыс, уыцы статьятæй иу дæр ивд не ’рцыди.',
+'watchnochange'     => 'Дæ цæстдард статьятæй иу дæр ивд не ’рцыдис.',
 'watchlist-details' => '{{PLURAL:$1|$1 фарсмæ|$1 фарсмæ}} дæ цæст дарыс, тæрхоны фæрстæ нæ нымайгæйæ.',
-'watchlistcontains' => 'Дæ цæст $1 фарсмæ дарыс.',
+'watchlistcontains' => 'Дæ цæст $1 {{PLURAL:$1|фарсмæ|фарсмæ}} дарыс.',
 'wlnote'            => "Дæлæ афæстаг '''$2 сахаты дæргъы''' цы $1 {{PLURAL:$1|ивддзинад|ивддзинады}} æрцыди.",
 'wlshowlast'        => 'Фæстæг $1 сахаты, $2 боны дæргъы; $3.',
 'watchlist-options' => 'Цæстдард рæгъы фадæттæ',
@@ -867,7 +921,6 @@ $3',
 'delete-confirm'        => 'Схаф "$1"',
 'actioncomplete'        => 'Æххæст',
 'actionfailed'          => 'Нæ рауадис',
-'deletedarticle'        => 'схафта "[[$1]]"',
 'dellogpage'            => 'Аппарыны лог',
 'deletionlog'           => 'аппарыны лог',
 'deletecomment'         => 'Аххос:',
@@ -878,9 +931,9 @@ $3',
 'rollbacklink' => 'раздæхын',
 
 # Protect
-'protectlogpage'         => 'Хъахъхъæндты лог',
-'protectedarticle'       => '«[[$1]]» — фарс æхгæд æрцыд',
-'prot_1movedto2'         => '[[$1]] хаст æрцыд [[$2]], зæгъгæ, ахæм фарсмæ',
+'protectlogpage'         => 'Хъахъхъæды лог',
+'protectedarticle'       => '«[[$1]]» фарс æхгæд æрцыд',
+'prot_1movedto2'         => '[[$1]] хаст æрцыд [[$2|{{grammar:allative|$2}}]]',
 'protectcomment'         => 'Аххос:',
 'protectexpiry'          => 'Кæдмæ æхгæд у:',
 'protect-level-sysop'    => 'Æрмæст админтæ',
@@ -949,7 +1002,7 @@ $3',
 'blockipsuccesstext'       => '[[Special:Contributions/$1|$1]] хъодыгонд æрцыд.<br />
 Кæс [[Special:Ipblocklist|хъодыгонд IP-адристы номхыгъд]].',
 'ipb-blocklist'            => 'Актуалон хъоды равдис',
-'ipb-blocklist-contribs'   => '$1, зæгъгæ, уыцы архайæджы бавæрд',
+'ipb-blocklist-contribs'   => '{{grammar:genitive|$1}} бавæрд',
 'ipblocklist'              => 'Хъодыгонд архайджытæ',
 'ipblocklist-legend'       => 'Хъодыгонд архайæджы ацагур',
 'ipblocklist-empty'        => 'Хъодыгæндты номхыгъд афтид у.',
@@ -962,22 +1015,20 @@ $3',
 'block-log-flags-nocreate' => 'аккаунт аразæн нал ис',
 
 # Developer tools
-'lockdbsuccesssub'    => 'Бæрæггæнæнты базæ æхгæд у',
-'unlockdbsuccesssub'  => 'Бæрæггæнæнты базæ æхгæд нал у',
-'unlockdbsuccesstext' => 'Бæрæггæнæнты базæ æхгæд нал у.',
-'databasenotlocked'   => 'Бæрæггæнæнты базæ æхгæд не ’рцыд.',
+'lockdbsuccesssub'    => 'Рарддон æхгæд æрцыд',
+'unlockdbsuccesssub'  => 'Рардон байгом ис',
+'unlockdbsuccesstext' => 'Рард дон гом æрцыд.',
+'databasenotlocked'   => 'Рарддон æхгæд неу.',
 
 # Move page
-'movearticle'              => 'Статьяйы ном баив',
-'movenologin'              => 'Системæйæн дæхи нæ бацамыдтай',
-'newtitle'                 => 'Ног ном',
-'move-watch'               => 'Ацы фарсмæ дæ цæст æрдар',
-'movepagebtn'              => 'Фарсы ном ивын',
-'1movedto2_redir'          => "[[$1]] æрвыстимæ хаст æрцыд [[$2]]'мæ",
-'move-redirect-suppressed' => 'рарвысты фарс нæ бахъуыд',
-'movelogpage'              => 'Номивдтыты лог',
-'movereason'               => 'Аххос:',
-'revertmove'               => 'раивын',
+'movearticle' => 'Статьяйы ном баив',
+'movenologin' => 'Системæйæн дæхи нæ бацамыдтай',
+'newtitle'    => 'Ног ном',
+'move-watch'  => 'Ацы фарсмæ дæ цæст æрдар',
+'movepagebtn' => 'Фарсы ном ивын',
+'movelogpage' => 'Номивдтыты лог',
+'movereason'  => 'Аххос:',
+'revertmove'  => 'раивын',
 
 # Export
 'export' => 'Фæрсты экспорт',
@@ -998,12 +1049,12 @@ $3',
 'importuploaderrortemp' => 'Импорты файл æрвитын нæ фæрæстмæ. Нæй рæстæгмæ файлдон.',
 
 # Tooltip help for the actions
-'tooltip-pt-userpage'             => 'Мæхи фарс (дæу тыххæй ам ныффысс)',
+'tooltip-pt-userpage'             => 'Дæ архайæджы фарс',
 'tooltip-pt-mytalk'               => 'Дæ ныхасы фарс',
 'tooltip-pt-preferences'          => 'Дæ фадæттæ',
 'tooltip-pt-watchlist'            => 'Фæрстæ кæй ивдтытæм ды дарыс дæ цæст',
 'tooltip-pt-mycontris'            => 'Дæ бавæрд',
-'tooltip-pt-login'                => 'Хуыздæр у куы базизай системæмæ; фæлæ нæмæнг нæу',
+'tooltip-pt-login'                => 'Хуыздæр у куы бахизай системæмæ; фæлæ нæмæнг нæу',
 'tooltip-pt-logout'               => 'Рахизын',
 'tooltip-ca-talk'                 => 'Фарсы тыххæй тæрхон',
 'tooltip-ca-edit'                 => 'Ацы фарс дæ бон у ивын. Дæ хорзæхæй, «Фен уал æй» джыбыйæ пайда кæн',
@@ -1032,7 +1083,7 @@ $3',
 'tooltip-feed-atom'               => 'Atom feed ацы фарсæн',
 'tooltip-t-contributions'         => 'Ацы архайæджы бавæрд фенын',
 'tooltip-t-emailuser'             => 'Арвитын фыстæг ацы архайæгмæ',
-'tooltip-t-upload'                => 'Нывтæ кæнæ мультимедиа-файлтæ бавæр',
+'tooltip-t-upload'                => 'Файлтæ бавгæнынæн',
 'tooltip-t-specialpages'          => 'Сæрмагонд фæрсты номхыгъд',
 'tooltip-t-print'                 => 'Ацы фарс мыхуырмæ цæттæ форматы',
 'tooltip-t-permalink'             => 'Фарсы ацы фæлтæрмæ æрвитæн (фæрстæ ивынц, ацы фæлтæр — нæ)',
@@ -1048,7 +1099,7 @@ $3',
 'tooltip-preview'                 => 'Бакæс уал дæ ивдмæ. Дæ хорзæхæй ай уал сараз бавæрыны размæ!',
 'tooltip-diff'                    => 'Æвдисы цы ивд бахастай текстмæ',
 'tooltip-compareselectedversions' => 'Кæс дыууæ æвзæрст фæлтæры цæмæй хицæн кæнынц',
-'tooltip-watch'                   => 'Ацы фарс, дæ цæст кæмæ дарыс, уыцы фæрсты номхыгъдмæ бафтау',
+'tooltip-watch'                   => 'Ацы фарсмæ цæст æрдарынæн',
 'tooltip-rollback'                => '"Раздæхын" æздæхы ацы фарсы фæстаг архайæджы ивд(тытæ) иу хæстмæ',
 'tooltip-undo'                    => '"Раивын" æздæхы ацы ивд æмæ æвдисы ивæн фарс разбакаст уавæры. Уый дын дæ бавæрдæн фсон скæныны фадат дæтты.',
 'tooltip-summary'                 => 'Бафысс чысыл æмбарынгæнæн',
@@ -1067,11 +1118,6 @@ $3',
 'skinname-myskin'      => 'Мæхи',
 'skinname-chick'       => 'Карк',
 
-# Patrol log
-'patrol-log-line' => 'банысан кодта $1 $2 фарсæй патрулгондæй $3',
-'patrol-log-auto' => '(автоматон)',
-'patrol-log-diff' => 'ивд $1',
-
 # Browsing diffs
 'previousdiff' => '← Зæронддæр ивд',
 'nextdiff'     => 'Фæстæдæр ивд →',
@@ -1080,6 +1126,7 @@ $3',
 'thumbsize'       => 'Къаддæргонды бæрц:',
 'widthheightpage' => '$1 × $2, $3 {{PLURAL:$3|фарс|фарсы}}',
 'file-info-size'  => '$1 × $2 пикселы, файлы уæз: $3, MIME тип: $4',
+'file-nohires'    => 'Нæй ын стырдæр фæлтæр .',
 'svg-long-desc'   => 'SVG файл, номиналон $1 × $2 пикселы, файлы бæрц: $3',
 'show-big-image'  => 'Æнæхъæнæй',
 
@@ -1097,8 +1144,9 @@ $3',
 Иннæ æрвитæнтæ уыцы рæнхъы нымады кæнынц куыд уæлвæткытæ, кæдон сты фæрстæ кæдæм ис бар бавæрын файл.',
 
 # Metadata
-'metadata'        => 'Метабæрæггæнæнтæ',
-'metadata-expand' => 'Фылдæр детальтæ равдис',
+'metadata'          => 'Метабæрæггæнæнтæ',
+'metadata-expand'   => 'Равдисын лæмбынæг афыст',
+'metadata-collapse' => 'Айсын лæмбынæг афыст',
 
 # EXIF tags
 'exif-imagewidth'   => 'Уæрх',
@@ -1144,9 +1192,9 @@ $3',
 'livepreview-failed' => 'Тагъд разæркастæй пайда кæнæн нæй. Хуымæтæджы разæркастæй пайда кæн.',
 
 # Watchlist editor
-'watchlistedit-noitems'       => 'Иу фарсмæ дæр нæ дарыс дæ цæст, ацы номхыгъд афтид у.',
-'watchlistedit-normal-title'  => 'Дæ цæст кæмæ дарыс, уыцы фæрсты номхыгъд ивыс',
-'watchlistedit-normal-submit' => 'Аппар фыстытæ',
+'watchlistedit-noitems'       => 'Дæ цæстдард афтид у.',
+'watchlistedit-normal-title'  => 'Цæстдард ивæн',
+'watchlistedit-normal-submit' => 'Схафын фыстытæ',
 'watchlistedit-raw-titles'    => 'Фæрстæ:',
 'watchlistedit-raw-submit'    => 'Номхыгъд бафснай',
 
@@ -1163,4 +1211,22 @@ $3',
 # Special:SpecialPages
 'specialpages' => 'Сæрмагонд фæрстæ',
 
+# Special:Tags
+'tags-edit' => 'ивын',
+
+# Special:ComparePages
+'compare-page1'  => 'Фарс 1',
+'compare-page2'  => 'Фарс 2',
+'compare-rev1'   => 'Фæлтæр 1',
+'compare-rev2'   => 'Фæлтæр 2',
+'compare-submit' => 'Абарын',
+
+# HTML forms
+'htmlform-selectorother-other' => 'Æндæр',
+
+# Feedback
+'feedback-subject' => 'Сæр:',
+'feedback-message' => 'Фыстæг:',
+'feedback-close'   => 'Æххæст',
+
 );
