@@ -7,6 +7,7 @@
  * @ingroup Language
  * @file
  *
+ * @author Kaganer
  * @author Xqt
  * @author לערי ריינהארט
  */
@@ -151,7 +152,7 @@ $messages = array(
 'faqpage'        => 'Project:FAQ',
 
 # Vector skin
-'vector-action-delete'  => 'Lesche',
+'vector-action-delete'  => 'Verwische',
 'vector-action-move'    => 'Ziehe',
 'vector-action-protect' => 'Schitze',
 'vector-view-create'    => 'Schtaerte',
@@ -178,8 +179,8 @@ $messages = array(
 'create'           => 'Schtaerte',
 'editthispage'     => 'Des Blatt ennere',
 'create-this-page' => 'Blatt schtaerte',
-'delete'           => 'Lesche',
-'deletethispage'   => 'Des Blatt lösche',
+'delete'           => 'Verwische',
+'deletethispage'   => 'Des Blatt verwische',
 'protect'          => 'Schitze',
 'protect_change'   => 'tscheensche',
 'protectthispage'  => 'Des Blatt schitze',
@@ -273,7 +274,8 @@ Des Blatt iss verleicht glescht adder gezoge warre.
 Wenns des net iss, hoscht verleicht en Fehler in de Daadebank gfunne. Bitte meld des an en [[Special:ListUsers/sysop|Verwalter]] unn gebb die URL dezu aa.',
 'missingarticle-rev'  => '(Version: $1)',
 'missingarticle-diff' => '(Unnerschidd zwische Versione: $1, $2)',
-'viewsourcefor'       => 'fer $1',
+'internalerror'       => 'Interner Fehler',
+'internalerror_info'  => 'Interner Fehler: $1',
 'ns-specialprotected' => 'Besunnere Bledder sinn net zum Ennere.',
 
 # Virus scanner
@@ -311,6 +313,9 @@ Wenns des net iss, hoscht verleicht en Fehler in de Daadebank gfunne. Bitte meld
 'passwordreset-emailelement' => 'Yuusernaame: $1
 Paesswatt fer nau: $2',
 
+# Special:ChangeEmail
+'changeemail-none' => '(ken)',
+
 # Edit page toolbar
 'bold_sample'     => 'Wadde fett gmarrickt',
 'bold_tip'        => 'Wadde fett gmarrickt',
@@ -327,6 +332,7 @@ Paesswatt fer nau: $2',
 # Edit pages
 'minoredit'              => 'Nur gleene Enneringe gemacht',
 'watchthis'              => 'Watsch des Blatt',
+'savearticle'            => 'Blatt beilege',
 'preview'                => 'Aagucke',
 'showdiff'               => 'Enneringe zeige',
 'blockednoreason'        => 'ken Grund gewwe',
@@ -342,6 +348,9 @@ Paesswatt fer nau: $2',
 'template-protected'     => '(geschitzt)',
 'template-semiprotected' => '(geschitzt fer neie Yuuser)',
 
+# "Undo" feature
+'undo-summary' => 'Enneringe $1 vun [[Special:Contributions/$2|$2]] ([[User talk:$2|Dischbedutt]]) losgmacht.',
+
 # History pages
 'revisionasof'     => 'Version vum $2, $3 Uhr',
 'previousrevision' => '← letscht Version',
@@ -352,7 +361,7 @@ Paesswatt fer nau: $2',
 'page_last'        => 'End',
 'histfirst'        => 'Eldescht',
 'histlast'         => 'Letscht',
-'historysize'      => '({{PLURAL:$1|1 Byte|$1 Bytes}})',
+'historysize'      => '({{PLURAL:$1|1 Beit|$1 Beit}})',
 'historyempty'     => '(leer)',
 
 # Revision deletion
@@ -368,8 +377,6 @@ Paesswatt fer nau: $2',
 'revdelete-radio-unset'      => 'Nee',
 'revdelete-log'              => 'Grund:',
 'pagehist'                   => 'Gschicht',
-'revdelete-uname'            => 'Yuuser-Naame',
-'revdelete-log-message'      => '$1 fer $2 {{PLURAL:$2|Version|Versione}}',
 'revdelete-otherreason'      => 'Annere Grind dezu:',
 'revdelete-reasonotherlist'  => 'Annere Grind',
 'revdelete-edit-reasonlist'  => "Grind fer's Lesche ennere",
@@ -381,7 +388,7 @@ Paesswatt fer nau: $2',
 # Diffs
 'difference' => '(Unnerschidd zwische Versione)',
 'lineno'     => 'Lein $1:',
-'editundo'   => 'zerick',
+'editundo'   => 'losmache',
 
 # Search results
 'searchresults'                  => 'Results vum Uffgucke',
@@ -426,6 +433,8 @@ Paesswatt fer nau: $2',
 'prefs-watchlist'          => 'Watsch-Lischt',
 'prefs-watchlist-days'     => 'Daage in de Watsch-Lischt:',
 'prefs-resetpass'          => 'Paesswatt ennere',
+'saveprefs'                => 'Uffstellinge beilege',
+'resetprefs'               => 'Ausduh',
 'prefs-editing'            => 'Ennere',
 'columns'                  => 'Kallems:',
 'searchresultshead'        => 'Guck uff',
@@ -475,7 +484,7 @@ Paesswatt fer nau: $2',
 'right-edit'     => 'Bledder ennere',
 'right-move'     => 'Bledder ziehe',
 'right-movefile' => 'Feils ziehe',
-'right-upload'   => 'Feils ufflaade',
+'right-upload'   => 'Feils nuffdraage',
 'right-writeapi' => 'Yuus vun write API',
 'right-delete'   => 'Bledder lesche',
 
@@ -488,7 +497,7 @@ Paesswatt fer nau: $2',
 'action-move'     => 'des Blatt zu ziehe',
 'action-movefile' => 'Des Feil ziehe',
 'action-upload'   => 'Des Feil ufflaade',
-'action-delete'   => 'des Blatt zu lösche',
+'action-delete'   => 'des Blatt zu verwische',
 
 # Recent changes
 'nchanges'                  => '$1 {{PLURAL:$1|Ennering|Enneringe}}',
@@ -508,6 +517,7 @@ Paesswatt fer nau: $2',
 'newpageletter'             => 'N',
 'boteditletter'             => 'W',
 'rc_categories_any'         => 'All',
+'rc-change-size-new'        => '$1 {{PLURAL:$1|Beit|Beit}} nooch daer Ennering',
 'newsectionsummary'         => 'Neier Abschnitt /* $1 */',
 
 # Recent changes linked
@@ -515,20 +525,25 @@ Paesswatt fer nau: $2',
 'recentchangeslinked-page' => 'Blatt:',
 
 # Upload
-'upload'             => 'Ufflaade',
-'uploadbtn'          => 'Feil ufflaade',
+'upload'             => 'Nuffdraage',
+'uploadbtn'          => 'Feil nuffdraage',
 'uploadlogpage'      => 'Feil-Lochbuch',
 'filename'           => 'Feilnaame',
 'badfilename'        => 'Daer Feilnaame iss gennert warre nooch „$1“.',
+'savefile'           => 'Feil beilege',
 'uploadedimage'      => 'hot „[[$1]]“ uffglaade',
 'overwroteimage'     => 'hot e neie Version vun „[[$1]]“ uffglaade',
 'uploaddisabled'     => 'Ufflaade verbodde',
 'uploaddisabledtext' => 'Es Ufflaade vun Feils iss verbodde.',
 'watchthisupload'    => 'Watsch des Blatt',
 
+'upload-file-error'   => 'Interner Fehler',
 'upload-unknown-size' => 'Unbekannte Grees',
 'upload-http-error'   => 'En HTTP-Fehler iss kumme: $1',
 
+# File backend
+'backend-fail-backup' => 'Des Feil $1 iss net zwettgmacht warre.',
+
 # img_auth script messages
 'img-auth-nofile' => 'Feil „$1“ gebt es net.',
 
@@ -547,7 +562,7 @@ Paesswatt fer nau: $2',
 'file-anchor-link'    => 'Feil',
 'filehist'            => 'Versione vun Feils',
 'filehist-deleteall'  => 'All Versione lösche',
-'filehist-deleteone'  => 'Sell Version lesche',
+'filehist-deleteone'  => 'Sell Version verwische',
 'filehist-revert'     => 'zerick',
 'filehist-datetime'   => 'Version vum',
 'filehist-thumb'      => 'Glee Pikder',
@@ -565,7 +580,7 @@ Paesswatt fer nau: $2',
 # File deletion
 'filedelete'                  => 'Lösche „$1“',
 'filedelete-comment'          => 'Grund:',
-'filedelete-submit'           => 'Lesche',
+'filedelete-submit'           => 'Verwische',
 'filedelete-nofile'           => "'''„$1“''' gebt es net.",
 'filedelete-otherreason'      => 'Annere Grind dezu:',
 'filedelete-reason-otherlist' => 'Annerer Gund',
@@ -595,12 +610,12 @@ Paesswatt fer nau: $2',
 
 'brokenredirects'        => 'Kaputte Weiderleidinge',
 'brokenredirects-edit'   => 'ennere',
-'brokenredirects-delete' => 'lesche',
+'brokenredirects-delete' => 'verwische',
 
 'withoutinterwiki-submit' => 'Zeig',
 
 # Miscellaneous special pages
-'nbytes'            => '$1 {{PLURAL:$1|Byte|Bytes}}',
+'nbytes'            => '$1 {{PLURAL:$1|Beit|Beit}}',
 'ncategories'       => '$1 {{PLURAL:$1|Abdeeling|Abdeelinge}}',
 'nlinks'            => '{{PLURAL:$1|1 Gleecher|$1 Gleecher}}',
 'nimagelinks'       => 'Gyuust uff $1 {{PLURAL:$1|Blatt|Bledder}}',
@@ -668,7 +683,7 @@ Paesswatt fer nau: $2',
 
 # E-mail user
 'emailuser'       => 'E-Poschd fer den Yuuser',
-'defemailsubject' => '{{SITENAME}}-E-Poschde',
+'defemailsubject' => '{{SITENAME}} - E-Poschde vun Yuuser „$1“',
 'emailusername'   => 'Yuuser-Naame:',
 'emailfrom'       => 'Vun:',
 'emailto'         => 'Fer:',
@@ -700,10 +715,9 @@ Paesswatt fer nau: $2',
 'deletepage'             => 'Blatt lesche',
 'exblank'                => 'Blatt war leer',
 'delete-confirm'         => 'Lesche vun „$1“',
-'delete-legend'          => 'Lesche',
+'delete-legend'          => 'Verwische',
 'deletedtext'            => '"$1" iss gelescht warre.
 Guck $2 fer e Lischt vun de letscht Leschunge.',
-'deletedarticle'         => 'hot „[[$1]]“ gelöscht',
 'dellogpage'             => 'Lischt vun gelöschte Bledder',
 'deletecomment'          => 'Grund:',
 'deleteotherreason'      => 'Annre Grind:',
@@ -724,7 +738,7 @@ Guck $2 fer e Lischt vun de letscht Leschunge.',
 'protect-expiry-options'    => '1 Schtund:1 hour,1 Daag:1 day,1 Woch:1 week,2 Woche:2 weeks,1 Munet:1 month,3 Munede:3 months,6 Munede:6 months,1 Yaar:1 year,Fer immer:infinite',
 'minimum-size'              => 'Min. Grees',
 'maximum-size'              => 'Max. Grees:',
-'pagesize'                  => '(Bytes)',
+'pagesize'                  => '(Beit)',
 
 # Restrictions (nouns)
 'restriction-edit'   => 'Ennere/Tscheensche',
@@ -797,16 +811,15 @@ Guck $2 fer e Lischt vun de letscht Leschunge.',
 'pagemovedsub'            => 'Blatt iss gezoge warre',
 'movepage-moved'          => "'''Es Blatt „$1“ iss gezoge warre uff „$2“'''",
 'movedto'                 => 'gezoge uff',
-'1movedto2'               => 'hot „[[$1]]“ nooch „[[$2]]“ gezoge',
-'1movedto2_redir'         => 'hot „[[$1]]“ nooch „[[$2]]“ gezoge unn debei e Weiderleiding iwwerschriwwe',
 'movereason'              => 'Grund:',
 'revertmove'              => 'zerick ziehe',
 'delete_and_move_confirm' => 'Ya, es Blatt lösche',
 
 # Export
-'export'        => 'Bledder exportiere',
-'export-addcat' => 'Dezu duh',
-'export-addns'  => 'Dezu duh',
+'export'          => 'Bledder exportiere',
+'export-addcat'   => 'Dezu duh',
+'export-addns'    => 'Dezu duh',
+'export-download' => 'As XML-Feil annelege',
 
 # Namespace 8 related
 'allmessagesname'               => 'Naame',
@@ -839,7 +852,7 @@ Guck $2 fer e Lischt vun de letscht Leschunge.',
 'tooltip-ca-edit'                => 'Du kannscht des Blatt ennere. Bitte brauch de Aaguck-Gnopp vor em Speichere.',
 'tooltip-ca-history'             => 'Ledschde Versione vun dem Blattt',
 'tooltip-ca-protect'             => 'Des Blatt schitze',
-'tooltip-ca-delete'              => 'Des Blatt lösche',
+'tooltip-ca-delete'              => 'Des Blatt verwische',
 'tooltip-ca-move'                => 'Des Blatt ziehe',
 'tooltip-search'                 => 'Guck uff {{SITENAME}}',
 'tooltip-search-go'              => 'Geh zu dem Blatt mit genaa dem Naame, wenns es gebbt.',
@@ -857,7 +870,7 @@ Guck $2 fer e Lischt vun de letscht Leschunge.',
 'tooltip-feed-atom'              => 'Atom-Feed fer des Blatt',
 'tooltip-t-contributions'        => 'Lischt von Ardickele vun dem Yuuser zeige',
 'tooltip-t-emailuser'            => 'Dem Yuuser e E-Poschd schicke',
-'tooltip-t-upload'               => 'Feils ufflaade',
+'tooltip-t-upload'               => 'Feils nuffdraage',
 'tooltip-t-specialpages'         => 'Lischt vun alle besunnere Bledder',
 'tooltip-t-print'                => 'Des Blatt fer zum Drucke',
 'tooltip-t-permalink'            => 'En permanent Gleecher zu derre Version vun dem Blatt',
@@ -866,6 +879,7 @@ Guck $2 fer e Lischt vun de letscht Leschunge.',
 'tooltip-ca-nstab-special'       => 'Sell iss en besunneres Blatt. Du kannscht es Blatt net ennere.',
 'tooltip-ca-nstab-image'         => 'Feil zeige',
 'tooltip-ca-nstab-template'      => 'Moddel aagucke',
+'tooltip-save'                   => 'Enneringe beilege',
 
 # Attribution
 'siteuser'  => '{{SITENAME}}-Yuuser $1',
@@ -882,7 +896,7 @@ Guck $2 fer e Lischt vun de letscht Leschunge.',
 'nextdiff' => 'Zum neegschte Versionsunnerschidd →',
 
 # Media information
-'widthheightpage' => '$1×$2, {{PLURAL:$3|1 Blatt|$3 Bledder}}',
+'widthheightpage' => '$1 × $2, {{PLURAL:$3|1 Blatt|$3 Bledder}}',
 'file-info-size'  => '$1 × $2 Pixel, Daadegrees: $3, MIME-Typ: $4',
 
 # Special:NewFiles
@@ -890,6 +904,13 @@ Guck $2 fer e Lischt vun de letscht Leschunge.',
 'noimages'     => 'Keene Feils gfunne.',
 'ilsubmit'     => 'Guck uff',
 
+# Video information, used by Language::formatTimePeriod() to format lengths in the above messages
+'seconds' => '{{PLURAL:$1|$1 Sekund|$1 Sekunde}}',
+'minutes' => '{{PLURAL:$1|$1 Minudd|$1 Minudde}}',
+'hours'   => '{{PLURAL:$1|ee Schtund|$1 Schtunde}}',
+'days'    => '{{PLURAL:$1|een Daag|$1 Daag}}',
+'ago'     => 'vor $1',
+
 # Metadata
 'metadata' => 'Metadaade',
 
@@ -907,6 +928,8 @@ Guck $2 fer e Lischt vun de letscht Leschunge.',
 
 'exif-gaincontrol-0' => 'Ken',
 
+'exif-iimcategory-sci' => 'Wisseschaft unn Waerkzeichheet‎',
+
 # 'all' in various places, this might be different for inflected languages
 'watchlistall2' => 'all',
 'namespacesall' => 'all',
@@ -916,9 +939,6 @@ Guck $2 fer e Lischt vun de letscht Leschunge.',
 # Scary transclusion
 'scarytranscludetoolong' => '[URL iss zu lang]',
 
-# Trackbacks
-'trackbackremove' => '([$1 lösche])',
-
 # action=purge
 'confirm_purge_button' => 'OK',
 
@@ -995,7 +1015,10 @@ Guck $2 fer e Lischt vun de letscht Leschunge.',
 'compare-page2' => 'Blatt 2',
 
 # HTML forms
-'htmlform-reset'               => 'Enneringe zerick nemme',
+'htmlform-reset'               => 'Enneringe losmache',
 'htmlform-selectorother-other' => 'Annere',
 
+# Feedback
+'feedback-message' => 'Melding:',
+
 );
