@@ -14,24 +14,22 @@
 $fallback = 'ro';
 
 $namespaceNames = array(
-	NS_MEDIA          => 'Mediya',
-	NS_SPECIAL        => 'Uzalutno',
-	NS_MAIN           => '',
-	NS_TALK           => 'Vakyarimata',
-	NS_USER           => 'Jeno',
-	NS_USER_TALK      => 'Jeno_vakyarimata',
-	# NS_PROJECT set by $wgMetaNamespace
-	NS_PROJECT_TALK   => '{{grammar:genitive-pl|$1}}_vakyarimata',
-	NS_FILE           => 'Chitro',
-	NS_FILE_TALK      => 'Chitro_vakyarimata',
-	NS_MEDIAWIKI      => 'MediyaViki',
-	NS_MEDIAWIKI_TALK => 'MediyaViki_vakyarimata',
-	NS_TEMPLATE       => 'Sikavno',
-	NS_TEMPLATE_TALK  => 'Sikavno_vakyarimata',
-	NS_HELP           => 'Zhutipen',
-	NS_HELP_TALK      => 'Zhutipen_vakyarimata',
-	NS_CATEGORY       => 'Shopni',
-	NS_CATEGORY_TALK  => 'Shopni_vakyarimata'
+	NS_MEDIA            => 'Mediya',
+	NS_SPECIAL          => 'Uzalutno',
+	NS_TALK             => 'Vakyarimata',
+	NS_USER             => 'Jeno',
+	NS_USER_TALK        => 'Jeno_vakyarimata',
+	NS_PROJECT_TALK     => '{{grammar:genitive-pl|$1}}_vakyarimata',
+	NS_FILE             => 'Chitro',
+	NS_FILE_TALK        => 'Chitro_vakyarimata',
+	NS_MEDIAWIKI        => 'MediyaViki',
+	NS_MEDIAWIKI_TALK   => 'MediyaViki_vakyarimata',
+	NS_TEMPLATE         => 'Sikavno',
+	NS_TEMPLATE_TALK    => 'Sikavno_vakyarimata',
+	NS_HELP             => 'Zhutipen',
+	NS_HELP_TALK        => 'Zhutipen_vakyarimata',
+	NS_CATEGORY         => 'Shopni',
+	NS_CATEGORY_TALK    => 'Shopni_vakyarimata',
 );
 
 $messages = array(
@@ -75,17 +73,19 @@ $messages = array(
 # Categories related messages
 'subcategories' => 'Telekategoriye',
 
-'about'          => 'Andar',
-'article'        => 'Lekh',
-'newwindow'      => '(inklel aver filiyastra)',
-'cancel'         => 'Mekh la',
+'about'      => 'Andar',
+'article'    => 'Lekh',
+'newwindow'  => '(inklel aver filiyastra)',
+'cancel'     => 'Mekh la',
+'mypage'     => 'Miri patrin',
+'mytalk'     => 'Mire vakyarimata',
+'navigation' => 'Phiripen',
+'and'        => '&#32;thai',
+
+# Cologne Blue skin
 'qbedit'         => 'Editisar',
 'qbpageinfo'     => 'Patrinyake janglimata',
 'qbspecialpages' => 'Uzalutne patrya',
-'mypage'         => 'Miri patrin',
-'mytalk'         => 'Mire vakyarimata',
-'navigation'     => 'Phiripen',
-'and'            => '&#32;thai',
 
 'errorpagetitle'   => 'Dosh',
 'returnto'         => 'Ja palpale kai $1.',
@@ -115,7 +115,7 @@ $messages = array(
 'userpage'         => 'Dikh i jeneski patrin',
 'viewtalkpage'     => 'Dikh i diskucia',
 'otherlanguages'   => 'Avre ćhibande',
-'lastmodifiedat'   => 'O palutno paruvipen $2, $1.', # $1 date, $2 time
+'lastmodifiedat'   => 'O palutno paruvipen $2, $1.',
 'viewcount'        => 'Kadaya patrin dikhlilyas {{PLURAL:$1|one time|$1var}}.',
 'jumpto'           => 'Ja kai:',
 'jumptonavigation' => 'phiripen',
@@ -166,14 +166,12 @@ $messages = array(
 'viewsource'           => 'Dikh i sursa',
 
 # Login and logout pages
-'logouttitle'                => 'San avri akana',
 'logouttext'                 => "'''Akana san avryal i {{SITENAME}}.'''
 
 Shai te labyares {{SITENAME}} sar ekh bijanglo jeno vai shai te prinjares tut palem sar o jeno le kadale navesa vai le aver navesa.",
 'welcomecreation'            => '== Mishto avilyan, $1! ==
 
 Akana si tuke ekh akont. Te na bistares te paruves, kana trebul tuke, tire kamimata kai {{SITENAME}}.',
-'loginpagetitle'             => 'Jenesko prinjaripen',
 'yourname'                   => 'Tiro anav',
 'yourpassword'               => 'O nakhavipnasko lav',
 'yourpasswordagain'          => 'O nakhavipnasko lav de nevo',
@@ -189,11 +187,6 @@ Akana si tuke ekh akont. Te na bistares te paruves, kana trebul tuke, tire kamim
 'gotaccountlink'             => 'De andre',
 'createaccountmail'          => 'palal o e-mail',
 'badretype'                  => 'Le nakhavipnaske lava so lekhavdyan nai myazutne.',
-'youremail'                  => 'Emailesko adress (kana kames)*',
-'yourrealname'               => 'Tiro chacho anav*',
-'yourlanguage'               => 'Ćhib:',
-'yournick'                   => 'I xarni versyunya, le semnaturenge',
-'badsig'                     => 'Bilachhi semnatura; dikh le tagurya HTML.',
 'loginerror'                 => 'Prinjaripnaski dosh',
 'nocookiesnew'               => "O tiro akont sas kerdo, pale tu nai prinjardo/i. {{SITENAME}} labyarel ''cookies'' te astarel le manusha prinjarde. O tiro browser na astarel le cookies. Si mishto te das les drom te astarel le ''cookies'' thai, palal kodya, te zumaves vi ekh var, labyarindoi o nav thai o nakhavipnaso lav.",
 'nocookieslogin'             => "{{SITENAME}} labyarel ''cookies'' te prinjaren le manusha so aven kathe. O tiro browser chi astarel len. Si mishto te das les drom te astarel le ''cookies'' thai, palal kodya, te zumaves vi ekh var.",
@@ -218,7 +211,7 @@ Mishto si te jas kai {{SITENAME}} thai te paruves tiro lav sigo.',
 'accountcreated'             => 'Akount kerdo',
 'accountcreatedtext'         => 'Kerdo o akonto le jenesko ko $1.',
 
-# Password reset dialog
+# Change password dialog
 'oldpassword' => 'Purano nakahvipnasko lav',
 'newpassword' => 'Nevo nakhavipnasko lav:',
 
@@ -226,27 +219,26 @@ Mishto si te jas kai {{SITENAME}} thai te paruves tiro lav sigo.',
 'image_sample' => 'Misal.jpg',
 
 # Edit pages
-'summary'            => 'Xarno xalyaripen:',
-'minoredit'          => 'Kadava si ek tikno editisarimos',
-'watchthis'          => 'Dikh kadaya patrin',
-'savearticle'        => 'Uxtav i patrin',
-'showpreview'        => 'Dikh sar avelas i patrin',
-'showlivepreview'    => 'Jivutno angledikhipen',
-'showdiff'           => 'Dikh le paruvimata',
-'whitelistedittitle' => 'Trebul o autentifikaripen kashte editisares',
-'whitelistedittext'  => 'Trebul te [[Special:UserLogin|autentifikisares]] kashte editisares artikolurya.',
-'accmailtitle'       => 'O nakhavipnasko lav bićhaldo.',
-'accmailtext'        => "O nakhavipnasko lav andar '$1' bićhaldo ko $2.",
-'newarticle'         => '(Nevo)',
-'newarticletext'     => 'Avilyan kai ek patrin so na si.
+'summary'           => 'Xarno xalyaripen:',
+'minoredit'         => 'Kadava si ek tikno editisarimos',
+'watchthis'         => 'Dikh kadaya patrin',
+'savearticle'       => 'Uxtav i patrin',
+'showpreview'       => 'Dikh sar avelas i patrin',
+'showlivepreview'   => 'Jivutno angledikhipen',
+'showdiff'          => 'Dikh le paruvimata',
+'whitelistedittext' => 'Trebul te [[Special:UserLogin|autentifikisares]] kashte editisares artikolurya.',
+'accmailtitle'      => 'O nakhavipnasko lav bićhaldo.',
+'accmailtext'       => "O nakhavipnasko lav andar '$1' bićhaldo ko $2.",
+'newarticle'        => '(Nevo)',
+'newarticletext'    => 'Avilyan kai ek patrin so na si.
 Te keres la, shai te shirdes (astares) te lekhaves ando telutno moxton (dikh [[{{MediaWiki:Helppage}}|zhutipnaski patrin]] te janes buteder).
 Kana avilyan kathe doshatar, ja palpale.',
-'noarticletext'      => "Andi '''{{SITENAME}}''' nai ji akana ek lekh kadale anavesa.
+'noarticletext'     => "Andi '''{{SITENAME}}''' nai ji akana ek lekh kadale anavesa.
 * Te shirdes (astares) te keres o lekh, ker klik  '''[{{fullurl:{{FULLPAGENAME}}|action=edit}} kathe]'''.",
-'editing'            => 'Editisaripen $1',
-'yourtext'           => 'Tiro teksto',
-'storedversion'      => 'Akanutni versiya',
-'yourdiff'           => 'Ververimata',
+'editing'           => 'Editisaripen $1',
+'yourtext'          => 'Tiro teksto',
+'storedversion'     => 'Akanutni versiya',
+'yourdiff'          => 'Ververimata',
 
 # History pages
 'previousrevision' => '← Purano paruvipen',
@@ -255,7 +247,6 @@ Kana avilyan kathe doshatar, ja palpale.',
 'last'             => 'purani',
 'histlegend'       => 'Xalyaripen: (akanutni) = ververimata mamui i akanutni versiya,
 (purani) = ververimata mamui i puraneder versiya, T = tikno editisaripen',
-'deletedrev'       => '[khoslo]',
 'histfirst'        => 'O mai purano',
 'histlast'         => 'O mai nevo',
 
@@ -266,40 +257,36 @@ Kana avilyan kathe doshatar, ja palpale.',
 'compareselectedversions' => 'Dikh ververimata mashkar alosarde versiye',
 
 # Search results
-'prevn'             => 'mai neve $1',
-'nextn'             => 'mai purane $1',
-'viewprevnext'      => 'Dikh ($1) ($2) ($3).',
+'prevn'             => 'mai neve {{PLURAL:$1|$1}}',
+'nextn'             => 'mai purane {{PLURAL:$1|$1}}',
+'viewprevnext'      => 'Dikh ($1 {{int:pipe-separator}} $2) ($3).',
 'searchhelp-url'    => 'Help:Zhutipen',
 'showingresults'    => 'Tele si <b>$1</b> rezultaturya shirdindoi le ginestar <b>$2</b>.',
 'showingresultsnum' => 'Tele si <b>$3</b> rezultaturya shirdindoi le ginestar <b>$2</b>.',
 'powersearch'       => 'Rod',
 
 # Preferences page
-'preferences'           => 'Kamimata',
-'changepassword'        => 'Paruv o nakhavipnasko lav',
-'skin'                  => 'Dikhimos',
-'math'                  => 'Matematika',
-'dateformat'            => 'Datengi forma',
-'datedefault'           => 'Ni ekh kamipen',
-'datetime'              => 'Dives thai chaso',
-'math_unknown_error'    => 'bijangli dosh',
-'math_unknown_function' => 'bijangli funkciya',
-'math_syntax_error'     => 'sintaksaki dosh',
-'math_bad_output'       => 'Nashti te kerel pes vai te lekhavel po matematikano direktoro kai del pes avri.',
-'math_notexvc'          => 'Nai o kerditori (eksekutabilo) texvc; dikh math/README te labyares les.',
-'prefs-rc'              => 'Neve paruvimata',
-'saveprefs'             => 'Uxtav le kamimata',
-'resetprefs'            => 'Thov le kamimata sar ko shirdipen',
-'columns'               => 'Uche vortorina:',
-'contextlines'          => 'Vortorinyango gin pe avimos:',
-'contextchars'          => 'Grafemengo gin pe ekh vortorin:',
-'localtime'             => 'Thanutno vaxt',
-'timezoneoffset'        => 'Ververipen',
-'guesstimezone'         => 'Le les katar o browser',
-'allowemail'            => 'De drom te aven e-mailurya katar aver jene',
-'defaultns'             => 'Rod savaxt vi kai kadale riga:',
-'default'               => 'acharuno',
-'files'                 => 'Failurya',
+'preferences'    => 'Kamimata',
+'changepassword' => 'Paruv o nakhavipnasko lav',
+'prefs-skin'     => 'Dikhimos',
+'datedefault'    => 'Ni ekh kamipen',
+'prefs-datetime' => 'Dives thai chaso',
+'prefs-rc'       => 'Neve paruvimata',
+'saveprefs'      => 'Uxtav le kamimata',
+'resetprefs'     => 'Thov le kamimata sar ko shirdipen',
+'columns'        => 'Uche vortorina:',
+'localtime'      => 'Thanutno vaxt',
+'timezoneoffset' => 'Ververipen',
+'guesstimezone'  => 'Le les katar o browser',
+'allowemail'     => 'De drom te aven e-mailurya katar aver jene',
+'defaultns'      => 'Rod savaxt vi kai kadale riga:',
+'default'        => 'acharuno',
+'prefs-files'    => 'Failurya',
+'youremail'      => 'Emailesko adress (kana kames)*',
+'yourrealname'   => 'Tiro chacho anav*',
+'yourlanguage'   => 'Ćhib:',
+'yournick'       => 'I xarni versyunya, le semnaturenge',
+'badsig'         => 'Bilachhi semnatura; dikh le tagurya HTML.',
 
 # User rights
 'editinguser' => "Editisaripen '''[[User:$1|$1]]''' ([[User talk:$1|{{int:talkpagelinktext}}]] | [[Special:Contributions/$1|{{int:contribslink}}]])",
@@ -341,12 +328,13 @@ Kana avilyan kathe doshatar, ja palpale.',
 'rc_categories_any'                 => 'Savegodi',
 
 # Recent changes linked
-'recentchangeslinked' => 'Pashvipnaske paruvimata',
+'recentchangeslinked'         => 'Pashvipnaske paruvimata',
+'recentchangeslinked-feed'    => 'Pashvipnaske paruvimata',
+'recentchangeslinked-toolbox' => 'Pashvipnaske paruvimata',
 
 # Upload
 'upload'      => 'Bichhal file',
 'uploadbtn'   => 'Bichhal file',
-'reupload'    => 'Pale bichhal',
 'filedesc'    => 'Xarno xalyaripen',
 'badfilename' => 'O chitrosko anav sas paruvdo; o nevo anav si "$1".',
 'savefile'    => 'Uxtav file',
@@ -355,7 +343,8 @@ Kana avilyan kathe doshatar, ja palpale.',
 'listfiles' => 'Patrinipen le chitrengo',
 
 # File description page
-'imagelinks' => 'Chitroske phandimata',
+'file-anchor-link' => 'Chitro',
+'imagelinks'       => 'Chitroske phandimata',
 
 # Unused templates
 'unusedtemplates'    => 'Bilabyarde sikavne',
@@ -391,7 +380,6 @@ Kana avilyan kathe doshatar, ja palpale.',
 # Watchlist
 'watchlist'        => 'Dikhipnaske lekha',
 'mywatchlist'      => 'Dikhipnaske lekha',
-'addedwatch'       => 'Thovdi ando patrinipen le patrinyange so arakhav len',
 'addedwatchtext'   => 'I patrin "[[:$1]]" sas thovdi andi tiri lista [[Special:Watchlist|le artikolengi so dikhes len]].
 Le neve paruvimata andar kadale patrya thai andar lenge vakyarimatenge patrya thona kathe, vi dikhena pen le <b>thule semnurenca</b> andi patrin le [[Special:RecentChanges|neve paruvimatenge]].
 
@@ -413,9 +401,8 @@ Kana kamesa te khoses kadaya patrin andar tiri lista le patryange so arakhes len
 'exblank'         => 'i patrin sas chuchi',
 'historywarning'  => 'Dikh! La patrya so kames to khoses la si la puranipen:',
 'actioncomplete'  => 'Agorisardi buti',
-'deletedtext'     => '"<nowiki>$1</nowiki>" sas khosli.
+'deletedtext'     => '"$1" sas khosli.
 Dikh ando $2 ek patrinipen le palutne butyange khosle.',
-'deletedarticle'  => '"$1" sas khosli.',
 
 # Rollback
 'rollback_short' => 'Palemavilipen',
@@ -459,7 +446,6 @@ Dikh ando $2 ek patrinipen le palutne butyange khosle.',
 'movepagebtn'     => 'Inger i patrin',
 'pagemovedsub'    => 'I patrin sas bićhaldi.',
 'movedto'         => 'ingerdi kai',
-'1movedto2'       => '[[$1]] bichhaldo kai [[$2]]',
 'delete_and_move' => 'Khos thai inger',
 
 # Export
@@ -524,7 +510,7 @@ Dikh ando $2 ek patrinipen le palutne butyange khosle.',
 # Attribution
 'anonymous'        => 'Bijangle labyarne kai {{SITENAME}}',
 'siteuser'         => 'Jeno kai {{SITENAME}} $1',
-'lastmodifiedatby' => 'Kadaya patrin sas paruvdi agoreste $2, $1 katar $3.', # $1 date, $2 time, $3 user
+'lastmodifiedatby' => 'Kadaya patrin sas paruvdi agoreste $2, $1 katar $3.',
 'others'           => 'aver',
 'siteusers'        => 'Jeno/e kai {{SITENAME}} $1',
 
@@ -540,13 +526,8 @@ Dikh ando $2 ek patrinipen le palutne butyange khosle.',
 'ilsubmit'     => 'Rod',
 
 # 'all' in various places, this might be different for inflected languages
-'recentchangesall' => 'sa',
-'imagelistall'     => 'savore',
-'watchlistall2'    => 'savore',
-'namespacesall'    => 'savore',
-
-# Trackbacks
-'trackbacklink' => 'Vurma',
+'watchlistall2' => 'savore',
+'namespacesall' => 'savore',
 
 # Delete conflict
 'deletedwhileediting' => 'Dikh: Kadaya patrin sas khosli de kana shirdyas (astardyas) te editisares la!',
@@ -555,7 +536,7 @@ Dikh ando $2 ek patrinipen le palutne butyange khosle.',
 'confirm_purge_button' => 'Va',
 
 # Special:Version
-'version' => 'Versiya', # Not used as normal message but as header for the special page itself
+'version' => 'Versiya',
 
 # Special:SpecialPages
 'specialpages' => 'Uzalutne patrya',
