@@ -104,55 +104,55 @@ $specialPageAliases = array(
 );
 
 $magicWords = array(
-	'redirect'              => array( '0', '#چوريو', '#REDIRECT' ),
-	'localmonth'            => array( '1', 'مقاميمهينو', 'LOCALMONTH', 'LOCALMONTH2' ),
-	'localmonthname'        => array( '1', 'مقاميمهينونالو', 'LOCALMONTHNAME' ),
-	'localday'              => array( '1', 'مقاميڏينهن', 'LOCALDAY' ),
-	'localday2'             => array( '1', 'مقاميڏينهن2', 'LOCALDAY2' ),
-	'localdayname'          => array( '1', 'مقاميڏينهننالو', 'LOCALDAYNAME' ),
-	'localyear'             => array( '1', 'مقاميسال', 'LOCALYEAR' ),
-	'localtime'             => array( '1', 'مقاميوقت', 'LOCALTIME' ),
-	'localhour'             => array( '1', 'مقاميڪلاڪ', 'LOCALHOUR' ),
-	'numberofpages'         => array( '1', 'صفحنجوتعداد', 'NUMBEROFPAGES' ),
-	'numberofarticles'      => array( '1', 'مضموننجوتعداد', 'NUMBEROFARTICLES' ),
-	'numberoffiles'         => array( '1', 'فائيلنجوتعداد', 'NUMBEROFFILES' ),
-	'numberofusers'         => array( '1', 'يوزرسجوتعداد', 'NUMBEROFUSERS' ),
-	'numberofedits'         => array( '1', 'ترميمنجوتعداد', 'NUMBEROFEDITS' ),
-	'pagename'              => array( '1', 'صفحيجوعنوان', 'PAGENAME' ),
-	'namespace'             => array( '1', 'نانئپولار', 'NAMESPACE' ),
-	'talkspace'             => array( '1', 'بحثپولار', 'TALKSPACE' ),
-	'subjectspace'          => array( '1', 'مضمونپولار', 'SUBJECTSPACE', 'ARTICLESPACE' ),
-	'fullpagename'          => array( '1', 'صحفيجوپورونالو', 'FULLPAGENAME' ),
-	'msg'                   => array( '0', 'نياپو:', 'MSG:' ),
-	'img_right'             => array( '1', 'ساڄو', 'right' ),
-	'img_left'              => array( '1', 'کاٻو', 'left' ),
-	'img_none'              => array( '1', 'ڪجهنه', 'none' ),
-	'img_width'             => array( '1', '$1 عڪسلون', '$1px' ),
-	'img_center'            => array( '1', 'مرڪز', 'center', 'centre' ),
-	'img_top'               => array( '1', 'سِرُ', 'top' ),
-	'img_middle'            => array( '1', 'وچ', 'middle' ),
-	'img_bottom'            => array( '1', 'تَرُ', 'bottom' ),
-	'sitename'              => array( '1', 'سرزميننالو', 'SITENAME' ),
-	'ns'                    => array( '0', 'نپ', 'NS:' ),
-	'localurl'              => array( '0', 'مقامييوآريل', 'LOCALURL:' ),
-	'grammar'               => array( '0', 'وياڪرڻ', 'GRAMMAR:' ),
-	'currentweek'           => array( '1', 'هلندڙهفتو', 'CURRENTWEEK' ),
-	'currentdow'            => array( '1', 'اڄوڪوڏينهن', 'CURRENTDOW' ),
-	'localweek'             => array( '1', 'مقاميهفتو', 'LOCALWEEK' ),
-	'plural'                => array( '0', 'جمع', 'PLURAL:' ),
-	'fullurl'               => array( '0', 'مڪمليوآريل', 'FULLURL:' ),
-	'currenttimestamp'      => array( '1', 'هلندڙوقتمهر', 'CURRENTTIMESTAMP' ),
-	'localtimestamp'        => array( '1', 'مقاميوقتمهر', 'LOCALTIMESTAMP' ),
-	'directionmark'         => array( '1', 'طرفنشان', 'DIRECTIONMARK', 'DIRMARK' ),
-	'language'              => array( '0', '#ٻولي:', '#LANGUAGE:' ),
-	'contentlanguage'       => array( '1', 'موادٻولي', 'CONTENTLANGUAGE', 'CONTENTLANG' ),
-	'pagesinnamespace'      => array( '1', 'نپ۾صفحا', 'PAGESINNAMESPACE:', 'PAGESINNS:' ),
-	'numberofadmins'        => array( '1', 'منتظمينجوتعداد', 'NUMBEROFADMINS' ),
-	'special'               => array( '0', 'خاص', 'special' ),
-	'filepath'              => array( '0', 'فائيلڏس', 'FILEPATH:' ),
-	'hiddencat'             => array( '1', '__ لڪل زمرو __', '__HIDDENCAT__' ),
-	'pagesincategory'       => array( '1', 'زمريجاصفحا', 'PAGESINCATEGORY', 'PAGESINCAT' ),
-	'pagesize'              => array( '1', 'صفحيجيماپ', 'PAGESIZE' ),
+	'redirect'                => array( '0', '#چوريو', '#REDIRECT' ),
+	'localmonth'              => array( '1', 'مقاميمهينو', 'LOCALMONTH', 'LOCALMONTH2' ),
+	'localmonthname'          => array( '1', 'مقاميمهينونالو', 'LOCALMONTHNAME' ),
+	'localday'                => array( '1', 'مقاميڏينهن', 'LOCALDAY' ),
+	'localday2'               => array( '1', 'مقاميڏينهن2', 'LOCALDAY2' ),
+	'localdayname'            => array( '1', 'مقاميڏينهننالو', 'LOCALDAYNAME' ),
+	'localyear'               => array( '1', 'مقاميسال', 'LOCALYEAR' ),
+	'localtime'               => array( '1', 'مقاميوقت', 'LOCALTIME' ),
+	'localhour'               => array( '1', 'مقاميڪلاڪ', 'LOCALHOUR' ),
+	'numberofpages'           => array( '1', 'صفحنجوتعداد', 'NUMBEROFPAGES' ),
+	'numberofarticles'        => array( '1', 'مضموننجوتعداد', 'NUMBEROFARTICLES' ),
+	'numberoffiles'           => array( '1', 'فائيلنجوتعداد', 'NUMBEROFFILES' ),
+	'numberofusers'           => array( '1', 'يوزرسجوتعداد', 'NUMBEROFUSERS' ),
+	'numberofedits'           => array( '1', 'ترميمنجوتعداد', 'NUMBEROFEDITS' ),
+	'pagename'                => array( '1', 'صفحيجوعنوان', 'PAGENAME' ),
+	'namespace'               => array( '1', 'نانئپولار', 'NAMESPACE' ),
+	'talkspace'               => array( '1', 'بحثپولار', 'TALKSPACE' ),
+	'subjectspace'            => array( '1', 'مضمونپولار', 'SUBJECTSPACE', 'ARTICLESPACE' ),
+	'fullpagename'            => array( '1', 'صحفيجوپورونالو', 'FULLPAGENAME' ),
+	'msg'                     => array( '0', 'نياپو:', 'MSG:' ),
+	'img_right'               => array( '1', 'ساڄو', 'right' ),
+	'img_left'                => array( '1', 'کاٻو', 'left' ),
+	'img_none'                => array( '1', 'ڪجهنه', 'none' ),
+	'img_width'               => array( '1', '$1 عڪسلون', '$1px' ),
+	'img_center'              => array( '1', 'مرڪز', 'center', 'centre' ),
+	'img_top'                 => array( '1', 'سِرُ', 'top' ),
+	'img_middle'              => array( '1', 'وچ', 'middle' ),
+	'img_bottom'              => array( '1', 'تَرُ', 'bottom' ),
+	'sitename'                => array( '1', 'سرزميننالو', 'SITENAME' ),
+	'ns'                      => array( '0', 'نپ', 'NS:' ),
+	'localurl'                => array( '0', 'مقامييوآريل', 'LOCALURL:' ),
+	'grammar'                 => array( '0', 'وياڪرڻ', 'GRAMMAR:' ),
+	'currentweek'             => array( '1', 'هلندڙهفتو', 'CURRENTWEEK' ),
+	'currentdow'              => array( '1', 'اڄوڪوڏينهن', 'CURRENTDOW' ),
+	'localweek'               => array( '1', 'مقاميهفتو', 'LOCALWEEK' ),
+	'plural'                  => array( '0', 'جمع', 'PLURAL:' ),
+	'fullurl'                 => array( '0', 'مڪمليوآريل', 'FULLURL:' ),
+	'currenttimestamp'        => array( '1', 'هلندڙوقتمهر', 'CURRENTTIMESTAMP' ),
+	'localtimestamp'          => array( '1', 'مقاميوقتمهر', 'LOCALTIMESTAMP' ),
+	'directionmark'           => array( '1', 'طرفنشان', 'DIRECTIONMARK', 'DIRMARK' ),
+	'language'                => array( '0', '#ٻولي:', '#LANGUAGE:' ),
+	'contentlanguage'         => array( '1', 'موادٻولي', 'CONTENTLANGUAGE', 'CONTENTLANG' ),
+	'pagesinnamespace'        => array( '1', 'نپ۾صفحا', 'PAGESINNAMESPACE:', 'PAGESINNS:' ),
+	'numberofadmins'          => array( '1', 'منتظمينجوتعداد', 'NUMBEROFADMINS' ),
+	'special'                 => array( '0', 'خاص', 'special' ),
+	'filepath'                => array( '0', 'فائيلڏس', 'FILEPATH:' ),
+	'hiddencat'               => array( '1', '__ لڪل زمرو __', '__HIDDENCAT__' ),
+	'pagesincategory'         => array( '1', 'زمريجاصفحا', 'PAGESINCATEGORY', 'PAGESINCAT' ),
+	'pagesize'                => array( '1', 'صفحيجيماپ', 'PAGESIZE' ),
 );
 
 $messages = array(
@@ -381,7 +381,6 @@ $messages = array(
 'unexpected'          => 'غير متوقع قدر: "$1"="$2".',
 'badtitle'            => 'غيردرست عنوان',
 'viewsource'          => 'ڪوڊ ڏسو',
-'viewsourcefor'       => 'براءِ $1',
 'protectedpagetext'   => 'هيءُ صفحو ترميمن کان تحفظيل آهي.',
 'viewsourcetext'      => 'توهان هن صفحي جو ڪوڊ ڏسي ۽ نقل ڪري سگھو ٿا:',
 'namespaceprotected'  => "توهان کي نانءُ پولار '''$1''' جا صفحا سنوارڻ جا اختيار ناهن.",
@@ -468,7 +467,9 @@ $messages = array(
 * بندش جو انجام: $6
 * بندش جو هدف: $7
 
-اهڙي روڪ تي بحث ڪرڻ لاءِ توهان $1 يا ڪنهن ٻي [[{{MediaWiki:Grouppage-sysop}}|منتظم]] سان رابطو ڪري سگھو ٿا. جيڪڏهن توهان جو درست [[Special:ترجيحات|کاتو ترجيحات]] ۾ درست برق ٽپال پتو درج ٿيل نه آهي ته توهان 'هن يوزر کي برق ٽپال ڪريو' وارو فيچر نه ٿا استعمال ڪري سگھو. توهان جو هاڻوڪو آءِ پي پتو $3 آهي، ۽ بندش سڃاڻپ $5 آهي. مهرباني ڪري ڪنهن به پڇا ڳاڇا يا لهوچڙ  لاءِ انهن مان ڪنهن هڪ يا ٻنهي جو حوالو ڏيندا.",
+اهڙي روڪ تي بحث ڪرڻ لاءِ توهان $1 يا ڪنهن ٻي [[{{MediaWiki:Grouppage-sysop}}|منتظم]] سان رابطو ڪري سگھو ٿا. جيڪڏهن توهان جو درست [[Special:ترجيحات|کاتو ترجيحات]] ۾ درست برق ٽپال پتو درج ٿيل نه آهي ته توهان 'هن يوزر کي برق ٽپال ڪريو' وارو فيچر نه ٿا 
+You cannot use the 'e-mail this user' feature unless a valid e-mail address is specified in your [[Special:Preferences|account preferences]] and you have not been blocked from using it.
+استعمال ڪري سگھو. توهان جو هاڻوڪو آءِ پي پتو $3 آهي، ۽ بندش سڃاڻپ $5 آهي. مهرباني ڪري ڪنهن به پڇا ڳاڇا يا لهوچڙ  لاءِ انهن مان ڪنهن هڪ يا ٻنهي جو حوالو ڏيندا.",
 'blockednoreason'            => 'سبب اڻڄاڻايل',
 'accmailtitle'               => 'ڳجھو لفظ اماڻجي چڪو.',
 'newarticle'                 => '(نئون)',
@@ -725,7 +726,6 @@ $1 {{PLURAL:$1|اکر|اکرن}} کان ننڍي هوڻ گھرجي.',
 'actioncomplete'        => 'ڪم پُورو',
 'deletedtext'           => '"$1" ڊهي چڪو آهي.
 تازو ڊاٺل صفحن جي فهرست لاءِ $2 ڏسندا.',
-'deletedarticle'        => '"[[$1]]" ڊهي چڪو',
 'dellogpage'            => 'ڊاٺ لاگ',
 'deletecomment'         => 'سبب:',
 'deleteotherreason'     => 'اڃا ڪو ٻيو سبب:',
@@ -828,7 +828,6 @@ $1 {{PLURAL:$1|اکر|اکرن}} کان ننڍي هوڻ گھرجي.',
 '''موادي صفحو پاڻ ته ڪاميابيءَ سان چُري ويو، پر لاڳاپيل مباحثي صفحو چُري نه سگھيو ڇاڪاڻ ته نئين عنوان تي اڳي ئي هڪ مباحثي صفحو موجود آهي. براءِ مهرباني انهن ٻنهي هٿ سان ضمائيندا.",
 'movedto'                 => 'چوريو ويو برسر',
 'movetalk'                => 'لاڳاپيل مباحثي صفحو چوريو',
-'1movedto2'               => '[[$1]] کي چوري [[$2]] تي رکيو ويو',
 'movelogpage'             => 'چورڻ لاگ',
 'movereason'              => 'سبب:',
 'revertmove'              => 'ورايو',
@@ -901,7 +900,7 @@ $1 {{PLURAL:$1|اکر|اکرن}} کان ننڍي هوڻ گھرجي.',
 
 # Media information
 'file-info-size' => '$1 × $2 عڪسلون، فائيل سائيز: $3، MIME ٽائيپ: $4',
-'file-nohires'   => '<small>اڃا سنهو تحلل ميسر ناهي.</small>',
+'file-nohires'   => 'اڃا سنهو تحلل ميسر ناهي.',
 'svg-long-desc'  => 'ايس وي جي فائيل، اٽڪل $1 × $2 عڪسلون، فائيل سائيز: $3',
 'show-big-image' => 'سنهو ترين تحلل',
 
