@@ -8,6 +8,7 @@
  * @file
  *
  * @author Ccaxjoj Iteja Z Iti Poop
+ * @author Kaganer
  * @author SeriCtam
  * @author Teak
  * @author Urhixidur
@@ -27,8 +28,7 @@ $messages = array(
 'tog-editsection'             => 'Ton ticpatlöx seccion [edit] linkám via',
 'tog-editsectiononrightclick' => 'Ton ticpatlöx seccion pok clickám mii<br /> seccion titelám iti (JavaScript)',
 'tog-showtoc'                 => 'Cohuatlöx insacualte (páhinám bajlip 3 text corridór mii)',
-'tog-rememberpassword'        => 'Qualtiinii he quimx canj jan ordinator iti',
-'tog-editwidth'               => 'Cui ticpatlöx janvam',
+'tog-rememberpassword'        => 'Qualtiinii he quimx canj jan ordinator iti (for a maximum of $1 {{PLURAL:$1|day|days}})',
 'tog-watchcreations'          => 'Plusöx páhinám he hun he listade cáminot',
 'tog-watchdefault'            => 'Plusöx páhinám he ticpatlöx he listade cáminot',
 'tog-watchmoves'              => 'Plusöx páhinám he yacom he listade cáminot',
@@ -119,12 +119,18 @@ $messages = array(
 'category-empty'         => "''Cayliib danjobam nihíl''",
 'listingcontinuesabbrev' => 'korb.',
 
-'mainpagetext' => "'''MediaWiki coccebj installöx successua zo mii.'''",
+'about'         => 'Miixaz',
+'article'       => 'Artículo',
+'newwindow'     => '(dansinám precquen)',
+'cancel'        => 'Antajöx',
+'moredotdotdot' => 'Tamläj...',
+'mypage'        => 'Hepáhina',
+'mytalk'        => 'Heczaxö',
+'anontalk'      => 'Czaxöde IP',
+'navigation'    => 'Navigacion',
+'and'           => '&#32;ö',
 
-'about'          => 'Miixaz',
-'article'        => 'Artículo',
-'newwindow'      => '(dansinám precquen)',
-'cancel'         => 'Antajöx',
+# Cologne Blue skin
 'qbfind'         => 'Hinuetzöx',
 'qbbrowse'       => 'Quetzexal',
 'qbedit'         => 'Ticpatlöx',
@@ -132,15 +138,8 @@ $messages = array(
 'qbpageinfo'     => 'Contextua',
 'qbmyoptions'    => 'Hepáhinám',
 'qbspecialpages' => 'Páhinám extravám',
-'moredotdotdot'  => 'Tamläj...',
-'mypage'         => 'Hepáhina',
-'mytalk'         => 'Heczaxö',
-'anontalk'       => 'Czaxöde IP',
-'navigation'     => 'Navigacion',
-'and'            => '&#32;ö',
-
-# Metadata in edit box
-'metadata_help' => 'Datade Meta:',
+'faq'            => 'Cocmíiit cmaa',
+'faqpage'        => 'Project:Cocmíiit cmaa',
 
 'errorpagetitle'    => 'Römj',
 'returnto'          => 'Jumpöx $1.',
@@ -153,7 +152,6 @@ $messages = array(
 'history'           => 'Historiám páhina',
 'history_short'     => 'Historiám',
 'updatedmarker'     => 'Par hiineditar visitua ciónsam',
-'info_short'        => 'Informacion',
 'printableversion'  => 'Cabjöxino printino',
 'permalink'         => 'Link permanentöj',
 'print'             => 'Printom',
@@ -188,7 +186,7 @@ $messages = array(
 'otherlanguages'    => 'Itóm pacehuatl iti',
 'redirectedfrom'    => '(Meniitomöxde $1)',
 'redirectpagesub'   => 'Meniitomöx páhina',
-'lastmodifiedat'    => "Jan páhina coccebjöx ticpatlöx iti'ab $2, $1.", # $1 date, $2 time
+'lastmodifiedat'    => "Jan páhina coccebjöx ticpatlöx iti'ab $2, $1.",
 'viewcount'         => '{{PLURAL:$1|1 ctam|$1 ctám}} coccebj cohuatlöx jan páhina.',
 'protectedpage'     => 'Páhina protecta',
 'jumpto'            => 'Jumpöx:',
@@ -199,7 +197,6 @@ $messages = array(
 'aboutsite'            => '{{SITENAME}} mii',
 'aboutpage'            => 'Project:Miilà',
 'copyright'            => 'Contentua coitáamb $1 tan.',
-'copyrightpagename'    => 'Copyright {{SITENAME}}',
 'copyrightpage'        => '{{ns:project}}:Copyrightám',
 'currentevents'        => 'Hualtezxes',
 'currentevents-url'    => 'Project:Hualtezxes',
@@ -207,8 +204,6 @@ $messages = array(
 'disclaimerpage'       => 'Project:Isoj cacóomx geniiraloj',
 'edithelp'             => 'Help ticpatlöx',
 'edithelppage'         => 'Help:Ticpatlöx',
-'faq'                  => 'Cocmíiit cmaa',
-'faqpage'              => 'Project:Cocmíiit cmaa',
 'helppage'             => 'Help:Caálixötöj',
 'mainpage'             => 'Caálixötöj',
 'mainpage-description' => 'Caálixötöj',
@@ -281,10 +276,6 @@ Hunattemptöx database query coccebjöx:
 "$1"
 funccion xi "$2".
 MySQL returnöx römj iti "$3: $4"',
-'noconnect'            => 'Sorry! Wiki zo expiriencom cy technicy pac ö necontactom serverde database zo. <br />
-$1',
-'nodb'                 => 'Neselectam database $1',
-'cachederror'          => 'Jan coccebj copynam cachenamde páhina Neces ö necoccebj updatenom.',
 'laggedslavemode'      => 'Attencion: Páhina necoccebj updatenám cmaa.',
 'readonly'             => 'Database protectáme',
 'enterlockreason'      => 'Enterom raede lockom zo, includom estimacionde janxepe lockom zo releasom',
@@ -307,14 +298,13 @@ Sysop zo locköx zo xuniim jan rae': $1",
 'badtitle'             => 'Ahisharliit',
 'badtitletext'         => 'Zo páhina coccebj ahisharliit zo.
 Jan pos-coccebj plusöxde 1 jöx 1 characterám jan nepos-coccebj usadas titlenám iti.',
-'perfcached'           => 'Jan data coccebj cache ö necoccebj updatenom.',
-'perfcachedts'         => "Jan data coccebj cache ö coccebjöx updatenom $1 'de.",
+'perfcached'           => 'Jan data coccebj cache ö necoccebj updatenom. A maximum of {{PLURAL:$1|one result is|$1 results are}} available in the cache.',
+'perfcachedts'         => "Jan data coccebj cache ö coccebjöx updatenom $1 'de. A maximum of {{PLURAL:$4|one result is|$4 results are}} available in the cache.",
 'querypage-no-updates' => 'Updatenámde jan páhina coccebj disablenöx cmaa. Jan data necanj cmaa.',
 'wrong_wfQuery_params' => 'Parameterám incorrectámde wfQuery()<br />
 Funccion: $1<br />
 Query: $2',
 'viewsource'           => 'Cohuatlöx sourcenam',
-'viewsourcefor'        => '$1 mii',
 'protectedpagetext'    => 'Jan páhina coccebj lockom neticpatlöx pos-poop.',
 'viewsourcetext'       => 'Mecohuatlöx ö copynom sourcenam zode jan páhina:',
 'protectedinterface'   => "Jan páhina coccebj textuade interface software zo 'de ö coccebj lockom neticpatlöx abusenam.",
@@ -323,11 +313,9 @@ Query: $2',
 'cascadeprotected'     => 'Jan páhina coccebj protectöxde ticpatlöx, zo coccebj cascadande jan {{PLURAL:$1|páhina|páhinám}}, jan coccebj protëctox cascadanöx opcion zo mii:
 $2',
 'namespaceprotected'   => "Me necoccebj permiccion ticpatlöx páhinám '''$1''' ipartuatl zo iti.",
-'customcssjsprotected' => 'Me necoccebj permiccion ticpatlöx jan páhina, zo coccebj diijömde caitom quáatlaác.',
 'ns-specialprotected'  => 'Páhinámde {{ns:special}} zo iti neticpatlöx.',
 
 # Login and logout pages
-'logouttitle'                => 'Caitom cuípo',
 'logouttext'                 => "'''Me cuípo.'''
 
 Mecontinudad usadad {{SITENAME}} anon jïx me caápo dajcaitom ö jömcaitom.
@@ -335,11 +323,10 @@ Páhinám pac continudad displayom dajme caápo, jánclearom mecachede browser."
 'welcomecreation'            => "== Q'$1! ==
 
 Mecaitom coccebj creatöx. Quiix hequáatlaácde {{SITENAME}} pos-poop.",
-'loginpagetitle'             => 'Caitom caápo',
 'yourname'                   => 'Caitom ID:',
 'yourpassword'               => 'Quimx canj:',
 'yourpasswordagain'          => 'Vanquimx canj:',
-'remembermypassword'         => 'Qualtiinii he quimx canj jan ordinator iti',
+'remembermypassword'         => 'Qualtiinii he quimx canj jan ordinator iti (for a maximum of $1 {{PLURAL:$1|day|days}})',
 'yourdomainname'             => 'Hedomino:',
 'externaldberror'            => 'Pos-römjde authenticacionde database extername jöx me necoccebj permiccionde updatan mecaitom externom.',
 'login'                      => 'Caápo',
@@ -357,26 +344,14 @@ Mecaitom coccebj creatöx. Quiix hequáatlaácde {{SITENAME}} pos-poop.",
 'createaccountmail'          => 'caxuatl e-iitom',
 'badretype'                  => 'Quimx cánj zo misoj nematchöx.',
 'userexists'                 => 'IDde caitom coccebj usadad. Submitom hunnom.',
-'youremail'                  => 'E-iitom:',
-'username'                   => 'Caitom ID:',
-'uid'                        => 'ID comháars:',
-'yourrealname'               => 'Comcáacuatl:',
-'yourlanguage'               => 'Itom ö:',
-'yourvariant'                => 'Ccójbam:',
-'yournick'                   => 'Brazzi:',
-'badsig'                     => 'Signatura raw invalidaw; checkom HTML tagám.',
-'badsiglength'               => 'Brazzi coccebj bajlip; brazzi correctom minusde $1 characterám.',
-'email'                      => 'E-iitom',
-'prefs-help-realname'        => 'Comcáacuatl coccebj opcional, zo xuniim plusöxde attribucionde menaffortua.',
 'loginerror'                 => 'Römjde caápo',
-'prefs-help-email'           => 'Adressade e-iitom coccebj opcional, zo enable diijömde caitom contactom me mecaitom jöx meczaxöde caitom sans comcáacuatl ajbul.',
 'nocookiesnew'               => 'IDde caitom zo coccebj creatöx, me necaápo. {{SITENAME}} usadad cookie caápo caitóm. Me necoccebj cookie. Enable cookie, caápo quimx canj ö caitom.',
 'nocookieslogin'             => '{{SITENAME}} usadad cookie caápo caitóm. Me necoccebj cookie. Enable cookie ö caápo.',
 'noname'                     => 'Me necoccebj IDde caitom validom caápospecified.',
 'loginsuccesstitle'          => 'Caápo tampua',
 'loginsuccess'               => "'''Me coccebj caápo {{SITENAME}} itide \"\$1\".'''",
 'nosuchuser'                 => 'Jan caitom necoccebj zo, ID "$1". Cohuatlöx mecuáxiit jöx creatom huncaitom.',
-'nosuchusershort'            => 'Jan caitom necoccebj zo, ID "<nowiki>$1</nowiki>". Cohuatlöx mecuáxiit.',
+'nosuchusershort'            => 'Jan caitom necoccebj zo, ID "$1". Cohuatlöx mecuáxiit.',
 'nouserspecified'            => 'Me coccebj IDde caitom caápo.',
 'wrongpassword'              => 'Römjde quimx canj. Vanquimx canj.',
 'wrongpasswordempty'         => 'Quimx canj blankanj. Vanquimx canj.',
@@ -407,17 +382,16 @@ confirmom account zo coccebj de'me.",
 'accountcreatedtext'         => 'Jönneram $1 mii puo.',
 'loginlanguagelabel'         => 'Itom: $1',
 
-# Password reset dialog
-'resetpass'               => "Account quimx canj'reset",
-'resetpass_announce'      => "Me caápo code temp e-iitomöx mii. Fini caápo, me reset' hunquimx canj cmaadexepe:",
-'resetpass_header'        => "Reset'quimx canj",
-'oldpassword'             => 'Janquimx canj:',
-'newpassword'             => 'Hunquimx canj:',
-'retypenew'               => 'Vanhunquimx canj:',
-'resetpass_submit'        => 'Vanquimx canj ö caápo',
-'resetpass_success'       => 'Me quimx canj coccebj quiixde success! Caápo cmaa...',
-'resetpass_bad_temporary' => "Quimx canj temp invalidanj. Me coccebj reset' quimx canjde success jöx requestan hunquimx canj temp pac.",
-'resetpass_forbidden'     => 'Quimx cánj nereset jan wiki iti',
+# Change password dialog
+'resetpass'           => "Account quimx canj'reset",
+'resetpass_announce'  => "Me caápo code temp e-iitomöx mii. Fini caápo, me reset' hunquimx canj cmaadexepe:",
+'resetpass_header'    => "Reset'quimx canj",
+'oldpassword'         => 'Janquimx canj:',
+'newpassword'         => 'Hunquimx canj:',
+'retypenew'           => 'Vanhunquimx canj:',
+'resetpass_submit'    => 'Vanquimx canj ö caápo',
+'resetpass_success'   => 'Me quimx canj coccebj quiixde success! Caápo cmaa...',
+'resetpass_forbidden' => 'Quimx cánj nereset jan wiki iti',
 
 # Edit page toolbar
 'bold_sample'     => 'Text ccomca',
@@ -430,8 +404,6 @@ confirmom account zo coccebj de'me.",
 'extlink_tip'     => 'Link extern (¡hajbazxo http:// ö!)',
 'headline_sample' => 'Text corridor',
 'headline_tip'    => 'Text corridor 2',
-'math_sample'     => 'Heformula cuerte damir',
-'math_tip'        => 'Formula mathematatl (LaTeX)',
 'nowiki_sample'   => 'Neformattám cuerte damir',
 'nowiki_tip'      => 'Neformatöxde wiki',
 'image_sample'    => 'Cuáxiit.jpg',
@@ -482,11 +454,7 @@ Me contactam $1 jöx pac [[{{MediaWiki:Grouppage-sysop}}|sysop]] discussom iti b
 Me nenusor e-iitom päzxo hab' adressade e-iitom validom coccebj [[Special:Preferences|mequáatlaác]] ö'me neblockomde e-iitom.
 
 Me IDde block coccebj $5. Includam 1 jöx 2 pac querinám iti.",
-'blockedoriginalsource'     => "Sourcenam zode '''$1''' coccebj cohuatlöx:",
-'blockededitsource'         => "Textua zode '''meticpatlöxde''' '''$1''' coccebj cohuatlöx:",
-'whitelistedittitle'        => 'Caápo Neces ticpatlöx',
 'whitelistedittext'         => 'Mecoccebj $1 ticpatlöx páhinám.',
-'confirmedittitle'          => 'Confirmacionde e-iitom coccebj Neces ticpatlöx',
 'confirmedittext'           => "Me confirmöx menadressade de e-iitom ticpatlöx 'depre. Set' ö validatenan menadressade IP [[Special:Preferences|hequáatlaác]] mii.",
 'nosuchsectiontitle'        => "Ne'dáár partam",
 'nosuchsectiontext'         => "Me pos-xuniim ticpatlöx ne'dáár partam.",
@@ -503,10 +471,11 @@ Me coccebj römjasi poop, clickom meback-buttonde browser coccebj perfectua.',
 'anontalkpagetext'          => "----''Jan coccebj czaxö zode caitomde IDde adressade IP. Isój necoccebj caápo. Jan coccebj rae'de usadadde adressade IP numerical identificacion 'prenisój. Plusöxde caitom pos-coccebj jan adressade IP. Me pos-coccebj anonimo ö commentua irrevelantua coccebj directomde me poop, [[Special:UserLogin|caápo-jande]] exitom confucion diijömde IP-caitóm mii.''",
 'noarticletext'             => 'Jan páhina necoccebj textua zo, me pos-coccebj [[Special:Search/{{PAGENAME}}|yahöx jan páhina]] diijömde páhinám iti jöx [{{fullurl:{{FULLPAGENAME}}|action=edit}} ticpatlöx jan páhina].',
 'clearyourcache'            => "'''Notificacion:''' Xuniim 'depre, me pos-coccebj bypassöx mecachede browser caitomi quiíx. '''Mozilla / Firefox / Safari:''' quan ti caitomde ''Shift'' zoxepe clickom ''Reload'', jöx cuápook zo ti ''Ctrl-Shift-R'' (''Cmd-Shift-R'' Apple Mac iti); '''IE:''' quan ti ''Ctrl'' zoxepe clickom ''Refresh'', jöx cuápook zo ti ''Ctrl-F5''; '''Konqueror:''': clickom buttonde ''Reload'' zo, jöx cuápook zo iti ''F5''; '''Opera''' caitóm pos-coccebj clairomde cache completementua ''Tools→Preferences'' iti.",
-'usercssjsyoucanpreview'    => "'''Tip:''' Usadad 'Cohuatlöx cuáxiit' testom me hun CSS/JS xuniim 'depre.",
+'usercssyoucanpreview'      => "'''Tip:''' Usadad 'Cohuatlöx cuáxiit' testom me hun CSS xuniim 'depre.",
+'userjsyoucanpreview'       => "'''Tip:''' Usadad 'Cohuatlöx cuáxiit' testom me hun JS xuniim 'depre.",
 'usercsspreview'            => "'''He cuáxiit he CSSde caitom, zo necoccebj xuniim!'''",
 'userjspreview'             => "'''He cuáxiit/testom he JavaScriptde caitom, zo necoccebj xuniim!'''",
-'userinvalidcssjstitle'     => "'''Attencion:''' Skin \"\$1\" coccebj ne'dáár. Regardom .css ö .js páhinám usadad titlenam lowercase zo, yanuiíxzo mii yahöxde ti {{ns:user}}:Foo/monobook.css opposadadde {{ns:user}}:Foo/Monobook.css.",
+'userinvalidcssjstitle'     => "'''Attencion:''' Skin \"\$1\" coccebj ne'dáár. Regardom .css ö .js páhinám usadad titlenam lowercase zo, yanuiíxzo mii yahöxde ti {{ns:user}}:Foo/vector.css opposadadde {{ns:user}}:Foo/Vector.css.",
 'updated'                   => '(varupdatenám)',
 'note'                      => "'''Notificacion:'''",
 'previewnote'               => "'''Jan coccebj cuáxiit zo; quiíx necoccebj xuniim!'''",
@@ -518,7 +487,7 @@ Nexajvon. Jan necoccebj naxajvon poop, cuípo ö caápo.'''",
 ''Jan wiki coccebj HTML raw enablenom, cuáxiit zo coccebj camaátde precaucion JavaScripts caniim.''
 
 '''Jan coccebj ticpatlöx legimatöx poop, reprocessom. Jan necoccebj processom poop, cuípo ö caápo.'''",
-'token_suffix_mismatch'     => "'''Meticpatlöx coccebj rejectöx meclient cahöx characteromde punctacion zo ticpatlöx zo iti. TicpatlÖx zo coccebj rejectöxde preventua corrupcionde textuade páhina zo. 
+'token_suffix_mismatch'     => "'''Meticpatlöx coccebj rejectöx meclient cahöx characteromde punctacion zo ticpatlöx zo iti. TicpatlÖx zo coccebj rejectöxde preventua corrupcionde textuade páhina zo.
 Jan lajxepe occuram me usadad proxy service anon web-based buggy.'''",
 'editing'                   => 'Ticpatlöx $1',
 'editingsection'            => 'Ticpatlöx $1 (seccion)',
@@ -529,8 +498,6 @@ Jan lajxepe occuram me usadad proxy service anon web-based buggy.'''",
 'nonunicodebrowser'         => "'''ATTENCION: Mebrowser necoccebj compliantede 'unicode' (characterám sans huáp ti). Workaround coccebj hant itide me permiccion ticpatlöx páhinám: non-ASCII characterám coccebj codes hexidecimales.'''",
 'editingold'                => "'''ATTENCION: Me coccebj ticpatlöx revicion outdatenam zode jan páhina. Me xuniim zo, jömde quiíx hunde jan revicion coccebj delar poop.'''",
 'yourdiff'                  => 'Quiíx',
-'longpagewarning'           => "'''ATTENCION: Jan páhina coccebj $1 kilobynám; browserám pac pos-coccebj problemámde ticpatlöx páhinám necade jöx plusöxde 32 kb.
-Cahöx ticpatlöx jan páhina minöx seccion iti.'''",
 'longpageerror'             => "'''RÖMJ: Textua zo mexuniim coccebj $1 kilobytenám, jan coccebj plusöxde maxde $2 kilobytenám. Zo necoccebj xuniim.'''",
 'readonlywarning'           => "'''ATTENCION: Database zo coccebj lockomde kyépöx, zo necoccebj posde xuniim meticpatlöx cmaa. Me coccebj considerom ''cut-n-paste'' textua zo ciúchande textua iti ö xuniimde diijömdexepe.'''",
 'protectedpagewarning'      => "'''ATTENCION: Jan páhina coccebj lockomde sysopám coccebj ticpatlöx zo permiccional.'''",
@@ -564,7 +531,7 @@ Rae' zo xuniim $3 mii coccebj ''$2''",
 'nohistory'           => 'Jan páhina necoccebj históriade ticpatlöx.',
 'currentrev'          => 'Revicion cmaa',
 'revisionasof'        => 'Revicionde $1',
-'revision-info'       => "Revicionde $1 'de $2", # Additionally available: $3: revision id
+'revision-info'       => "Revicionde $1 'de $2",
 'previousrevision'    => '←Janrevicion',
 'nextrevision'        => 'Hunrevicion→',
 'currentrevisionlink' => 'Revicion currentuanon',
@@ -576,7 +543,6 @@ Rae' zo xuniim $3 mii coccebj ''$2''",
 'histlegend'          => "Seleccionde quiíx: xuniim cui radio zode vercion zode comparar ö click 'enter' jöx click bazoniiniitöxamde vyu !-cmaa uisan.<br />
 Informacion: (curt) = quiíxde vercion currentua,
 (hunl) = quiíxde vercion precedatöxuam, b = ticpatlöx bajlöxam.",
-'deletedrev'          => '[ëjmet]',
 'histfirst'           => 'Xepe',
 'histlast'            => 'Cmaa',
 'historysize'         => '($1 bytenám)',
@@ -585,7 +551,7 @@ Informacion: (curt) = quiíxde vercion currentua,
 # Revision feed
 'history-feed-title'          => 'Históriade revicion',
 'history-feed-description'    => 'Históriade revicion jande páhina wiki zo iti',
-'history-feed-item-nocomment' => '$1 öl $2 mii', # user at time
+'history-feed-item-nocomment' => '$1 öl $2 mii',
 
 # Revision deletion
 'rev-deleted-comment'     => '(delatom commentua)',
@@ -597,13 +563,11 @@ Informacion: (curt) = quiíxde vercion currentua,
 'revdelete-selected'      => "'''{{PLURAL:$2|Revicion selectonde|Revición selectónde}} $1:'''",
 'revdelete-legend'        => 'Xuniim restricción',
 'revdelete-hide-text'     => 'Camaát textuade revicion',
+'revdelete-hide-image'    => 'Cohuatlöx contentua ciúchan',
 'revdelete-hide-name'     => 'Camaát accion öjaim',
 'revdelete-hide-comment'  => 'Camaát commentuade ticpatlöx',
 'revdelete-hide-user'     => 'Camaát IDde caitom/IDde IP',
-'revdelete-hide-image'    => 'Cohuatlöx contentua ciúchan',
 'revdelete-log'           => 'Ra:',
-'revdelete-logentry'      => 'quiixöx revicion visibilitiitde [[$1]]',
-'logdelete-logentry'      => 'quiixöx eventua visibilitiitde [[$1]]',
 
 # Diffs
 'history-title'           => 'Históriade revicionde "$1"',
@@ -617,53 +581,59 @@ Informacion: (curt) = quiíxde vercion currentua,
 'searchresulttext'      => 'Plusöxde informaciónde yahöx {{SITENAME}} iti, jumpöx [[{{MediaWiki:Helppage}}|{{int:help}}]].',
 'searchsubtitle'        => "Me yahöx '''[[:$1]]''' iti",
 'searchsubtitleinvalid' => "Me yahöx '''$1''' iti",
-'noexactmatch'          => "'''Páhina zo \"\$1\" coccebj ne'dáár.''' Mecoccebj [[:\$1|hunpáhinámom]].",
-'prevn'                 => 'jan $1',
-'nextn'                 => 'hun $1',
-'viewprevnext'          => 'Cohuatlöx ($1) ($2) ($3)',
+'prevn'                 => 'jan {{PLURAL:$1|$1}}',
+'nextn'                 => 'hun {{PLURAL:$1|$1}}',
+'viewprevnext'          => 'Cohuatlöx ($1 {{int:pipe-separator}} $2) ($3)',
 'searchhelp-url'        => 'Help:Caálixötöj',
 'powersearch'           => 'Yahöx',
 
+# Quickbar
+'qbsettings'      => 'Zuónaát',
+'qbsettings-none' => 'Nepartám',
+
 # Preferences page
-'preferences'           => 'Quáatlaác',
-'mypreferences'         => 'Hequáatlaác',
-'prefs-edits'           => 'Ticpatlöx jöxualtec ID-cort:',
-'prefsnologin'          => 'Necaápo',
-'prefsnologintext'      => 'Zo coccebj Neces [[Special:UserLogin|caápo]] quiixom hequáatlaác.',
-'qbsettings'            => 'Zuónaát',
-'qbsettings-none'       => 'Nepartám',
-'changepassword'        => "Reset'quimx canj",
-'skin'                  => 'Zuláugaum',
-'skin-preview'          => 'Cuáxiit',
-'math'                  => 'HTML-cuat',
-'dateformat'            => 'Formatumde datum',
-'datedefault'           => 'Diiquáatlaac',
-'datetime'              => 'Datum ö xepe',
-'math_unknown_error'    => 'römj ác',
-'math_unknown_function' => 'functión ác',
-'math_lexing_error'     => 'römjde lexám',
-'math_syntax_error'     => 'römjde syntáx',
-'prefs-personal'        => 'Caitom profile',
-'prefs-rc'              => 'Camjöx cmaa',
-'prefs-watchlist'       => 'Listade cáminot',
-'prefs-misc'            => 'Jömc',
-'saveprefs'             => 'Xuniim',
-'resetprefs'            => "Reset'",
-'textboxsize'           => 'Ticpatlöx',
-'rows'                  => 'Rowám:',
-'columns'               => 'Columnám:',
-'searchresultshead'     => 'Yahöx',
-'savedprefs'            => 'Hequáatlaác coccebj xuniimöx.',
-'timezonelegend'        => 'Zonede xepe',
-'timezonetext'          => '¹Xepede zaah quij iitax mexepe locale quiixomde xepede servere (UTC).',
-'localtime'             => 'Xepe locale',
-'timezoneoffset'        => "Minus'set¹",
-'servertime'            => 'Xepede server',
-'guesstimezone'         => "Xuniimyabuatlecaún dai'browser",
-'allowemail'            => 'Pos-coccebj e-iitomde diijömde caitóm',
-'defaultns'             => 'Yahöx jan ipartuatl iti auto:',
-'default'               => 'auto',
-'files'                 => 'Ciúchán',
+'preferences'         => 'Quáatlaác',
+'mypreferences'       => 'Hequáatlaác',
+'prefs-edits'         => 'Ticpatlöx jöxualtec ID-cort:',
+'prefsnologin'        => 'Necaápo',
+'prefsnologintext'    => 'Zo coccebj Neces [[Special:UserLogin|caápo]] quiixom hequáatlaác.',
+'changepassword'      => "Reset'quimx canj",
+'prefs-skin'          => 'Zuláugaum',
+'skin-preview'        => 'Cuáxiit',
+'datedefault'         => 'Diiquáatlaac',
+'prefs-datetime'      => 'Datum ö xepe',
+'prefs-personal'      => 'Caitom profile',
+'prefs-rc'            => 'Camjöx cmaa',
+'prefs-watchlist'     => 'Listade cáminot',
+'prefs-misc'          => 'Jömc',
+'saveprefs'           => 'Xuniim',
+'resetprefs'          => "Reset'",
+'prefs-editing'       => 'Ticpatlöx',
+'rows'                => 'Rowám:',
+'columns'             => 'Columnám:',
+'searchresultshead'   => 'Yahöx',
+'savedprefs'          => 'Hequáatlaác coccebj xuniimöx.',
+'timezonelegend'      => 'Zonede xepe',
+'localtime'           => 'Xepe locale',
+'timezoneoffset'      => "Minus'set¹",
+'servertime'          => 'Xepede server',
+'guesstimezone'       => "Xuniimyabuatlecaún dai'browser",
+'allowemail'          => 'Pos-coccebj e-iitomde diijömde caitóm',
+'defaultns'           => 'Yahöx jan ipartuatl iti auto:',
+'default'             => 'auto',
+'prefs-files'         => 'Ciúchán',
+'youremail'           => 'E-iitom:',
+'username'            => 'Caitom ID:',
+'uid'                 => 'ID comháars:',
+'yourrealname'        => 'Comcáacuatl:',
+'yourlanguage'        => 'Itom ö:',
+'yourvariant'         => 'Ccójbam:',
+'yournick'            => 'Brazzi:',
+'badsig'              => 'Signatura raw invalidaw; checkom HTML tagám.',
+'badsiglength'        => 'Brazzi coccebj bajlip; brazzi correctom minusde $1 characterám.',
+'email'               => 'E-iitom',
+'prefs-help-realname' => 'Comcáacuatl coccebj opcional, zo xuniim plusöxde attribucionde menaffortua.',
+'prefs-help-email'    => 'Adressade e-iitom coccebj opcional, zo enable diijömde caitom contactom me mecaitom jöx meczaxöde caitom sans comcáacuatl ajbul.',
 
 # User rights
 'userrights-lookup-user'   => "Yoc' polámde caitom",
@@ -724,13 +694,14 @@ Informacion: (curt) = quiíxde vercion currentua,
 'newsectionsummary'                 => '/* $1 */ hunseccion',
 
 # Recent changes linked
-'recentchangeslinked'       => 'Quiix hámíigonix',
-'recentchangeslinked-title' => 'Quiix hámíigonixde "$1"',
+'recentchangeslinked'         => 'Quiix hámíigonix',
+'recentchangeslinked-feed'    => 'Quiix hámíigonix',
+'recentchangeslinked-toolbox' => 'Quiix hámíigonix',
+'recentchangeslinked-title'   => 'Quiix hámíigonixde "$1"',
 
 # Upload
 'upload'            => 'Ciúchan uploadan',
 'uploadbtn'         => 'Ciúchan uploadan',
-'reupload'          => 'Re-uploadan',
 'uploadnologin'     => 'Necaápo',
 'uploadnologintext' => 'Zo coccebj Neces [[Special:UserLogin|caápo]] (re-)uploadande ciúchán.',
 'uploaderror'       => 'Römjde uploadan',
@@ -759,6 +730,7 @@ Informacion: (curt) = quiíxde vercion currentua,
 'upload-curl-error28' => 'Time-outde uploadan',
 
 'license'           => 'Licenciónom:',
+'license-header'    => 'Licenciónom:',
 'nolicense'         => 'Seleccion coccebj hun',
 'license-nopreview' => '(Necuáxiit)',
 
@@ -773,6 +745,7 @@ Informacion: (curt) = quiíxde vercion currentua,
 'listfiles_description' => 'Discripcion',
 
 # File description page
+'file-anchor-link'          => 'Ciúchan',
 'filehist'                  => 'Historiade ciúchan',
 'filehist-deleteall'        => 'delatom jömde man',
 'filehist-deleteone'        => 'delatom jande man',
@@ -784,8 +757,6 @@ Informacion: (curt) = quiíxde vercion currentua,
 'filehist-filesize'         => 'Bajlipde ciúchan',
 'filehist-comment'          => 'Commentua',
 'imagelinks'                => 'Linkám',
-'shareduploadwiki-linktext' => 'discripcionde ciúchan páhina',
-'noimage-linktext'          => 'z(o) uploadan',
 'uploadnewversion-linktext' => 'Uploadan hunvercion zode jan ciúchan',
 
 # File reversion
@@ -829,8 +800,8 @@ Informacion: (curt) = quiíxde vercion currentua,
 
 'brokenredirects'        => 'Meniitomöx linkám nedireccion',
 'brokenredirectstext'    => 'Jan meniitomöx linkomde neday ti camiintivuatl páhinám:',
-'brokenredirects-edit'   => '(ticpatlöx)',
-'brokenredirects-delete' => '(delatom)',
+'brokenredirects-edit'   => 'ticpatlöx',
+'brokenredirects-delete' => 'delatom',
 
 # Miscellaneous special pages
 'nbytes'              => '$1 {{PLURAL:$1|byte|bytenám}}',
@@ -905,12 +876,9 @@ iitom e-iitomde diijömde caitóm.',
 # Watchlist
 'watchlist'        => 'He listade cáminot',
 'mywatchlist'      => 'He listade cáminot',
-'watchlistfor'     => "('''$1''' mii)",
 'nowatchlist'      => 'Hecoccebj 0 itémii helistade cáminot iti.',
 'watchnologin'     => 'Necaápo',
 'watchnologintext' => 'Zo coccebj Neces [[Special:UserLogin|caápo]] ticpatlöx helistade cáminot.',
-'addedwatch'       => 'Plusöxaj listade cáminot',
-'removedwatch'     => 'Delatajde he listade cáminot',
 'removedwatchtext' => 'Páhina zo "[[:$1]]" coccebj delataj me listade cáminot.',
 'watch'            => 'Cáminot',
 'watchthispage'    => 'Cáminot jan páhina',
@@ -953,6 +921,7 @@ iitom e-iitomde diijömde caitóm.',
 'mycontris'     => 'Hecontribución',
 'uctop'         => '(quániit)',
 
+'sp-contributions-talk'     => 'Czaxö',
 'sp-contributions-search'   => 'Yahöx contribución mii',
 'sp-contributions-username' => 'Addressade IP jöx caitom ID:',
 'sp-contributions-submit'   => 'Yahöx',
@@ -963,7 +932,6 @@ iitom e-iitomde diijömde caitóm.',
 
 # Block/unblock
 'blockip'                 => 'Block caitom',
-'ipaddress'               => 'Addressade IP:',
 'ipadressorusername'      => 'Addressade IP jöx caitom ID:',
 'ipbreason'               => 'Ra:',
 'ipbreasonotherlist'      => "Ra pac'de",
@@ -978,7 +946,6 @@ iitom e-iitomde diijömde caitóm.',
 'unblockip'               => 'Diiblockom caitom',
 'ipusubmit'               => 'Diiblockom jan adressa',
 'ipblocklist-legend'      => 'Yahöx caimát blockát pac',
-'ipblocklist-username'    => 'Caitom ID jöx addressade IP:',
 'ipblocklist-submit'      => 'Yahöx',
 'anononlyblock'           => 'Anonytiit',
 'emailblock'              => "e-iitom c'blockan",
@@ -1005,7 +972,6 @@ iitom e-iitomde diijömde caitóm.',
 'movepagebtn'      => 'Yacom páhina',
 'movedto'          => 'yacomöxde',
 'movetalk'         => 'Yacom czaxö páhina yodina ipríi',
-'1movedto2'        => '[[$1]] yacomöxde [[$2]]',
 'movereason'       => 'Ra:',
 'delete_and_move'  => 'Delatom ö yacom',
 
@@ -1058,11 +1024,8 @@ iitom e-iitomde diijömde caitóm.',
 # Spam protection
 'spambot_username' => 'MediaWiki nespam',
 
-# Info page
-'infosubtitle' => 'Informacionde páhina',
-
 # Media information
-'widthheightpage' => '$1×$2, $3 páhinám',
+'widthheightpage' => '$1 × $2, $3 páhinám',
 
 # Special:NewFiles
 'showhidebots' => '($1 botám)',
@@ -1080,11 +1043,9 @@ iitom e-iitomde diijömde caitóm.',
 'exif-focalplaneresolutionunit-2' => 'inchám',
 
 # 'all' in various places, this might be different for inflected languages
-'recentchangesall' => 'jöxdem',
-'imagelistall'     => 'jöxdem',
-'watchlistall2'    => 'jöxdem',
-'namespacesall'    => 'jöxdem',
-'monthsall'        => 'jöxdem',
+'watchlistall2' => 'jöxdem',
+'namespacesall' => 'jöxdem',
+'monthsall'     => 'jöxdem',
 
 # action=purge
 'confirm_purge_button' => 'ton',
@@ -1099,7 +1060,7 @@ iitom e-iitomde diijömde caitóm.',
 'autosumm-new' => 'Hunpáhina: $1',
 
 # Special:Version
-'version' => 'Vercion', # Not used as normal message but as header for the special page itself
+'version' => 'Vercion',
 
 # Special:SpecialPages
 'specialpages' => 'Páhinám extravám',
