@@ -289,7 +289,6 @@ Lista ida pájina espesiál nian [[Special:SpecialPages|iha ne'e]].",
 'missingarticle-rev'  => '(version#: $1)',
 'missingarticle-diff' => '(Dif.: $1, $2)',
 'viewsource'          => 'Lee testu',
-'viewsourcefor'       => 'ba $1',
 'viewsourcetext'      => 'Ó bele lee no kopia testu pájina nian:',
 'namespaceprotected'  => "Ó la iha priviléjiu ba edita pájina sira iha espasu '''$1'''.",
 'ns-specialprotected' => 'La ema ida bele edita pájina espesiál sira.',
@@ -389,8 +388,6 @@ Check your spelling, ka [[Special:UserLogin/signup|kria konta foun]].',
 'revdelete-hide-user'        => "Subar naran edita-na'in/IP",
 'revdelete-radio-set'        => 'Sin',
 'revdelete-radio-unset'      => 'Lae',
-'revdelete-uname'            => "naran uza-na'in",
-'revdelete-hid'              => 'subar $1',
 'revdelete-edit-reasonlist'  => 'Edita lista motivu nian',
 
 # Diffs
@@ -453,7 +450,7 @@ Check your spelling, ka [[Special:UserLogin/signup|kria konta foun]].',
 'group-all'        => '(hotu)',
 
 'group-user-member'       => "{{GENDER:$1|Uza-na'in}}",
-'group-bot-member'        => 'Bot',
+'group-bot-member'        => '{{GENDER:$1|Bot}}',
 'group-sysop-member'      => '{{GENDER:$1|Administradór|Administradóra}}',
 'group-bureaucrat-member' => '{{GENDER:$1|Burokrata}}',
 'group-suppress-member'   => "{{GENDER:$1|Oversight-na'in}}",
@@ -620,10 +617,8 @@ Check your spelling, ka [[Special:UserLogin/signup|kria konta foun]].',
 'activeusers-hidesysops' => 'Subar administradór sira',
 
 # Special:Log/newusers
-'newuserlogpage'           => "Lista kria uza-na'in",
-'newuserlogpagetext'       => "Ne'e lista kria uza-na'in.",
-'newuserlog-create-entry'  => "Uza-na'in foun",
-'newuserlog-create2-entry' => 'registrar tiha konta foun $1',
+'newuserlogpage'     => "Lista kria uza-na'in",
+'newuserlogpagetext' => "Ne'e lista kria uza-na'in.",
 
 # Special:ListGroupRights
 'listgrouprights-group'   => 'Grupu',
@@ -632,7 +627,7 @@ Check your spelling, ka [[Special:UserLogin/signup|kria konta foun]].',
 
 # E-mail user
 'emailuser'       => "Haruka korreiu eletróniku ba uza-na'in ne'e",
-'defemailsubject' => '{{SITENAME}} korreiu eletróniku',
+'defemailsubject' => '{{SITENAME}} - korreiu eletróniku husi uza-na\'in "$1"',
 'noemailtitle'    => "Lá'os diresaun korreiu eletróniku",
 'emailusername'   => "Naran uza-na'in:",
 'emailsend'       => 'Haruka',
@@ -665,7 +660,6 @@ Check your spelling, ka [[Special:UserLogin/signup|kria konta foun]].',
 'delete-legend'          => 'Halakon',
 'actioncomplete'         => 'operasaun remata',
 'deletedtext'            => 'Ita foin halakon pájina "$1". Haree $2 ba "operasaun halakon" seluk.',
-'deletedarticle'         => 'halakon "[[$1]]"',
 'dellogpage'             => 'Lista halakon',
 'deletionlog'            => 'lista halakon',
 'deletecomment'          => 'Motivu:',
@@ -702,7 +696,6 @@ Check your spelling, ka [[Special:UserLogin/signup|kria konta foun]].',
 'undeletelink'              => 'lee/restaurar',
 'undeleteviewlink'          => 'haree',
 'undeletecomment'           => 'Razaun:',
-'undeletedarticle'          => 'restaurar "[[$1]]"',
 'undeletedrevisions'        => 'restaurar {{PLURAL:$1|versaun|versaun}} $1',
 'undelete-search-submit'    => 'Buka',
 'undelete-show-file-submit' => 'Sin',
@@ -767,7 +760,6 @@ Check your spelling, ka [[Special:UserLogin/signup|kria konta foun]].',
 'movepagebtn'             => 'Book pájina',
 'movedto'                 => 'book tiha ba',
 'movetalk'                => 'Book pájina diskusaun mós',
-'1movedto2'               => 'book tiha [[$1]] ba [[$2]]',
 'movelogpage'             => 'Lista book',
 'movereason'              => 'Motivu:',
 'delete_and_move'         => 'Halakon ho book',
