@@ -7,6 +7,7 @@
  * @ingroup Language
  * @file
  *
+ * @author Agilight
  * @author Andrijko Z.
  * @author Krice from Tyvanet.com
  * @author Sborsody
@@ -126,6 +127,7 @@ $messages = array(
 'hidden-category-category'      => 'Чажыт бөлүктер',
 'category-subcat-count-limited' => 'Бо бөлүк {{PLURAL:$1|бир|$1}} бичии бөлүктүү.',
 'listingcontinuesabbrev'        => '(уланчы)',
+'noindex-category'              => 'Индекстелбес арынар',
 
 'about'         => 'Дугайында',
 'article'       => 'Допчу арын',
@@ -145,18 +147,22 @@ $messages = array(
 'qbpageoptions'  => 'Бо арын',
 'qbmyoptions'    => 'Мээң арыннарым',
 'qbspecialpages' => 'Тускай арыннар',
+'faq'            => 'Бо-ла салыр айтырыглар (БлСА)',
 
 # Vector skin
-'vector-action-delete'  => 'Ырадыры',
-'vector-action-move'    => 'Шимчээри',
-'vector-action-protect' => 'Камгалаары',
-'vector-view-edit'      => 'Өскертири',
-'vector-view-history'   => 'Төөгүнү көөрү',
-'vector-view-view'      => 'Номчууру',
+'vector-action-delete'   => 'Ырадыры',
+'vector-action-move'     => 'Шимчээри',
+'vector-action-protect'  => 'Камгалаары',
+'vector-view-create'     => 'Чогаадыры',
+'vector-view-edit'       => 'Өскертири',
+'vector-view-history'    => 'Төөгүнү көөрү',
+'vector-view-view'       => 'Номчууру',
+'vector-view-viewsource' => 'Дөзү бижиин көөрү',
+'actions'                => 'Кылыглар',
 
 'errorpagetitle'    => 'Алдаг',
 'returnto'          => '$1 деп арынже эглири.',
-'tagline'           => '{{SITENAME}} деп веб-сайттен',
+'tagline'           => '{{SITENAME}} деп веб-сайттан',
 'help'              => 'Дуза',
 'search'            => 'Дилээри',
 'searchbutton'      => 'Дилээри',
@@ -187,7 +193,7 @@ $messages = array(
 'postcomment'       => 'Чаа салбыр',
 'articlepage'       => 'Допчу арынны көөрү',
 'talk'              => 'Чугаалажыры',
-'views'             => 'Көрүштер',
+'views'             => 'Көрүүшкүнү',
 'toolbox'           => 'Херекселдер',
 'userpage'          => 'Ажыглакчының арынын көөрү',
 'projectpage'       => 'Проект арынын көөрү',
@@ -208,8 +214,8 @@ $messages = array(
 'copyrightpage'        => '{{ns:project}}:Чогаалчының эргелери',
 'currentevents'        => 'Амгы үеде болуушкуннар',
 'currentevents-url'    => 'Project:Амгы үеде болуушкуннар',
-'disclaimers'          => 'Ажыглаарынка чомпээрежилдер',
-'disclaimerpage'       => 'Project:Ажыглаарынка чомпээрежил',
+'disclaimers'          => 'Ажыглаар харысаалгазын чөрчүүрү (ойталаары)',
+'disclaimerpage'       => 'Project:Ажыглаар харысаалгазын чөрчүүрү (ойталаары)',
 'edithelp'             => 'Өскертиринге дуза',
 'edithelppage'         => 'Help:Өскертири',
 'helppage'             => 'Help:Допчузу',
@@ -218,6 +224,8 @@ $messages = array(
 'policy-url'           => 'Project:Политика',
 'portal'               => 'Ниитилелдиң хаалгазы',
 'portal-url'           => 'Project:Ниитилелдиң хаалгазы',
+'privacy'              => 'Актыг бүзүрел дугуржулгазы',
+'privacypage'          => 'Project:Актыг бүзүрел дугуржулгазы',
 
 'ok'                  => 'Чөп',
 'retrievedfrom'       => '"$1" деп арынында парлаттынган',
@@ -227,6 +235,7 @@ $messages = array(
 'editsection'         => 'өскертири',
 'editold'             => 'өскертири',
 'editlink'            => 'өскертири',
+'viewsourcelink'      => 'дөзү кодун көөрү',
 'editsectionhint'     => '$1 деп салбырны өскертири',
 'toc'                 => 'Допчузу',
 'showtoc'             => 'көргүзери',
@@ -261,6 +270,7 @@ $messages = array(
 'databaseerror'      => 'Медээ шыгжамыры алдаг',
 'laggedslavemode'    => 'Оваарымчалыг: Бо арында чаартыышкыннар чок болуп болур',
 'readonly'           => 'шоочалаарынга медээ шыгжамыры',
+'missing-article'    => 'дөзү кодун көөрү',
 'missingarticle-rev' => '(үндүрериниң саны: $1)',
 'internalerror'      => 'Иштики алдаг',
 'internalerror_info' => 'Иштики алдаг: $1',
@@ -270,6 +280,7 @@ $messages = array(
 # Login and logout pages
 'yourname'                => 'Aжыглакчының ады',
 'yourpassword'            => 'Чажыт сөс',
+'yourpasswordagain'       => 'Чажыт сөзүңер катап бижиңер:',
 'remembermypassword'      => 'Мени бо компютерде сактып алыры (for a maximum of $1 {{PLURAL:$1|day|days}})',
 'login'                   => 'Кирери',
 'nav-login-createaccount' => 'Кирери / бүрүткел бижикти бүдүрери',
@@ -303,7 +314,9 @@ $messages = array(
 
 # Edit page toolbar
 'bold_sample'     => 'Карартыр',
+'bold_tip'        => 'Кара бижик',
 'italic_sample'   => 'Ийлендирер',
+'italic_tip'      => 'Курсив бижик',
 'link_sample'     => 'Холбаадың ады',
 'link_tip'        => 'Иштики холбаа',
 'extlink_sample'  => 'http://www.example.com холбаадың ады',
@@ -346,7 +359,7 @@ The password for this new account can be changed on the ''[[Special:ChangePasswo
 'viewpagelogs'           => 'Бо арынның журналын көргүзери',
 'nohistory'              => 'Бо арынның өскерлиишкин төөгүзү чок.',
 'currentrev'             => 'Амгы үе үндүрери',
-'revisionasof'           => '$1 ündüreri',
+'revisionasof'           => '$1 версиязы',
 'previousrevision'       => '←Артык эрги үндүрери',
 'nextrevision'           => 'Артык чаа үндүрери→',
 'currentrevisionlink'    => 'Амгы үе үндүрери',
@@ -391,13 +404,17 @@ The password for this new account can be changed on the ''[[Special:ChangePasswo
 'history-title'           => '"$1" деп арынның үндүрери төөгүзү',
 'lineno'                  => 'Одуруг $1:',
 'compareselectedversions' => 'Шилип алган хевирлери деңнээри',
+'editundo'                => 'ойталаар (чөрчүүр)',
 
 # Search results
 'searchresults'             => 'Түңнелдер',
+'searchresults-title'       => '«$1» диле',
 'prevn'                     => 'бүрүнгү {{PLURAL:$1|$1}}',
 'nextn'                     => 'соонда {{PLURAL:$1|$1}}',
 'viewprevnext'              => '($1 {{int:pipe-separator}} $2) ($3) көөрү',
+'searchmenu-new'            => "'''Бо вики-проектиге «[[:$1]]» арынны чогаадыры'''",
 'searchhelp-url'            => 'Help:Допчузу',
+'searchprofile-articles'    => 'үндезин арыннар',
 'searchprofile-images'      => 'Мультимедиа',
 'searchprofile-everything'  => 'Бүгүде',
 'search-result-size'        => '$1 ({{PLURAL:$2|$2 сөс}})',
@@ -405,6 +422,7 @@ The password for this new account can be changed on the ''[[Special:ChangePasswo
 'search-interwiki-more'     => '(артык)',
 'search-mwsuggest-enabled'  => 'саналдар',
 'search-mwsuggest-disabled' => 'саналдар чок',
+'searchrelated'             => 'холбаалыг',
 'searchall'                 => 'шупту',
 'powersearch'               => 'Advanced search',
 'powersearch-toggleall'     => 'Шупту',
@@ -435,7 +453,7 @@ The password for this new account can be changed on the ''[[Special:ChangePasswo
 'prefs-files'               => 'файлдар',
 'youremail'                 => 'Э-чагааңар:',
 'username'                  => 'Aжыглакчының ады:',
-'yourrealname'              => 'Шын адыңар *',
+'yourrealname'              => 'Шын адыңар:',
 'yourlanguage'              => 'Дылыңар:',
 'yournick'                  => 'Шола ат:',
 'gender-male'               => 'Эр',
@@ -500,7 +518,8 @@ The password for this new account can be changed on the ''[[Special:ChangePasswo
 'rc-enhanced-hide'                  => 'Тодаларны чажырары',
 
 # Recent changes linked
-'recentchangeslinked-page' => 'Арынның ады:',
+'recentchangeslinked-toolbox' => 'Хамааржыр эдиглер',
+'recentchangeslinked-page'    => 'Арынның ады:',
 
 # Upload
 'upload'            => 'Файлды салыры',
@@ -518,6 +537,8 @@ The password for this new account can be changed on the ''[[Special:ChangePasswo
 'upload-file-error' => 'Иштики алдаг',
 'upload-misc-error' => 'Билбес кииреринге алдаг',
 
+'license-header' => 'Хоойлужудары',
+
 # Special:ListFiles
 'imgfile'               => 'файл',
 'listfiles'             => 'Файл даңзызы',
@@ -562,7 +583,7 @@ The password for this new account can be changed on the ''[[Special:ChangePasswo
 'unusedtemplateswlh' => 'өске холбаалар',
 
 # Random page
-'randompage' => 'Даап арын',
+'randompage' => 'Душ арын',
 
 # Statistics
 'statistics' => 'Статистика',
@@ -608,6 +629,7 @@ The password for this new account can be changed on the ''[[Special:ChangePasswo
 'movethispage'            => 'Бо арынны шимчээри',
 
 # Book sources
+'booksources'    => 'Номнарның үнген дөзү',
 'booksources-go' => 'Күүcедири',
 
 # Special:Log
@@ -639,9 +661,7 @@ The password for this new account can be changed on the ''[[Special:ChangePasswo
 'activeusers-hidesysops' => 'Эргелекчыларны чажырары',
 
 # Special:Log/newusers
-'newuserlogpage'           => 'Чаа ажыглакчы кырында журнал',
-'newuserlog-create-entry'  => 'Чаа бүрүткел бижик',
-'newuserlog-create2-entry' => '$1 деп чаа бүрүткел бижикти бүдүрген',
+'newuserlogpage' => 'Чаа ажыглакчы кырында журнал',
 
 # Special:ListGroupRights
 'listgrouprights-members' => '(кежигүннүң даңзызы)',
@@ -679,11 +699,13 @@ The password for this new account can be changed on the ''[[Special:ChangePasswo
 'delete-confirm'        => '"$1" деп арынны ырадыры',
 'delete-legend'         => 'Ырадыры',
 'actioncomplete'        => 'Ажыл доосту',
-'deletedarticle'        => '"[[$1]]" деп арынны ап каан',
 'deletecomment'         => 'Чылдагаан:',
 'deleteotherreason'     => 'Өске/немелде чылдагаан:',
 'deletereasonotherlist' => 'Өске чылдагаан',
 
+# Rollback
+'rollbacklink' => 'эглир',
+
 # Protect
 'protectlogpage'         => 'Камгалал кырында журнал',
 'protectedarticle'       => '"[[$1]]" деп арынны камгалаан',
@@ -702,8 +724,8 @@ The password for this new account can be changed on the ''[[Special:ChangePasswo
 # Undelete
 'undeletebtn'            => 'Диргисир',
 'undeletelink'           => 'көөрү/диргисири',
+'undeleteviewlink'       => 'көөрү',
 'undeletecomment'        => 'Чылдагаан:',
-'undeletedarticle'       => '"[[$1]]" диргискен',
 'undelete-search-submit' => 'Дилээр',
 
 # Namespace form on various pages
@@ -725,6 +747,7 @@ The password for this new account can be changed on the ''[[Special:ChangePasswo
 'sp-contributions-submit'   => 'Дилээри',
 
 # What links here
+'whatlinkshere'           => 'Шөлүлгелерни бээр',
 'whatlinkshere-page'      => 'Арын:',
 'isimage'                 => 'чуруктуң холбаазы',
 'whatlinkshere-links'     => '← холбаалар',
@@ -748,6 +771,7 @@ The password for this new account can be changed on the ''[[Special:ChangePasswo
 'blocklogpage'               => 'Ниимиктээриге журнал',
 'blocklogentry'              => ', [[$1]] $2 дургузунда ниимиктээн: $3',
 'block-log-flags-anononly'   => 'чүгле ат эвес ажыглакчылар',
+'block-log-flags-nocreate'   => 'Кижилер бүрүткээри хоруглуг',
 'block-log-flags-hiddenname' => 'ажыглакчының ады чажырган',
 
 # Developer tools
@@ -766,6 +790,9 @@ The password for this new account can be changed on the ''[[Special:ChangePasswo
 'movereason'       => 'Чылдагаан:',
 'delete_and_move'  => 'Ырадыры болгаш шимчээри',
 
+# Export
+'export' => 'Арынар үндүр дамчыдары',
+
 # Namespace 8 related
 'allmessages'               => 'Системниң дыңнадыглары',
 'allmessagesname'           => 'Ат',
@@ -775,6 +802,9 @@ The password for this new account can be changed on the ''[[Special:ChangePasswo
 'allmessages-language'      => 'Дыл:',
 'allmessages-filter-submit' => 'Күүcедири',
 
+# Thumbnails
+'thumbnail-more' => 'Улгаттыр',
+
 # Special:Import
 'import-comment' => 'Комментарий:',
 
@@ -782,36 +812,43 @@ The password for this new account can be changed on the ''[[Special:ChangePasswo
 'import-logentry-upload-detail' => '$1 {{PLURAL:$1|үндүрери}}',
 
 # Tooltip help for the actions
-'tooltip-pt-userpage'       => 'Силерниң ажыглакчы арыныңнар',
-'tooltip-pt-mytalk'         => 'Силерниң чугаалажыр арыныңар',
-'tooltip-pt-mycontris'      => 'Силерниң немелделериңерның даңзызы',
-'tooltip-pt-logout'         => 'Үнери',
-'tooltip-ca-talk'           => 'Бо арын дугайында чыгаалажыры',
-'tooltip-ca-protect'        => 'Бо арынны камгалаары',
-'tooltip-ca-delete'         => 'Бо арынны ырадыры',
-'tooltip-ca-move'           => 'Бо арынны шимчээри',
-'tooltip-ca-watch'          => 'Силерниң хайгаарылга даңзызынга бо арынны немээри',
-'tooltip-ca-unwatch'        => 'Силерниң хайгаарылга даңзызындан бо арынны ырадыры',
-'tooltip-search'            => '{{grammar:locative|{{SITENAME}}}} дилээри',
-'tooltip-p-logo'            => 'Кол Арын',
-'tooltip-n-mainpage'        => 'Кол Арынны баары',
-'tooltip-n-recentchanges'   => 'Викиниң дээм чагы өскерлиишкиннери',
-'tooltip-feed-rss'          => 'Бо арының РСС медээ агымы',
-'tooltip-feed-atom'         => 'Бо арының Атом медээ агымы',
-'tooltip-t-contributions'   => 'Бо ажыглакчының немелделериниң даңзазын көөрү.',
-'tooltip-t-emailuser'       => 'Бо ажыглакчыга э-чагааны чорудаары',
-'tooltip-t-upload'          => 'Файлдарны салыры',
-'tooltip-t-specialpages'    => 'Шупту тускай арыннар даңзызы',
-'tooltip-ca-nstab-main'     => 'Допчы арынын көөрү',
-'tooltip-ca-nstab-user'     => 'Ажыглакчының арынын көөрү',
-'tooltip-ca-nstab-media'    => 'Медиа арынын көөрү',
-'tooltip-ca-nstab-project'  => 'Проект арнызын көөрү',
-'tooltip-ca-nstab-image'    => 'Файлдың арынын көөрү',
-'tooltip-ca-nstab-template' => 'Хээни көөрү',
-'tooltip-ca-nstab-help'     => 'Дуза арынын көөрү',
-'tooltip-ca-nstab-category' => 'Бөлүктүң арынын көөрү',
-'tooltip-save'              => 'Силерниң өскерлиишкиннериңерни шыгжаары',
-'tooltip-watch'             => 'Силерниң хайгаарылга даңзызынга бо арынны немээри',
+'tooltip-pt-userpage'            => 'Силерниң ажыглакчы арыныңнар',
+'tooltip-pt-mytalk'              => 'Силерниң чугаалажыр арыныңар',
+'tooltip-pt-mycontris'           => 'Силерниң немелделериңерның даңзызы',
+'tooltip-pt-logout'              => 'Үнери',
+'tooltip-ca-talk'                => 'Бо арын дугайында чыгаалажыры',
+'tooltip-ca-history'             => 'Арынның мурнуку өскерлиишкиннери',
+'tooltip-ca-protect'             => 'Бо арынны камгалаары',
+'tooltip-ca-delete'              => 'Бо арынны ырадыры',
+'tooltip-ca-move'                => 'Бо арынны шимчээри',
+'tooltip-ca-watch'               => 'Силерниң хайгаарылга даңзызынга бо арынны немээри',
+'tooltip-ca-unwatch'             => 'Силерниң хайгаарылга даңзызындан бо арынны ырадыры',
+'tooltip-search'                 => '{{grammar:locative|{{SITENAME}}}} дилээри',
+'tooltip-search-fulltext'        => 'Бо бижике арыннардан дилээри',
+'tooltip-p-logo'                 => 'Кол Арын',
+'tooltip-n-mainpage'             => 'Кол Арынны баары',
+'tooltip-n-mainpage-description' => 'Кол Арынче кирери',
+'tooltip-n-recentchanges'        => 'Викиниң энир өскерлиишкиннери',
+'tooltip-n-randompage'           => 'Душ арынны көөрү',
+'tooltip-n-help'                 => 'Төлевилелдиң тайылбыры «{{SITENAME}}»',
+'tooltip-feed-rss'               => 'Бо арының РСС медээ агымы',
+'tooltip-feed-atom'              => 'Бо арының Атом медээ агымы',
+'tooltip-t-contributions'        => 'Бо ажыглакчының немелделериниң даңзазын көөрү.',
+'tooltip-t-emailuser'            => 'Бо ажыглакчыга э-чагааны чорудаары',
+'tooltip-t-upload'               => 'Файлдарны киирери',
+'tooltip-t-specialpages'         => 'Шупту тускай арыннар даңзызы',
+'tooltip-t-print'                => 'Бо арынның парлаттынар хевири',
+'tooltip-ca-nstab-main'          => 'Допчы арынын көөрү',
+'tooltip-ca-nstab-user'          => 'Ажыглакчының арынын көөрү',
+'tooltip-ca-nstab-media'         => 'Медиа арынын көөрү',
+'tooltip-ca-nstab-project'       => 'Проект арнызын көөрү',
+'tooltip-ca-nstab-image'         => 'Файлдың арынын көөрү',
+'tooltip-ca-nstab-template'      => 'Хээни көөрү',
+'tooltip-ca-nstab-help'          => 'Дуза арынын көөрү',
+'tooltip-ca-nstab-category'      => 'Бөлүктүң арынын көөрү',
+'tooltip-save'                   => 'Силерниң өскерлиишкиннериңерни шыгжаары',
+'tooltip-watch'                  => 'Силерниң хайгаарылга даңзызынга бо арынны немээри',
+'tooltip-summary'                => 'Кысказы-биле бижиңер',
 
 # Attribution
 'anonymous' => '{{grammar:genitive|{{SITENAME}}}} ат эвес {{PLURAL:$1|ажыглакчызы|ажыглакчылары}}',
