@@ -34,7 +34,7 @@ $namespaceNames = array(
 	NS_CATEGORY         => 'Turkum',
 	NS_CATEGORY_TALK    => 'Turkum_munozarasi',
 );
-	
+
 $namespaceAliases = array(
 	'Mediya'                => NS_MEDIA,
 	'MediyaViki'            => NS_MEDIAWIKI,
@@ -109,25 +109,26 @@ $messages = array(
 'category-article-count' => '{{PLURAL:$2|Ushbu turkumda faqat bitta sahifa mavjud.|Ushbu turkumda quyidagi {{PLURAL:$1|sahifa|$1 sahifalar}}, hammasi boʻlib $2 ta sahifa mavjud.}}',
 'listingcontinuesabbrev' => 'davomi',
 
-'linkprefix'        => '/^(.*?)([a-zA-Z\\x80-\\xffʻʼ«„]+)$/sDu',
-'mainpagetext'      => "<big>'''MediaWiki muvaffaqiyatli o'rnatildi.'''</big>",
-'mainpagedocfooter' => "Wiki dasturini ishlatish haqida ma'lumot olish uchun  [http://meta.wikimedia.org/wiki/Help:Contents Foydalanuvchi qo'llanmasi] sahifasiga murojaat qiling.
+'linkprefix' => '/^(.*?)([a-zA-Z\\x80-\\xffʻʼ«„]+)$/sDu',
 
-== Dastlabki qadamlar ==
+'about'      => 'Haqida',
+'newwindow'  => '(yangi oynada ochiladi)',
+'cancel'     => 'Voz kechish',
+'mytalk'     => 'Suhbatim',
+'anontalk'   => 'Bu IP uchun suhbat',
+'navigation' => 'Saytda harakatlanish',
+'and'        => '&#32;va',
 
-* [http://www.mediawiki.org/wiki/Manual:Configuration_settings Moslamalar ro'yxati]
-* [http://www.mediawiki.org/wiki/Manual:FAQ MediaWiki haqida ko'p so'raladigan savollar]
-* [https://lists.wikimedia.org/mailman/listinfo/mediawiki-announce MediaWiki yangi versiyasi chiqqanda xabar berish ro'yxati]",
-
-'about'          => 'Haqida',
-'newwindow'      => '(yangi oynada ochiladi)',
-'cancel'         => 'Voz kechish',
+# Cologne Blue skin
 'qbedit'         => 'Tahrirlash',
 'qbspecialpages' => 'Maxsus sahifalar',
-'mytalk'         => 'Suhbatim',
-'anontalk'       => 'Bu IP uchun suhbat',
-'navigation'     => 'Saytda harakatlanish',
-'and'            => '&#32;va',
+
+# Vector skin
+'vector-view-create'     => 'Yarat',
+'vector-view-edit'       => 'Tahrirla',
+'vector-view-history'    => 'Tarix',
+'vector-view-view'       => 'Mutolaa',
+'vector-view-viewsource' => 'Manbasini koʻrsat',
 
 'errorpagetitle'   => 'Xato',
 'returnto'         => '$1 sahifasiga qaytish.',
@@ -141,9 +142,12 @@ $messages = array(
 'history_short'    => 'Tarix',
 'printableversion' => 'Bosma uchun versiya',
 'permalink'        => "Doimiy bog'",
+'print'            => 'Chop et',
+'view'             => 'Koʻrish',
 'edit'             => 'Tahrirlash',
 'create'           => 'Yarat',
 'editthispage'     => 'Sahifani tahrirla',
+'create-this-page' => 'Bu sahifani yarat',
 'delete'           => "O'chirish",
 'protect'          => 'Himoyalash',
 'protectthispage'  => 'Bu sahifani himoyala',
@@ -153,14 +157,18 @@ $messages = array(
 'talkpagelinktext' => 'Munozara',
 'specialpage'      => 'Maxsus sahifa',
 'personaltools'    => 'Shaxsiy uskunalar',
+'postcomment'      => 'Yangi boʻlim',
 'talk'             => 'Munozara',
 'views'            => "Ko'rinishlar",
 'toolbox'          => 'Asboblar',
+'categorypage'     => 'Turkum sahifasi',
+'viewtalkpage'     => 'Munozara',
 'otherlanguages'   => 'Boshqa tillarda',
 'redirectedfrom'   => '($1dan yoʻnaltirildi)',
 'redirectpagesub'  => 'Yoʻnaltiruvchi sahifa',
-'lastmodifiedat'   => 'Bu sahifa oxirgi marta $2, $1 sanasida tahrirlangan.', # $1 date, $2 time
+'lastmodifiedat'   => 'Bu sahifa oxirgi marta $2, $1 sanasida tahrirlangan.',
 'viewcount'        => 'Bu sahifaga {{PLURAL:$1|bir marta|$1 marta}} murojaat qilingan.',
+'protectedpage'    => 'Himoyalangan sahifa',
 'jumpto'           => 'Oʻtish:',
 'jumptonavigation' => 'foydalanish',
 'jumptosearch'     => 'Qidir',
@@ -183,18 +191,20 @@ $messages = array(
 'privacy'              => 'Konfidensiallik siyosati',
 'privacypage'          => 'Project:Konfidensiallik siyosati',
 
-'retrievedfrom'       => ' "$1" dan olindi',
-'youhavenewmessages'  => 'Sizga $1 keldi ($2).',
-'newmessageslink'     => 'yangi xabarlar',
-'newmessagesdifflink' => 'soʻnggi oʻzgarish',
-'editsection'         => 'tahrirlash',
-'editold'             => 'tahrir',
-'viewsourcelink'      => 'manbasini koʻr',
-'editsectionhint'     => 'Boʻlimni tahrirlash: $1',
-'toc'                 => 'Mundarija',
-'showtoc'             => "Ko'rsatish",
-'hidetoc'             => 'yashirish',
-'red-link-title'      => '$1 (sahifa yaratilmagan)',
+'retrievedfrom'        => ' "$1" dan olindi',
+'youhavenewmessages'   => 'Sizga $1 keldi ($2).',
+'newmessageslink'      => 'yangi xabarlar',
+'newmessagesdifflink'  => 'soʻnggi oʻzgarish',
+'editsection'          => 'tahrirlash',
+'editold'              => 'tahrir',
+'viewsourcelink'       => 'manbasini koʻr',
+'editsectionhint'      => 'Boʻlimni tahrirlash: $1',
+'toc'                  => 'Mundarija',
+'showtoc'              => "Ko'rsatish",
+'hidetoc'              => 'yashirish',
+'collapsible-collapse' => 'Yashir',
+'collapsible-expand'   => 'Koʻrsat',
+'red-link-title'       => '$1 (sahifa yaratilmagan)',
 
 # Short words for each namespace, by default used in the namespace tab in monobook
 'nstab-main'     => 'Maqola',
@@ -207,36 +217,37 @@ $messages = array(
 'nstab-category' => 'Turkum',
 
 # General errors
+'error'             => 'Xato',
 'badtitle'          => 'Notoʻgʻri sarlavha',
 'viewsource'        => "Ko'rib chiqish",
-'viewsourcefor'     => '$1 uchun',
 'protectedpagetext' => 'Bu sahifa tahrirlashdan saqlanish maqsadida qulflangan.',
 'viewsourcetext'    => "Siz bu sahifaning manbasini ko'rishingiz va uni nusxasini olishingiz mumkin:",
 
 # Login and logout pages
-'logouttext'              => "'''Siz saytdan muvaffaqiyatli chiqdingiz.'''<br />
-{{SITENAME}} saytidan anonim holda foydalanishda davom etishindiz mumkin. Yoki siz yana hozirgi yoki boshqa foydalanuvchi nomi bilan qaytadan tizimga kirishingiz mumkin. Shuni e'tiborga olingki, ayrim sahifalar siz brauzeringiz keshini tozalamaguningizga qadar xuddi tizimga kirganingizdagidek ko'rinishda davom etaverishi mumkin.",
+'logouttext'              => "'''Siz saytdan muvaffaqiyatli chiqdingiz.'''
+
+{{SITENAME}} saytidan anonim holda foydalanishda davom etishindiz mumkin. Yoki siz yana hozirgi yoki boshqa foydalanuvchi nomi bilan qaytadan tizimga kirishingiz mumkin.
+Shuni e'tiborga olingki, ayrim sahifalar siz brauzeringiz keshini tozalamaguningizga qadar xuddi tizimga kirganingizdagidek ko'rinishda davom etaverishi mumkin.",
 'yourname'                => 'Foydalanuvchi nomi',
 'yourpassword'            => "Maxfiy so'z",
 'yourpasswordagain'       => "Maxfiy so'zni qayta kiriting",
-'remembermypassword'      => "Hisob ma'lumotlarini shu kompyuterda eslab qolish",
+'remembermypassword'      => "Hisob ma'lumotlarini shu kompyuterda eslab qolish (for a maximum of $1 {{PLURAL:$1|day|days}})",
 'login'                   => 'Kirish',
 'nav-login-createaccount' => 'Kirish / Hisob yaratish',
 'loginprompt'             => "{{SITENAME}}ga kirish uchun kukilar yoqilgan bo'lishi kerak.",
 'userlogin'               => 'Kirish / Hisob yaratish',
 'logout'                  => 'Chiqish',
 'userlogout'              => 'Chiqish',
-'nologin'                 => 'Hisobingiz yoʻqmi? $1.',
+'nologin'                 => "Hisobingiz yoʻqmi? '''$1'''.",
 'nologinlink'             => 'Hisob yaratish',
 'createaccount'           => 'Hisob yaratish',
-'gotaccount'              => 'Hisobingiz bormi? $1.',
+'gotaccount'              => "Hisobingiz bormi? '''$1'''.",
 'gotaccountlink'          => 'Kirish',
-'yourrealname'            => 'Haqiqiy ism *:',
 'loginsuccesstitle'       => 'Kirish muvaffaqiyatli amalga oshdi',
 'loginsuccess'            => "'''{{SITENAME}}ga \"\$1\" foydalanuvchi nomi bilan kirdingiz.'''",
 'wrongpassword'           => 'Kiritgan mahfiy soʻzingiz notoʻgʻri. Iltimos, qaytadan kiritib koʻring.',
 
-# Password reset dialog
+# Change password dialog
 'retypenew' => 'Yangi mahfiy soʻzni qayta tering:',
 
 # Edit page toolbar
@@ -249,22 +260,20 @@ $messages = array(
 'extlink_sample'  => 'http://www.example.com ishorat nomi',
 'extlink_tip'     => 'Tashqi ishorat (http:// prefiksini unutmang)',
 'headline_sample' => 'Sarlavha',
-'math_sample'     => 'Formula qoʻying',
-'math_tip'        => 'Matematik formula (LaTeX)',
 'image_tip'       => 'Qoʻshilgan tasvir',
 'media_tip'       => 'Faylga ishorat',
 'sig_tip'         => 'Imzoingiz va sana',
 
 # Edit pages
-'summary'                => 'Qisqa izoh:',
-'minoredit'              => 'Bu kichik tahrir',
-'watchthis'              => 'Sahifani kuzatish',
-'savearticle'            => 'Saqlash',
-'preview'                => "Ko'rib chiqish",
-'showpreview'            => "Ko'rib chiqish",
-'showdiff'               => "O'zgarishlarni ko'rsatish",
-'anoneditwarning'        => "'''Diqqat:''' Siz tizimga kirmagansiz. Ushbu sahifa tarixida Sizning IP manzilingiz yozib qolinadi.",
-'blockedtext'            => "<big>'''Siz (foydalanuvchi ismingiz yoki IP manzilingiz) tahrir qilishdan chetlashtirildingiz.'''</big>
+'summary'                    => 'Qisqa izoh:',
+'minoredit'                  => 'Bu kichik tahrir',
+'watchthis'                  => 'Sahifani kuzatish',
+'savearticle'                => 'Saqlash',
+'preview'                    => "Ko'rib chiqish",
+'showpreview'                => "Ko'rib chiqish",
+'showdiff'                   => "O'zgarishlarni ko'rsatish",
+'anoneditwarning'            => "'''Diqqat:''' Siz tizimga kirmagansiz. Ushbu sahifa tarixida Sizning IP manzilingiz yozib qolinadi.",
+'blockedtext'                => "'''Siz (foydalanuvchi ismingiz yoki IP manzilingiz) tahrir qilishdan chetlashtirildingiz.'''
 
 Sizni $1 chetlashtirdi. Bunga sabab: ''$2''.
 
@@ -272,32 +281,31 @@ Sizni $1 chetlashtirdi. Bunga sabab: ''$2''.
 * Chetlashtirish muddati yakuni: $6
 
 Siz $1 yoki boshqa [[{{MediaWiki:Grouppage-sysop}}|administrator]] bilan bogʻlanib, arz qilishingiz mumkin.
+You cannot use the 'e-mail this user' feature unless a valid e-mail address is specified in your [[Special:Preferences|account preferences]] and you have not been blocked from using it.
 Sizning hozirgi IP manzilingiz - $3, chetlashtirish raqamingiz - #$5. Arizaga bularni ilova qilishingiz mumkin.",
-'newarticle'             => '(Yangi)',
-'newarticletext'         => "Bu sahifa hali mavjud emas.
+'newarticle'                 => '(Yangi)',
+'newarticletext'             => "Bu sahifa hali mavjud emas.
 Sahifani yaratish uchun quyida matn kiritishingiz mumkin (qo'shimcha axborot uchun [[{{MediaWiki:Helppage}}|yordam sahifasini]] ko'ring).
 Agar bu sahifaga xatolik sabab kelgan bo'lsangiz brauzeringizning '''orqaga''' tugmasini bosing.",
-'noarticletext'          => 'Bu sahifada hozircha hech qanday matn yoʻq. Siz bu sarlavhani boshqa sahifalardan [[Special:Search/{{PAGENAME}}|qidirishingiz]], <span class="plainlinks">[{{fullurl:Special:Log|page={{urlencode:{{FULLPAGENAME}}}}}} tegishli loglarga qarashingiz] yoki bu sahifani [{{fullurl:{{FULLPAGENAME}}|action=edit}} tahrirlashingiz]</span> mumkin.',
-'clearyourcache'         => "'''Etibor bering:''' O'zgartirishlaringiz ko'rish uchun, yangi moslamalaringizning saqlashdan keyin, brauser keshini tozalash kerak:<br />
+'noarticletext'              => 'Bu sahifada hozircha hech qanday matn yoʻq. Siz bu sarlavhani boshqa sahifalardan [[Special:Search/{{PAGENAME}}|qidirishingiz]], <span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} tegishli loglarga qarashingiz] yoki bu sahifani [{{fullurl:{{FULLPAGENAME}}|action=edit}} tahrirlashingiz]</span> mumkin.',
+'clearyourcache'             => "'''Etibor bering:''' O'zgartirishlaringiz ko'rish uchun, yangi moslamalaringizning saqlashdan keyin, brauser keshini tozalash kerak:<br />
 '''Mozilla / Firefox:''' ''Ctrl+Shift+R'', '''IE:''' ''Ctrl+F5'', '''Safari:''' ''Cmd+Shift+R'', '''Konqueror:''' ''F5'', '''Opera:''' ''Tools → Preferences'' orqali keshni tozalang.",
-'previewnote'            => "'''Bu shunchaki ko'rib chiqish. O'zgarishlar hali saqlangani yo'q!'''",
-'editing'                => '$1 tahrirlanmoqda',
-'editingsection'         => '$1 (boʻlim) tahrirlanmoqda',
-'copyrightwarning'       => "Iltimos, {{SITENAME}}ga yuklangan har qanday axborot $2 ostida tarqatilishiga diqqat qiling (batafsil ma'lumot uchun $1ni ko'ring).
+'previewnote'                => "'''Bu shunchaki ko'rib chiqish. O'zgarishlar hali saqlangani yo'q!'''",
+'editing'                    => '$1 tahrirlanmoqda',
+'editingsection'             => '$1 (boʻlim) tahrirlanmoqda',
+'copyrightwarning'           => "Iltimos, {{SITENAME}}ga yuklangan har qanday axborot $2 ostida tarqatilishiga diqqat qiling (batafsil ma'lumot uchun $1ni ko'ring).
 Agar yozganlaringiz keyinchalik tahrir qilinishi va qayta tarqatilishiga rozi bo'lmasangiz, u holda bu yerga yozmang.<br />
 Siz shuningdek bu yozganlaringiz sizniki yoki erkin litsenziya ostida ekanligini va'da qilmoqdasiz.
 '''MUALLIFLIK HUQUQLARI BILAN HIMOYALANGAN ISHLARNI ZINHOR BERUXSAT YUBORMANG!'''",
-'copyrightwarning2'      => "Iltimos, shuni esda tutingki, {{SITENAME}} sahifalaridagi barcha matnlar boshqa foydalanuvchilar tomonidan tahrirlanishi, almashtirilishi yoki o'chirilishi mumkin. Agar siz yozgan ma'lumotlaringizni bunday tartibda tahrirlanishiga rozi bo'lmasangiz, unda uni bu yerga joylashtirmang.<br />
+'copyrightwarning2'          => "Iltimos, shuni esda tutingki, {{SITENAME}} sahifalaridagi barcha matnlar boshqa foydalanuvchilar tomonidan tahrirlanishi, almashtirilishi yoki o'chirilishi mumkin. Agar siz yozgan ma'lumotlaringizni bunday tartibda tahrirlanishiga rozi bo'lmasangiz, unda uni bu yerga joylashtirmang.<br />
 Bundan tashqari, siz ushbu ma'lumotlarni o'zingiz yozgan bo'lishingiz yoki ruxsat berilgan internet manzilidan yoki shu kabi erkin resursdan nusxa olgan bo'lishingiz lozim (Qo'shimcha ma'lumotlar ushun $1 sahifasiga murojaat qiling).
 '''MUALLIFLIK HUQUQI QO'YILGAN ISHLARNI RUXSATSIZ BU YERGA JOYLASHTIRMANG!'''",
-'longpagewarning'        => "'''DIQQAT: Ushbu sahifa hajmi $1 kilobaytdir; ayrim browser'lar 32 kb dan oshiq hajmli sahifalarni tahrirlashda muammolarga duch kelishi mumkin.
-Agar sizda shunday muammolar yuzaga kelsa, iltimos, sahifani butunlay emas, qismlab tahrirlang.'''",
-'templatesused'          => 'Ushbu sahifada ishlatilgan andozalar:',
-'template-protected'     => '(himoyalangan)',
-'template-semiprotected' => '(yarim-himoyalangan)',
-'nocreatetext'           => 'Ushbu sayt yangi sahifa yaratishni taqiqlagan.
+'templatesused'              => '{{PLURAL:$1|Template|Templates}} used on this page:',
+'template-protected'         => '(himoyalangan)',
+'template-semiprotected'     => '(yarim-himoyalangan)',
+'nocreatetext'               => 'Ushbu sayt yangi sahifa yaratishni taqiqlagan.
 Ortga qaytib, mavjud sahifani tahrirlashingiz yoki [[Special:UserLogin|tizimga kirishingiz]] mumkin.',
-'recreate-deleted-warn'  => "'''Diqqat: Siz avval yoʻqotilgan sahifani yana yaratmoqchisiz.'''
+'recreate-moveddeleted-warn' => "'''Diqqat: Siz avval yoʻqotilgan sahifani yana yaratmoqchisiz.'''
 
 Bu sahifani yaratishda davom etishdan avval uning nega avval yoʻqotilgani bilan qiziqib koʻring.
 Qulaylik uchun quyida yoʻqotilish qaydlari keltirilgan:",
@@ -335,13 +343,11 @@ Bu yerda: (joriy) = hozirgi koʻrinish bilan farq,
 'searchresulttext'         => "{{SITENAME}}da qidirish haqida qo'shimcha ma'lumotga ega bo'lishini xoxlasangiz, [[{{MediaWiki:Helppage}}|{{SITENAME}}da qidiruv]] sahifasini o'qing.",
 'searchsubtitle'           => '\'\'\'[[:$1]]\'\'\'ni qidirdingiz ([[Special:Prefixindex/$1|"$1" bilan boshlanadigan sahifalar]]{{int:pipe-separator}}[[Special:WhatLinksHere/$1|"$1"ga bogʻlangan sahifalar]])',
 'searchsubtitleinvalid'    => "'''$1'''ni qidirdingiz",
-'noexactmatch'             => "'''\"\$1\" nomli birorta ham sahifa yo'q.''' Bu sahifani [[:\$1|yaratishingiz]] mumkin.",
-'noexactmatch-nocreate'    => "'''\"\$1\" sarlavhali sahifa yoʻq.'''",
 'notitlematches'           => 'Bunday sarlavha topilmadi',
 'notextmatches'            => 'Bunday matn topilmadi',
 'prevn'                    => 'oldingi $1',
-'nextn'                    => 'keyingi $1',
-'viewprevnext'             => "Ko'rish ($1) ($2) ($3).",
+'nextn'                    => 'keyingi {{PLURAL:$1|$1}}',
+'viewprevnext'             => "Ko'rish ($1 {{int:pipe-separator}} $2) ($3).",
 'searchhelp-url'           => 'Help:Mundarija',
 'search-result-size'       => '$1 ({{PLURAL:$2|1 soʻz|$2 soʻz}})',
 'search-redirect'          => '(yoʻnaltirish $1)',
@@ -349,7 +355,6 @@ Bu yerda: (joriy) = hozirgi koʻrinish bilan farq,
 'search-suggest'           => 'Balki buni nazarda tutgandirsiz: $1',
 'search-interwiki-default' => '$1 natijalar:',
 'showingresults'           => "#<b>$2</b> boshlanayotgan <b>$1</b> natijalar ko'rsatilyapti.",
-'showingresultstotal'      => "Quyida {{PLURAL:$4|'''$3'''dan '''$1''' natija|'''$3'''dan '''$1 - $2''' natijalar}} koʻrsatilgan",
 'powersearch'              => 'Qidiruv',
 'powersearch-ns'           => 'Bu nom-fazolarda izla:',
 'powersearch-redir'        => 'Yoʻnaltirishlarni koʻrsat',
@@ -358,18 +363,18 @@ Bu yerda: (joriy) = hozirgi koʻrinish bilan farq,
 # Preferences page
 'preferences'       => 'Moslamalar',
 'mypreferences'     => 'Moslamalarim',
-'skin'              => "Tashqi ko'rinish",
-'math'              => 'Formulalar',
-'datetime'          => 'Sana va vaqt',
+'prefs-skin'        => "Tashqi ko'rinish",
+'prefs-datetime'    => 'Sana va vaqt',
 'prefs-personal'    => "Shaxsiy ma'lumotlar",
 'prefs-rc'          => "Yangi o'zgartirishlar",
 'prefs-watchlist'   => "Kuzatuv ro'yxati",
 'prefs-misc'        => 'Boshqa moslamalar',
 'saveprefs'         => 'Saqlash',
 'resetprefs'        => 'Bekor qilish',
-'textboxsize'       => 'Tahrirlash',
+'prefs-editing'     => 'Tahrirlash',
 'searchresultshead' => 'Qidiruv natijalari',
-'files'             => 'Fayllar',
+'prefs-files'       => 'Fayllar',
+'yourrealname'      => 'Haqiqiy ism *:',
 
 # Groups
 'group-sysop' => 'Administratorlar',
@@ -411,6 +416,7 @@ Bu yerda: (joriy) = hozirgi koʻrinish bilan farq,
 'listfiles' => 'Fayllar roʻyxati',
 
 # File description page
+'file-anchor-link'          => 'Fayl',
 'filehist'                  => 'Fayl tarixi',
 'filehist-help'             => 'Faylning biror paytdagi holatini koʻrish uchun tegishli sana/vaqtga bosingiz.',
 'filehist-current'          => 'joriy',
@@ -422,8 +428,7 @@ Bu yerda: (joriy) = hozirgi koʻrinish bilan farq,
 'imagelinks'                => 'Fayllarga ishoratlar',
 'linkstoimage'              => 'Bu faylga quyidagi {{PLURAL:$1|sahifa|$1 sahifalar}} bogʻlangan:',
 'nolinkstoimage'            => 'Bu faylga bogʻlangan sahifalar yoʻq.',
-'sharedupload'              => 'Ushbu fayl umumiy joyga yuklangandir va boshqa loyihalarda ishlatilishi mumkin.', # $1 is the repo name, $2 is shareduploadwiki(-desc)
-'shareduploadwiki-linktext' => 'fayl haqida sahifa',
+'sharedupload'              => 'This file is from $1 and may be used by other projects.',
 'uploadnewversion-linktext' => 'Bu faylning yangi versiyasini yukla',
 
 # Unused templates
@@ -474,10 +479,9 @@ Bu yerda: (joriy) = hozirgi koʻrinish bilan farq,
 
 # Special:Categories
 'categories'         => 'Turkumlar',
-'categoriespagetext' => 'Ushbu turkumlarda sahifa yoki fayllar mavjud.',
-
-# Special:Log/newusers
-'newuserlog-create-entry' => 'Yangi foydalanuvchi',
+'categoriespagetext' => 'The following {{PLURAL:$1|category contains|categories contain}} pages or media.
+[[Special:UnusedCategories|Unused categories]] are not shown here.
+Also see [[Special:WantedCategories|wanted categories]].',
 
 # E-mail user
 'emailuser' => 'Bu foydalanuvchiga e-maktub joʻnat',
@@ -485,27 +489,23 @@ Bu yerda: (joriy) = hozirgi koʻrinish bilan farq,
 # Watchlist
 'watchlist'        => 'Kuzatuv roʻyxatim',
 'mywatchlist'      => 'Kuzatuv roʻyxatim',
-'watchlistfor'     => "('''$1''' uchun)",
 'nowatchlist'      => "Kuzatuv ro'yxatingizda hech narsa yo'q.",
-'addedwatch'       => "Kuzatuv ro'yxatiga qo'shildi",
 'addedwatchtext'   => "\"[[:\$1]]\" sahifasi sizning [[Special:Watchlist|kuzatuv ro'yxatingizga]] qo'shildi. Bu sahifada va unga mos munozara sahifasida bo'ladigan kelajakdagi o'zgarishlar bu yerda ro'yxatga olinadi, hamda bu sahifa topish qulay bo'lishi uchun [[Special:RecentChanges|yangi o'zgarishlar ro'yxati]]da '''qalin''' harflar bilan ko'rsatiladi.
 
 Agar siz bu sahifani kuzatuv ro'yxatingizdan o'chirmoqchi bo'lsangiz \"Kuzatmaslik\" yozuvini bosing.",
-'removedwatch'     => "Kuzatuv ro'yxatidan o'chirildi",
 'removedwatchtext' => '"[[:$1]]" sahifasi kuzatuv ro\'yxatingizdan o\'chirildi.',
 'watch'            => 'kuzatish',
 'watchthispage'    => 'Sahifani kuzatish',
 'unwatch'          => 'kuzatmaslik',
-'wlnote'           => "Pastda oxirgi '''$2''' soatda sodir bo'lgan $1 o'zgartirishlar ko'rsatilgan.",
+'wlnote'           => "Below {{PLURAL:$1|is the last change|are the last '''$1''' changes}} in the last {{PLURAL:$2|hour|'''$2''' hours}}, as of $3, $4.",
 'wlshowlast'       => "Oxirgi $1 soatdagi $2 kundagi tahrirlarni ko'rsatish. $3 tahrirlarni ko'rsatish",
 
 # Delete
 'actioncomplete'        => 'Bajarildi',
-'deletedtext'           => '"<nowiki>$1</nowiki>" yoʻqotildi.
+'deletedtext'           => '"$1" yoʻqotildi.
 Yaqinda sodir etilgan yoʻqotishlar uchun $2ni koʻring.',
-'deletedarticle'        => '"[[$1]]" yoʻqotildi',
 'dellogpage'            => 'Yoʻqotish qaydlari',
-'deletecomment'         => "O'chirish sababi",
+'deletecomment'         => 'Sabab:',
 'deleteotherreason'     => 'Boshqa/qoʻshimcha sabab:',
 'deletereasonotherlist' => 'Boshqa sabab',
 
@@ -515,7 +515,7 @@ Yaqinda sodir etilgan yoʻqotishlar uchun $2ni koʻring.',
 # Protect
 'protectlogpage'         => 'Himoyalash qaydlari',
 'protect-level-sysop'    => 'Faqat administratorlar uchun',
-'protect-expiry-options' => '2 soat:2 hours,1 kun:1 day,3 kun:3 days,1 hafta:1 week,2 hafta:2 weeks,1 oy:1 month,3 oy:3 months,6 oy:6 months,1 yil:1 year,cheksiz:infinite', # display1:time1,display2:time2,...
+'protect-expiry-options' => '2 soat:2 hours,1 kun:1 day,1 hafta:1 week,2 hafta:2 weeks,1 oy:1 month,3 oy:3 months,6 oy:6 months,1 yil:1 year,cheksiz:infinite',
 
 # Restrictions (nouns)
 'restriction-edit' => 'Tahrirlash',
@@ -535,6 +535,7 @@ Yaqinda sodir etilgan yoʻqotishlar uchun $2ni koʻring.',
 
 'sp-contributions-newbies'  => 'Faqatgina yangi foydalanuvchilarning hissalarini koʻrsat',
 'sp-contributions-blocklog' => 'Chetlashtirish qaydlari',
+'sp-contributions-talk'     => 'Munozara',
 'sp-contributions-search'   => 'Hissalarni qidir',
 'sp-contributions-username' => 'IP manzil yoki foydalanuvchi ismi:',
 'sp-contributions-submit'   => 'Qidir',
@@ -550,7 +551,7 @@ Yaqinda sodir etilgan yoʻqotishlar uchun $2ni koʻring.',
 
 # Block/unblock
 'blockip'      => 'Foydalanuvchini chetlashtir',
-'ipboptions'   => '2 soat:2 hours,1 kun:1 day,3 kun:3 days,1 hafta:1 week,2 hafta:2 weeks,1 oy:1 month,3 oy:3 months,6 oy:6 months,1 yil:1 year,cheksiz:infinite', # display1:time1,display2:time2,...
+'ipboptions'   => '2 soat:2 hours,1 kun:1 day,3 kun:3 days,1 hafta:1 week,2 hafta:2 weeks,1 oy:1 month,3 oy:3 months,6 oy:6 months,1 yil:1 year,cheksiz:infinite',
 'ipblocklist'  => 'Chetlashtirilgan IP manzillari va foydalanuvchilar',
 'blocklink'    => 'chetlashtir',
 'contribslink' => 'hissasi',
@@ -560,8 +561,7 @@ Yaqinda sodir etilgan yoʻqotishlar uchun $2ni koʻring.',
 'movearticle'    => "Sahifani ko'chirish",
 'movepagebtn'    => 'Sahifani koʻchir',
 'pagemovedsub'   => 'Koʻchirildi',
-'movepage-moved' => '<big>\'\'\'"$1" nomli sahifa "$2" nomli sahifaga koʻchirildi\'\'\'</big>', # The two titles are passed in plain text as $3 and $4 to allow additional goodies in the message.
-'1movedto2'      => "[[$1]] [[$2]]ga ko'chirildi",
+'movepage-moved' => '\'\'\'"$1" nomli sahifa "$2" nomli sahifaga koʻchirildi\'\'\'',
 'movelogpage'    => 'Koʻchirish qaydlari',
 'movereason'     => 'Sabab:',
 'revertmove'     => 'qaytar',
@@ -634,13 +634,12 @@ Yaqinda sodir etilgan yoʻqotishlar uchun $2ni koʻring.',
 'nextdiff'     => 'Keyingi tahrir →',
 
 # Media information
-'imagemaxsize'         => "Tasvir ta'rifi sahifasidagi tasvirning kattaligi:",
-'thumbsize'            => 'Tasvirning kichiklashtirilgan versiyasining kattaligi:',
-'file-info-size'       => '($1 × $2 piksel, fayl hajmi: $3, MIME tipi: $4)',
-'file-nohires'         => '<small>Bundan kattaroq tasvir yoʻq.</small>',
-'svg-long-desc'        => '(SVG fayl, asl oʻlchamlari $1 × $2 piksel, fayl hajmi: $3)',
-'show-big-image'       => 'Asl hajmdagi tasvir',
-'show-big-image-thumb' => '<small>Ushbu koʻrinish oʻlchamlari: $1 × $2 piksel</small>',
+'imagemaxsize'   => "Tasvir ta'rifi sahifasidagi tasvirning kattaligi:",
+'thumbsize'      => 'Tasvirning kichiklashtirilgan versiyasining kattaligi:',
+'file-info-size' => '$1 × $2 piksel, fayl hajmi: $3, MIME tipi: $4',
+'file-nohires'   => 'Bundan kattaroq tasvir yoʻq.',
+'svg-long-desc'  => 'SVG fayl, asl oʻlchamlari $1 × $2 piksel, fayl hajmi: $3',
+'show-big-image' => 'Asl hajmdagi tasvir',
 
 # Special:NewFiles
 'ilsubmit' => 'Qidirish',
@@ -651,13 +650,11 @@ Yaqinda sodir etilgan yoʻqotishlar uchun $2ni koʻring.',
 
 # External editor support
 'edit-externally'      => 'Bu faylni tashqi dasturiy ilovalar yordamida tahrirla',
-'edit-externally-help' => "(Batafsil ma'lumotlar uchun [http://www.mediawiki.org/wiki/Manual:External_editors bu yerga] qarang)",
+'edit-externally-help' => "(Batafsil ma'lumotlar uchun [//www.mediawiki.org/wiki/Manual:External_editors bu yerga] qarang)",
 
 # 'all' in various places, this might be different for inflected languages
-'recentchangesall' => 'Barchasi',
-'imagelistall'     => 'Barchasi',
-'watchlistall2'    => 'Barcha',
-'namespacesall'    => 'Barchasi',
+'watchlistall2' => 'Barcha',
+'namespacesall' => 'Barchasi',
 
 'unit-pixel' => 'piksel',
 
