@@ -7,6 +7,8 @@
  * @ingroup Language
  * @file
  *
+ * @author PhiLiP
+ * @author Shizhao
  * @author Wong128hk
  */
 
@@ -17,7 +19,10 @@ $messages = array(
 # User preference toggles
 'tog-norollbackdiff' => '进行回退后略过差异比较',
 
-# Move page
-'move-redirect-suppressed' => '已禁止重新定向',
+# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
+'portal' => '社区入口',
+
+# Edit pages
+'editing' => '正在编辑 $1',
 
 );
