@@ -23,6 +23,8 @@
  * @author לערי ריינהארט
  */
 
+$fallback = 'zh-hant, zh-hans';
+
 $specialPageAliases = array(
 	'Ancientpages'              => array( '最舊頁面' ),
 	'Block'                     => array( '查封用戶' ),
@@ -44,8 +46,6 @@ $specialPageAliases = array(
 	'Withoutinterwiki'          => array( '沒有跨語言鏈接的頁面' ),
 );
 
-$fallback = 'zh-hant';
-
 $namespaceNames = array(
 	NS_USER             => '使用者',
 	NS_USER_TALK        => '使用者討論',
@@ -395,7 +395,6 @@ $messages = array(
 'revdelete-hide-restricted'   => '將此限制同樣應用於管理員',
 'revdelete-suppress'          => '同時壓制由操作員以及其他使用者的資料',
 'revdelete-unsuppress'        => '在已復原的修訂中移除限制',
-'revdelete-logentry'          => '已更改「[[$1]]」之修訂可見度',
 'revdelete-success'           => '修訂的可見性已經成功設定。',
 'logdelete-success'           => '事件的可見性已經成功設定。',
 
@@ -646,7 +645,6 @@ $NEWPAGE
 請確定您要進行此項操作，並且了解其後果，同時您的行為符合[[{{MediaWiki:Policy-url}}]]。',
 'deletedtext'       => '「$1」已經被刪除。
 最近刪除的紀錄請參見$2。',
-'deletedarticle'    => '已刪除「[[$1]]」',
 'dellogpagetext'    => '以下是最近刪除的紀錄列表。
 所有的時間都是使用伺服器時間。',
 'reverted'          => '復原到早期版本',
@@ -691,7 +689,6 @@ $NEWPAGE
 'undelete-revision'            => '刪除$1時由$3（在$2）所編寫的修訂版本:',
 'undeleterevision-missing'     => '此版本的內容不正確或已經遺失。可能連結錯誤、被移除或已經被復原。',
 'undeletebtn'                  => '復原',
-'undeletedarticle'             => '已經復原「$1」',
 'undeletedrevisions'           => '$1個修訂版本已經復原',
 'undeletedrevisions-files'     => '$1 個版本和 $2 個檔案被復原',
 'undeletedfiles'               => '$1 個檔案被復原',
@@ -731,7 +728,7 @@ $NEWPAGE
 'ipbhidename'                 => '在封鎖日誌、活躍封鎖列表以及使用者列表中隱藏使用者名／IP',
 'blockipsuccesssub'           => '封鎖成功',
 'blockipsuccesstext'          => '[[Special:Contributions/$1|$1]]已經被封鎖。
-<br />參看[[Special:IPBlockList|被封IP地址列表]]以覆審封鎖。',
+<br />參看[[Special:BlockList|被封IP地址列表]]以覆審封鎖。',
 'ipb-edit-dropdown'           => '編輯封鎖原因',
 'ipb-unblock-addr'            => '解除封鎖$1',
 'ipb-unblock'                 => '解除禁封使用者名或IP地址',
@@ -858,7 +855,6 @@ $NEWPAGE
 
 # Patrol log
 'patrol-log-page' => '巡查記錄',
-'patrol-log-line' => '已經標示$1/$2版做已巡查的$3',
 
 # Browsing diffs
 'previousdiff' => '←上一個',
@@ -866,7 +862,7 @@ $NEWPAGE
 
 # Media information
 'imagemaxsize'   => '在圖片描述頁對圖片大小限制為:',
-'file-nohires'   => '<small>無更高解析度可提供。</small>',
+'file-nohires'   => '無更高解析度可提供。',
 'show-big-image' => '完整解析度',
 
 # Special:NewFiles
